@@ -1,36 +1,11 @@
-<?PHP //$Id: backuplib.php,v 1.65.2.9 2005/02/04 16:13:41 stronk7 Exp $
+<?php //$Id: backuplib.php,v 1.96.2.1 2005/07/12 07:42:43 moodler Exp $
     //This file contains all the function needed in the backup utility
     //except the mod-related funtions that are into every backuplib.php inside
     //every mod directory
-
-    //Insert necessary category ids to backup_ids table
-    function insert_category_ids ($course,$backup_unique_code) {
-        global $CFG;
-        $status = true;
-        $status = execute_sql("INSERT INTO {$CFG->prefix}backup_ids
-                                   (backup_code, table_name, old_id)
-                               SELECT DISTINCT $backup_unique_code,'quiz_categories',t.category
-                               FROM {$CFG->prefix}quiz_questions t,
-                                    {$CFG->prefix}quiz_question_grades g,
-                                    {$CFG->prefix}quiz q
-                               WHERE q.course = '$course' AND
-                                     g.quiz = q.id AND
-                                     g.question = t.id",false);
-        return $status;
-    }
-    
-    //Delete category ids from backup_ids table
-    function delete_category_ids ($backup_unique_code) {
-        global $CFG;
-        $status = true;
-        $status = execute_sql("DELETE FROM {$CFG->prefix}backup_ids
-                               WHERE backup_code = '$backup_unique_code'",false);
-        return $status;
-    }
  
     //Calculate the number of users to backup and put their ids in backup_ids
     //Return an array of info (name,value)
-    function user_check_backup($course,$backup_unique_code,$backup_users) {
+    function user_check_backup($course,$backup_unique_code,$backup_users,$backup_messages) {
         //$backup_users=0-->all
         //              1-->course (needed + enrolled)
         //              2-->none
@@ -44,7 +19,7 @@
         if ($backup_users == 0 or $backup_users == 1) {
         
             //Calculate needed users (calling every xxxx_get_participants function + scales users)
-            $needed_users = backup_get_needed_users($course);
+            $needed_users = backup_get_needed_users($course, $backup_messages);
 
             //Calculate enrolled users (students + teachers)
             $enrolled_users = backup_get_enrolled_users($course);
@@ -126,9 +101,9 @@
     //   every student and teacher in the course, so it
     //must be merged with backup_get_enrrolled_users !!
 
-    function backup_get_needed_users ($courseid) {
+    function backup_get_needed_users ($courseid, $includemessages=false) {
         
-        global $CFG, $THEME;
+        global $CFG;
 
         $result = false;
 
@@ -158,7 +133,7 @@
             }
         }
 
-        //Now, add scales users (from site and course scales)
+        //Now, add scale users (from site and course scales)
         //Get users
         $scaleusers = get_records_sql("SELECT DISTINCT userid,userid
                                        FROM {$CFG->prefix}scale
@@ -172,6 +147,22 @@
                 }
             }
         }
+
+        //Now, add message users if necessary
+        if ($includemessages) {
+            include_once("$CFG->dirroot/message/lib.php");
+            //Get users
+            $messageusers = message_get_participants();
+            //Add message users to results
+            if ($messageusers) {
+                foreach ($messageusers as $messageuser) {
+                    //If id != 0
+                    if ($messageuser->id !=0) {
+                        $result[$messageuser->id]->id = $messageuser->id;
+                    }
+                }
+            }
+        }
     
         return $result;
 
@@ -371,6 +362,17 @@
         return $status;
     }
 
+    //Function to check and create the "group_files" dir to
+    //save all the user files we need from "groups" dir
+    function check_and_create_group_files_dir($backup_unique_code) {
+ 
+        global $CFG;
+
+            $status = check_dir_exists($CFG->dataroot."/temp/backup/".$backup_unique_code."/group_files",true);
+
+        return $status;
+    }
+
     //Function to check and create the "course_files" dir to
     //save all the course files we need from "CFG->datadir/course" dir
     function check_and_create_course_files_dir($backup_unique_code) {
@@ -495,6 +497,12 @@
             //Print the end
             fwrite ($bf,end_tag("MOD",3,true));
         }
+        //The metacourse in backup
+        if ($preferences->backup_metacourse == 1) {
+            fwrite ($bf,full_tag("METACOURSE",3,false,"true"));
+        } else {
+            fwrite ($bf,full_tag("METACOURSE",3,false,"false"));
+        }
         //The user in backup
         if ($preferences->backup_users == 1) {
             fwrite ($bf,full_tag("USERS",3,false,"course"));
@@ -521,6 +529,14 @@
         } else {
             fwrite ($bf,full_tag("COURSEFILES",3,false,"false"));
         }
+        //The messages in backup
+        if ($preferences->backup_messages == 1 && $preferences->backup_course == SITEID) {
+            fwrite ($bf,full_tag("MESSAGES",3,false,"true"));
+        } else {
+            fwrite ($bf,full_tag("MESSAGES",3,false,"false"));
+        }
+        //The mode of writing the block data
+        fwrite ($bf,full_tag('BLOCKFORMAT',3,false,'instances'));
 
         fwrite ($bf,end_tag("DETAILS",2,true));
 
@@ -564,7 +580,6 @@
             fwrite ($bf,full_tag("SUMMARY",3,false,$course->summary));
             fwrite ($bf,full_tag("FORMAT",3,false,$course->format));
             fwrite ($bf,full_tag("SHOWGRADES",3,false,$course->showgrades));
-            fwrite ($bf,full_tag("BLOCKINFO",3,false,blocks_get_block_names($course->blockinfo)));
             fwrite ($bf,full_tag("NEWSITEMS",3,false,$course->newsitems));
             fwrite ($bf,full_tag("TEACHER",3,false,$course->teacher));
             fwrite ($bf,full_tag("TEACHERS",3,false,$course->teachers));
@@ -580,12 +595,20 @@
             fwrite ($bf,full_tag("GROUPMODE",3,false,$course->groupmode));
             fwrite ($bf,full_tag("GROUPMODEFORCE",3,false,$course->groupmodeforce));
             fwrite ($bf,full_tag("LANG",3,false,$course->lang));
+            fwrite ($bf,full_tag("THEME",3,false,$course->theme));
             fwrite ($bf,full_tag("COST",3,false,$course->cost));
             fwrite ($bf,full_tag("MARKER",3,false,$course->marker));
             fwrite ($bf,full_tag("VISIBLE",3,false,$course->visible));
             fwrite ($bf,full_tag("HIDDENSECTIONS",3,false,$course->hiddensections));
             fwrite ($bf,full_tag("TIMECREATED",3,false,$course->timecreated));
-            $status = fwrite ($bf,full_tag("TIMEMODIFIED",3,false,$course->timemodified));
+            fwrite ($bf,full_tag("TIMEMODIFIED",3,false,$course->timemodified));
+            //If not selected, force metacourse to 0
+            if (!$preferences->backup_metacourse) {
+                $status = fwrite ($bf,full_tag("METACOURSE",3,false,'0'));
+            //else, export the field as is in DB
+            } else {
+                $status = fwrite ($bf,full_tag("METACOURSE",3,false,$course->metacourse));
+            }
             //Print header end
             fwrite ($bf,end_tag("HEADER",2,true));
         } else { 
@@ -605,6 +628,246 @@
 
     }
 
+    //Prints course's metacourse info (table course_meta)
+    function backup_course_metacourse ($bf,$preferences) {
+
+        global $CFG;
+
+        $status = true;
+
+        //Get info from meta
+        $parents = get_records_sql ("SELECT m.*, c.idnumber, c.shortname
+                                     FROM {$CFG->prefix}course_meta m,
+                                          {$CFG->prefix}course c
+                                          WHERE m.child_course = '$preferences->backup_course' AND
+                                                m.parent_course = c.id");
+        $childs =  get_records_sql ("SELECT m.*, c.idnumber, c.shortname
+                                     FROM {$CFG->prefix}course_meta m,
+                                          {$CFG->prefix}course c
+                                          WHERE m.parent_course = '$preferences->backup_course' AND
+                                                m.child_course = c.id");
+
+        if ($parents || $childs) {
+            //metacourse open tag
+            fwrite ($bf,start_tag("METACOURSE",2,true));
+            if ($parents) {
+                fwrite($bf, start_tag("PARENTS",3,true));
+                //Iterate over every parent    
+                foreach ($parents as $parent) {
+                    //Begin parent
+                    fwrite ($bf,start_tag("PARENT",4,true));
+                    fwrite ($bf,full_tag("ID",5,false,$parent->parent_course));
+                    fwrite ($bf,full_tag("IDNUMBER",5,false,$parent->idnumber));
+                    fwrite ($bf,full_tag("SHORTNAME",5,false,$parent->shortname));
+                    //End parent
+                    fwrite ($bf,end_tag("PARENT",4,true));
+                }
+                fwrite ($bf,end_tag("PARENTS",3,true));
+            }
+            if ($childs) {
+                fwrite($bf, start_tag("CHILDS",3,true));
+                //Iterate over every child    
+                foreach ($childs as $child) {
+                    //Begin parent
+                    fwrite ($bf,start_tag("CHILD",4,true));
+                    fwrite ($bf,full_tag("ID",5,false,$child->child_course));
+                    fwrite ($bf,full_tag("IDNUMBER",5,false,$child->idnumber));
+                    fwrite ($bf,full_tag("SHORTNAME",5,false,$child->shortname));
+                    //End parent
+                    fwrite ($bf,end_tag("CHILD",4,true));
+                }
+                fwrite ($bf,end_tag("CHILDS",3,true));
+            }
+            //metacourse close tag
+            $status = fwrite ($bf,end_tag("METACOURSE",3,true));
+        }
+
+        return $status;
+
+    }
+
+    //Prints course's messages info (tables message, message_read and message_contacts)
+    function backup_messages ($bf,$preferences) {
+
+        global $CFG;
+
+        $status = true;
+
+        //Get info from messages
+        $unreads = get_records ('message');
+        $reads   = get_records ('message_read');
+        $contacts= get_records ('message_contacts');
+
+        if ($unreads || $reads || $contacts) {
+            $counter = 0;
+            //message open tag
+            fwrite ($bf,start_tag("MESSAGES",2,true));
+            if ($unreads) {
+                //Iterate over every unread    
+                foreach ($unreads as $unread) {
+                    //start message
+                    fwrite($bf, start_tag("MESSAGE",3,true));
+                    fwrite ($bf,full_tag("ID",4,false,$unread->id));
+                    fwrite ($bf,full_tag("STATUS",4,false,"UNREAD"));
+                    fwrite ($bf,full_tag("USERIDFROM",4,false,$unread->useridfrom));
+                    fwrite ($bf,full_tag("USERIDTO",4,false,$unread->useridto));
+                    fwrite ($bf,full_tag("MESSAGE",4,false,$unread->message));
+                    fwrite ($bf,full_tag("FORMAT",4,false,$unread->format));
+                    fwrite ($bf,full_tag("TIMECREATED",4,false,$unread->timecreated));
+                    fwrite ($bf,full_tag("MESSAGETYPE",4,false,$unread->messagetype));
+                    //end message
+                    fwrite ($bf,end_tag("MESSAGE",3,true));
+
+                    //Do some output
+                    $counter++;
+                    if ($counter % 20 == 0) {
+                        echo ".";   
+                        if ($counter % 400 == 0) {
+                            echo "<br />";
+                        }
+                        backup_flush(300);
+                    }
+                }
+            }
+
+            if ($reads) {
+                //Iterate over every read    
+                foreach ($reads as $read) {
+                    //start message
+                    fwrite($bf, start_tag("MESSAGE",3,true));
+                    fwrite ($bf,full_tag("ID",4,false,$read->id));
+                    fwrite ($bf,full_tag("STATUS",4,false,"READ"));
+                    fwrite ($bf,full_tag("USERIDFROM",4,false,$read->useridfrom));
+                    fwrite ($bf,full_tag("USERIDTO",4,false,$read->useridto));
+                    fwrite ($bf,full_tag("MESSAGE",4,false,$read->message));
+                    fwrite ($bf,full_tag("FORMAT",4,false,$read->format));
+                    fwrite ($bf,full_tag("TIMECREATED",4,false,$read->timecreated));
+                    fwrite ($bf,full_tag("MESSAGETYPE",4,false,$read->messagetype));
+                    fwrite ($bf,full_tag("TIMEREAD",4,false,$read->timeread));
+                    fwrite ($bf,full_tag("MAILED",4,false,$read->mailed));
+                    //end message
+                    fwrite ($bf,end_tag("MESSAGE",3,true));
+
+                    //Do some output
+                    $counter++;
+                    if ($counter % 20 == 0) {
+                        echo ".";   
+                        if ($counter % 400 == 0) {
+                            echo "<br />";
+                        }
+                        backup_flush(300);
+                    }
+                }
+            }
+
+            if ($contacts) {
+                fwrite($bf, start_tag("CONTACTS",3,true));
+                //Iterate over every contact    
+                foreach ($contacts as $contact) {
+                    //start contact
+                    fwrite($bf, start_tag("CONTACT",4,true));
+                    fwrite ($bf,full_tag("ID",5,false,$contact->id));
+                    fwrite ($bf,full_tag("USERID",5,false,$contact->userid));
+                    fwrite ($bf,full_tag("CONTACTID",5,false,$contact->contactid));
+                    fwrite ($bf,full_tag("BLOCKED",5,false,$contact->blocked));
+                    //end contact
+                    fwrite ($bf,end_tag("CONTACT",4,true));
+
+                    //Do some output
+                    $counter++;
+                    if ($counter % 20 == 0) {
+                        echo ".";   
+                        if ($counter % 400 == 0) {
+                            echo "<br />";
+                        }
+                        backup_flush(300);
+                    }
+                }
+                fwrite($bf, end_tag("CONTACTS",3,true));
+            }
+            //messages close tag
+            $status = fwrite ($bf,end_tag("MESSAGES",2,true));
+        }
+
+        return $status;
+
+    }
+
+
+
+    //Prints course's blocks info (table block_instance)
+    function backup_course_blocks ($bf,$preferences) {
+
+        global $CFG;
+
+        $status = true;
+
+        // Read all of the block table
+        $blocks = blocks_get_record();
+
+        $pages = array();
+        $pages[] = page_create_object(PAGE_COURSE_VIEW, $preferences->backup_course);
+
+        // Let's see if we have to backup blocks from modules
+        $modulerecords = get_records_sql('SELECT name, id FROM '.$CFG->prefix.'modules');
+        
+        foreach($preferences->mods as $module) {
+            if(!$module->backup) {
+                continue;
+            }
+
+            $cmods = get_records_select('course_modules', 'course = '.$preferences->backup_course.' AND module = '.$modulerecords[$module->name]->id);
+            if(empty($cmods)) {
+                continue;
+            }
+
+            $pagetypes = page_import_types('mod/'.$module->name.'/');
+            if(empty($pagetypes)) {
+                continue;
+            }
+
+            foreach($pagetypes as $pagetype) {
+                foreach($cmods as $cmod) {
+                    $pages[] = page_create_object($pagetype, $cmod->instance);
+                }
+            }
+        }
+
+        //Blocks open tag
+        fwrite ($bf,start_tag('BLOCKS',2,true));
+
+        while($page = array_pop($pages)) {
+            if ($instances = blocks_get_by_page($page)) {
+                //Iterate over every block
+                foreach ($instances as $position) {
+                    foreach ($position as $instance) {
+                        //If we somehow have a block with an invalid id, skip it
+                        if(empty($blocks[$instance->blockid]->name)) {
+                            continue;
+                        }
+                        //Begin Block
+                        fwrite ($bf,start_tag('BLOCK',3,true));
+                        fwrite ($bf,full_tag('NAME',4,false,$blocks[$instance->blockid]->name));
+                        fwrite ($bf,full_tag('PAGEID',4,false,$instance->pageid));
+                        fwrite ($bf,full_tag('PAGETYPE',4,false,$instance->pagetype));
+                        fwrite ($bf,full_tag('POSITION',4,false,$instance->position));
+                        fwrite ($bf,full_tag('WEIGHT',4,false,$instance->weight));
+                        fwrite ($bf,full_tag('VISIBLE',4,false,$instance->visible));
+                        fwrite ($bf,full_tag('CONFIGDATA',4,false,$instance->configdata));
+                        //End Block
+                        fwrite ($bf,end_tag('BLOCK',3,true));
+                    }
+                }
+            }
+        }
+
+        //Blocks close tag
+        $status = fwrite ($bf,end_tag('BLOCKS',2,true));
+
+        return $status;
+
+    }
+
     //Prints course's sections info (table course_sections)
     function backup_course_sections ($bf,$preferences) {
 
@@ -724,7 +987,9 @@
                 //Output all user data
                 fwrite ($bf,full_tag("ID",4,false,$user_data->id));
                 fwrite ($bf,full_tag("AUTH",4,false,$user_data->auth));
+                fwrite ($bf,full_tag("GUID",4,false,$user_data->guid));
                 fwrite ($bf,full_tag("CONFIRMED",4,false,$user_data->confirmed));
+                fwrite ($bf,full_tag("POLICYAGREED",4,false,$user_data->policyagreed));
                 fwrite ($bf,full_tag("DELETED",4,false,$user_data->deleted));
                 fwrite ($bf,full_tag("USERNAME",4,false,$user_data->username));
                 fwrite ($bf,full_tag("PASSWORD",4,false,$user_data->password));
@@ -734,6 +999,10 @@
                 fwrite ($bf,full_tag("EMAIL",4,false,$user_data->email));
                 fwrite ($bf,full_tag("EMAILSTOP",4,false,$user_data->emailstop));
                 fwrite ($bf,full_tag("ICQ",4,false,$user_data->icq));
+                fwrite ($bf,full_tag("SKYPE",4,false,$user_data->skype));
+                fwrite ($bf,full_tag("YAHOO",4,false,$user_data->yahoo));
+                fwrite ($bf,full_tag("AIM",4,false,$user_data->aim));
+                fwrite ($bf,full_tag("MSN",4,false,$user_data->msn));
                 fwrite ($bf,full_tag("PHONE1",4,false,$user_data->phone1));
                 fwrite ($bf,full_tag("PHONE2",4,false,$user_data->phone2));
                 fwrite ($bf,full_tag("INSTITUTION",4,false,$user_data->institution));
@@ -742,6 +1011,7 @@
                 fwrite ($bf,full_tag("CITY",4,false,$user_data->city));
                 fwrite ($bf,full_tag("COUNTRY",4,false,$user_data->country));
                 fwrite ($bf,full_tag("LANG",4,false,$user_data->lang));
+                fwrite ($bf,full_tag("THEME",4,false,$user_data->theme));
                 fwrite ($bf,full_tag("TIMEZONE",4,false,$user_data->timezone));
                 fwrite ($bf,full_tag("FIRSTACCESS",4,false,$user_data->firstaccess));
                 fwrite ($bf,full_tag("LASTACCESS",4,false,$user_data->lastaccess));
@@ -757,6 +1027,7 @@
                 fwrite ($bf,full_tag("MAILDISPLAY",4,false,$user_data->maildisplay));
                 fwrite ($bf,full_tag("HTMLEDITOR",4,false,$user_data->htmleditor));
                 fwrite ($bf,full_tag("AUTOSUBSCRIBE",4,false,$user_data->autosubscribe));
+                fwrite ($bf,full_tag("TRACKFORUMS",4,false,$user_data->trackforums));
                 fwrite ($bf,full_tag("TIMEMODIFIED",4,false,$user_data->timemodified));
 
                 //Output every user role (with its associated info) 
@@ -806,6 +1077,7 @@
                         fwrite ($bf,full_tag("TIMEEND",6,false,$tea->timeend));
                         fwrite ($bf,full_tag("TIMEMODIFIED",6,false,$tea->timemodified));
                         fwrite ($bf,full_tag("TIMEACCESS",6,false,$tea->timeaccess));
+                        fwrite ($bf,full_tag("ENROL",6,false,$tea->enrol));
                         //Print ROLE end
                         fwrite ($bf,end_tag("ROLE",5,true));   
                     }
@@ -821,6 +1093,7 @@
                         fwrite ($bf,full_tag("TIMEEND",6,false,$stu->timeend));
                         fwrite ($bf,full_tag("TIME",6,false,$stu->time));
                         fwrite ($bf,full_tag("TIMEACCESS",6,false,$stu->timeaccess));
+                        fwrite ($bf,full_tag("ENROL",6,false,$stu->enrol));
                         //Print ROLE end
                         fwrite ($bf,end_tag("ROLE",5,true));   
                     }
@@ -860,7 +1133,7 @@
                 if ($counter % 10 == 0) {
                     echo ".";   
                     if ($counter % 200 == 0) {
-                        echo "<br>";
+                        echo "<br />";
                     }
                     backup_flush(300);
                 }
@@ -926,10 +1199,10 @@
                     }
                     //Do some output
                     $counter++;
-                    if ($counter % 10 == 0) {
+                    if ($counter % 20 == 0) {
                         echo ".";
-                        if ($counter % 200 == 0) {
-                            echo "<br>";
+                        if ($counter % 400 == 0) {
+                            echo "<br />";
                         }
                         backup_flush(300);
                     }
@@ -943,6 +1216,194 @@
         return $status;
     }
 
+    //Backup gradebook info
+    function backup_gradebook_info($bf,$preferences) {
+
+        global $CFG;
+
+        $status = true;
+
+        //Gradebook header
+        fwrite ($bf,start_tag("GRADEBOOK",2,true));
+
+        //Output grade_preferences
+        $grade_preferences = get_records("grade_preferences", "courseid", $preferences->backup_course);
+        if ($grade_preferences) {
+            //Begin grade_preferences tag
+            fwrite ($bf,start_tag("GRADE_PREFERENCES",3,true)); 
+            //Iterate for each preference
+            foreach ($grade_preferences as $grade_preference) {
+                //Begin grade_preference
+                fwrite ($bf,start_tag("GRADE_PREFERENCE",4,true)); 
+                //Output individual fields
+                fwrite ($bf,full_tag("ID",5,false,$grade_preference->id));
+                fwrite ($bf,full_tag("PREFERENCE",5,false,$grade_preference->preference));
+                fwrite ($bf,full_tag("VALUE",5,false,$grade_preference->value));
+                //End grade_preference
+                fwrite ($bf,end_tag("GRADE_PREFERENCE",4,true)); 
+            }
+            //End grade_preferences tag
+            $status = fwrite ($bf,end_tag("GRADE_PREFERENCES",3,true));
+        }
+
+        //Output grade_letter
+        $grade_letters = get_records("grade_letter", "courseid", $preferences->backup_course);
+        if ($grade_letters) {
+            //Begin grade_letters tag
+            fwrite ($bf,start_tag("GRADE_LETTERS",3,true)); 
+            //Iterate for each letter
+            foreach ($grade_letters as $grade_letter) {
+                //Begin grade_letter
+                fwrite ($bf,start_tag("GRADE_LETTER",4,true)); 
+                //Output individual fields
+                fwrite ($bf,full_tag("ID",5,false,$grade_letter->id));
+                fwrite ($bf,full_tag("LETTER",5,false,$grade_letter->letter));
+                fwrite ($bf,full_tag("GRADE_HIGH",5,false,$grade_letter->grade_high));
+                fwrite ($bf,full_tag("GRADE_LOW",5,false,$grade_letter->grade_low));
+                //End grade_letter
+                fwrite ($bf,end_tag("GRADE_LETTER",4,true)); 
+            }
+            //End grade_letters tag
+            $status = fwrite ($bf,end_tag("GRADE_LETTERS",3,true));
+        }
+
+        //Output grade_category
+        $grade_categories = get_records("grade_category", "courseid", $preferences->backup_course);
+        if ($grade_categories) {
+            //Begin grade_categories tag
+            fwrite ($bf,start_tag("GRADE_CATEGORIES",3,true)); 
+            //Iterate for each category
+            foreach ($grade_categories as $grade_category) {
+                //Begin grade_category
+                fwrite ($bf,start_tag("GRADE_CATEGORY",4,true)); 
+                //Output individual fields
+                fwrite ($bf,full_tag("ID",5,false,$grade_category->id));
+                fwrite ($bf,full_tag("NAME",5,false,$grade_category->name));
+                fwrite ($bf,full_tag("DROP_X_LOWEST",5,false,$grade_category->drop_x_lowest));
+                fwrite ($bf,full_tag("BONUS_POINTS",5,false,$grade_category->bonus_points));
+                fwrite ($bf,full_tag("HIDDEN",5,false,$grade_category->hidden));
+                fwrite ($bf,full_tag("WEIGHT",5,false,$grade_category->weight));
+
+                //Now backup grade_item (inside grade_category)
+                $status = backup_gradebook_item_info($bf,$preferences,$grade_category->id);
+
+                //End grade_category
+                fwrite ($bf,end_tag("GRADE_CATEGORY",4,true)); 
+            }
+            //End grade_categories tag
+            $status = fwrite ($bf,end_tag("GRADE_CATEGORIES",3,true));
+        }
+        //Gradebook footer
+        $status = fwrite ($bf,end_tag("GRADEBOOK",2,true));
+        return $status;
+    }
+
+    //Backup gradebook_item (called from backup_gradebook_info
+    function backup_gradebook_item_info($bf,$preferences,$gradecategoryid) {
+
+        global $CFG;
+
+        $status = true;
+
+        //Output grade_item (only for modules included in backup)
+        $grade_items = get_records_sql("SELECT *
+                                    FROM {$CFG->prefix}grade_item
+                                    WHERE courseid = $preferences->backup_course AND
+                                          category = $gradecategoryid");
+        //Filter items about modules not included in backup
+        $inc_grade_items = array();
+        if ($grade_items) {
+            foreach ($grade_items as $grade_item) {
+                //Get modulename
+                $rec_module = get_record("modules", "id", $grade_item->modid);
+                //If it exists and it's included in backup
+                if ($rec_module && $preferences->mods[$rec_module->name]->backup == 1) {
+                    //Set the name and add it
+                    $grade_item->module_name = $rec_module->name;
+                    $inc_grade_items[] = $grade_item;
+                } else {
+                    if ($CFG->debug > 7) {
+                        echo "skipping $grade_item->modid"."-"."$rec_module->name<br />";
+                    }
+                }
+            }
+        }
+        if ($inc_grade_items) {
+            //Begin grade_items tag
+            fwrite ($bf,start_tag("GRADE_ITEMS",5,true)); 
+            //Iterate for each item
+            foreach ($inc_grade_items as $grade_item) {
+                //Begin grade_item
+                fwrite ($bf,start_tag("GRADE_ITEM",6,true)); 
+                //Output individual fields
+                fwrite ($bf,full_tag("MODULE_NAME",7,false,$grade_item->module_name));
+                fwrite ($bf,full_tag("CMINSTANCE",7,false,$grade_item->cminstance));
+                fwrite ($bf,full_tag("SCALE_GRADE",7,false,$grade_item->scale_grade));
+                fwrite ($bf,full_tag("EXTRA_CREDIT",7,false,$grade_item->extra_credit));
+                fwrite ($bf,full_tag("SORT_ORDER",7,false,$grade_item->sort_order));
+ 
+                //Now backup grade_exceptions (inside grade_item)
+                $status = backup_gradebook_exceptions_info($bf,$preferences,$grade_item->id);
+
+                //End grade_item
+                fwrite ($bf,end_tag("GRADE_ITEM",6,true)); 
+            }
+            //End grade_items tag
+            $status = fwrite ($bf,end_tag("GRADE_ITEMS",5,true));
+        }
+
+        return $status;
+    }
+
+    //Backup gradebook_exceptions (called from backup_gradebook_item_info
+    function backup_gradebook_exceptions_info($bf,$preferences,$gradeitemid) {
+
+        global $CFG;
+
+        $status = true;
+
+        //Output grade_exceptions (only for users included in backup)
+        $grade_exceptions = get_records_sql("SELECT *
+                                             FROM {$CFG->prefix}grade_exceptions
+                                             WHERE courseid = $preferences->backup_course AND
+                                                   grade_itemid = $gradeitemid");
+        //Filter exceptions about users not included in backup
+        $inc_grade_exceptions = array();
+        if ($grade_exceptions) {
+            foreach ($grade_exceptions as $grade_exception) {
+                //Check if user has been included in backup
+                $rec_user = get_record ("backup_ids","backup_code",$preferences->backup_unique_code,
+                                        "table_name","user",
+                                        "old_id",$grade_exception->userid);
+                //If it's included in backup
+                if ($rec_user) {
+                    //Add it
+                    $inc_grade_exceptions[] = $grade_exception;
+                } else {
+                    if ($CFG->debug > 7) {
+                        echo "skipping $grade_exception->userid"."-user<br />";
+                    }
+                }
+            }
+        }
+        if ($inc_grade_exceptions) {
+            //Begin grade_exceptions tag
+            fwrite ($bf,start_tag("GRADE_EXCEPTIONS",7,true));
+            //Iterate for each exception
+            foreach ($inc_grade_exceptions as $grade_exception) {
+                //Begin grade_exception
+                fwrite ($bf,start_tag("GRADE_EXCEPTION",8,true));
+                //Output individual fields
+                fwrite ($bf,full_tag("USERID",9,false,$grade_exception->userid));
+                //End grade_exception
+                fwrite ($bf,end_tag("GRADE_EXCEPTION",8,true));
+            }
+            //End grade_exceptions tag
+            $status = fwrite ($bf,end_tag("GRADE_EXCEPTIONS",7,true));
+        }
+
+        return $status;
+    }
 
     //Backup scales info (common and course scales)
     function backup_scales_info($bf,$preferences) {
@@ -1022,6 +1483,7 @@
                 fwrite ($bf,full_tag("FORMAT",4,false,$event->format));
                 fwrite ($bf,full_tag("GROUPID",4,false,$event->groupid));
                 fwrite ($bf,full_tag("USERID",4,false,$event->userid));
+                fwrite ($bf,full_tag("REPEATID",4,false,$event->repeatid));
                 fwrite ($bf,full_tag("EVENTTYPE",4,false,$event->eventtype));
                 fwrite ($bf,full_tag("TIMESTART",4,false,$event->timestart));
                 fwrite ($bf,full_tag("TIMEDURATION",4,false,$event->timeduration));
@@ -1060,7 +1522,9 @@
                 fwrite ($bf,full_tag("COURSEID",4,false,$group->courseid));
                 fwrite ($bf,full_tag("NAME",4,false,$group->name));
                 fwrite ($bf,full_tag("DESCRIPTION",4,false,$group->description));
+                fwrite ($bf,full_tag("PASSWORD",4,false,$group->password));
                 fwrite ($bf,full_tag("LANG",4,false,$group->lang));
+                fwrite ($bf,full_tag("THEME",4,false,$group->theme));
                 fwrite ($bf,full_tag("PICTURE",4,false,$group->picture));
                 fwrite ($bf,full_tag("HIDEPICTURE",4,false,$group->hidepicture));
                 fwrite ($bf,full_tag("TIMECREATED",4,false,$group->timecreated));
@@ -1076,6 +1540,11 @@
             }
             //End groups tag
             $status = fwrite ($bf,end_tag("GROUPS",2,true));
+
+            //Now save group_files
+            if ($status && $status2) {
+                $status2 = backup_copy_group_files($preferences);
+            }
         }
         return ($status && $status2);
     }
@@ -1181,7 +1650,7 @@
         }
 
         if ($result != $content && $CFG->debug>7) {                                  //Debug
-            echo "<br><hr>".$content."<br>changed to<br>".$result."<hr><br>";        //Debug
+            echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';        //Debug
         }                                                                            //Debug
 
         return $result;
@@ -1221,6 +1690,43 @@
                 }
             }
         }
+
+        return $status;
+    }
+
+    //This function copies all the needed files under the "groups" directory to the "group_files"
+    //directory under temp/backup
+    function backup_copy_group_files ($preferences) {
+
+        global $CFG;
+
+        $status = true;
+
+        //First we check if "group_files" exists and create it as necessary
+        //in temp/backup/$backup_code  dir
+        $status = check_and_create_group_files_dir($preferences->backup_unique_code);
+ 
+        //Now iterate over directories under "groups" to check if that user must be 
+        //copied to backup
+        
+        $rootdir = $CFG->dataroot.'/groups';
+        //Check if directory exists
+        if (is_dir($rootdir)) {
+            $list = list_directories ($rootdir);
+            if ($list) {
+                //Iterate
+                foreach ($list as $dir) {
+                    //Look for dir like group in groups table
+                    $data = get_record ('groups', 'courseid', $preferences->backup_course,
+                                                  'id',$dir);
+                    //If exists, copy it
+                    if ($data) {
+                        $status = backup_copy_file($rootdir."/".$dir,
+                                       $CFG->dataroot."/temp/backup/".$preferences->backup_unique_code."/group_files/".$dir);
+                    }
+                }
+            }
+        }
         return $status;
     }
 
@@ -1310,9 +1816,9 @@
             //Define zip destination (course dir)
             $to_zip_file = $CFG->dataroot."/".$preferences->backup_course;
     
-            //echo "<p>From: ".$from_zip_file."<br>";                                              //Debug
+            //echo "<p>From: ".$from_zip_file."<br />";                                              //Debug
     
-            //echo "<p>Checking: ".$to_zip_file."<br>";                                          //Debug
+            //echo "<p>Checking: ".$to_zip_file."<br />";                                          //Debug
     
             //Checks course dir exists
             $status = check_dir_exists($to_zip_file,true);
@@ -1320,7 +1826,7 @@
             //Define zip destination (backup dir)
             $to_zip_file = $to_zip_file."/backupdata";
     
-            //echo "<p>Checking: ".$to_zip_file."<br>";                                          //Debug
+            //echo "<p>Checking: ".$to_zip_file."<br />";                                          //Debug
     
             //Checks backup dir exists
             $status = check_dir_exists($to_zip_file,true);
@@ -1329,7 +1835,7 @@
             $to_zip_file = $to_zip_file."/".$preferences->backup_name;
         }
 
-        //echo "<p>To: ".$to_zip_file."<br>";                                              //Debug
+        //echo "<p>To: ".$to_zip_file."<br />";                                              //Debug
 
         //Copy zip file
         if ($status) {
