@@ -1,4 +1,4 @@
-<?php // $Id: index.php,v 1.47.2.13 2005/02/08 18:01:44 defacer Exp $
+<?php // $Id: index.php,v 1.72.2.1 2005/07/12 19:26:59 skodak Exp $
 
 //  Manage all uploaded files in a course file area
 
@@ -7,8 +7,8 @@
 //  Must define:  USER, basedir, baseweb, html_header and html_footer
 //  USER is a persistent variable using sessions
 
-    require("../config.php");
-    require("mimetypes.php");
+    require('../config.php');
+    require($CFG->libdir.'/filelib.php');
 
     $id      = required_param('id', PARAM_INT);
     $file    = optional_param('file', '', PARAM_PATH);
@@ -49,7 +49,7 @@
     }
     
     function html_header($course, $wdir, $formfield=""){
-        global $CFG, $THEME, $ME, $choose;
+        global $CFG, $ME, $choose;
 
         if (! $site = get_site()) {
             error("Invalid site!");
@@ -94,13 +94,7 @@
 
             <?php
             $fullnav = str_replace('->', '&raquo;', "$course->shortname -> $fullnav");
-            echo '<table border="0" cellpadding="3" cellspacing="0" width="100%">';
-            echo '<tr>';
-            echo '<td bgcolor="'.$THEME->cellheading.'" class="navbar">';
-            echo '<font size="2"><b>'.$fullnav.'</b></font>';
-            echo '</td>';
-            echo '</tr>';
-            echo '</table>';
+            echo '<div id="nav-bar">'.$fullnav.'</div>';
 
             if ($course->id == $site->id) {
                 print_heading(get_string("publicsitefileswarning"), "center", 2);
@@ -123,7 +117,7 @@
         }
 
 
-        echo "<table border=0 align=center cellspacing=3 cellpadding=3 width=640>";
+        echo "<table border=\"0\" align=\"center\" cellspacing=\"3\" cellpadding=\"3\" width=\"640\">";
         echo "<tr>";
         echo "<td colspan=\"2\">";
 
@@ -502,18 +496,18 @@
                     notify($archive->errorInfo(true));
 
                 } else {
-                    echo "<table cellpadding=\"4\" cellspacing=\"2\" border=\"0\" width=\"640\">";
-                    echo "<tr><th align=\"left\">$strname</th><th align=\"right\">$strsize</th><th align=\"right\">$strmodified</th></tr>";
+                    echo "<table cellpadding=\"4\" cellspacing=\"2\" border=\"0\" width=\"640\" class=\"files\">";
+                    echo "<tr class=\"file\"><th align=\"left\" class=\"header name\">$strname</th><th align=\"right\" class=\"header size\">$strsize</th><th align=\"right\" class=\"header date\">$strmodified</th></tr>";
                     foreach ($list as $item) {
                         echo "<tr>";
-                        print_cell("left", $item['filename']);
+                        print_cell("left", $item['filename'], 'name');
                         if (! $item['folder']) {
-                            print_cell("right", display_size($item['size']));
+                            print_cell("right", display_size($item['size']), 'size');
                         } else {
                             echo "<td>&nbsp;</td>";
                         }
                         $filedate  = userdate($item['mtime'], get_string("strftimedatetime"));
-                        print_cell("right", $filedate);
+                        print_cell("right", $filedate, 'date');
                         echo "</tr>";
                     }
                     echo "</table>";
@@ -540,18 +534,18 @@
                 echo $file;
                 print_simple_box_end();
                 echo "<br />";
-                echo "<p align=center>".get_string("areyousuretorestorethisinfo")."</p>";
+                echo "<p align=\"center\">".get_string("areyousuretorestorethisinfo")."</p>";
                 $restore_path = "$CFG->wwwroot/backup/restore.php";
                 notice_yesno (get_string("areyousuretorestorethis"),
-                                $restore_path."?id=".$id."&file=".cleardoubleslashes($id.$wdir."/".$file),
-                                "index.php?id=$id&wdir=$wdir&action=cancel");
+                                $restore_path."?id=".$id."&amp;file=".cleardoubleslashes($id.$wdir."/".$file),
+                                "index.php?id=$id&amp;wdir=$wdir&amp;action=cancel");
             } else {
                 displaydir($wdir);
             }
             html_footer();
             break;
           
-        case "cancel";
+        case "cancel":
             clearfilelist();
 
         default:
@@ -564,37 +558,6 @@
 
 /// FILE FUNCTIONS ///////////////////////////////////////////////////////////
 
-function fulldelete($location) { 
-    if (is_dir($location)) {
-        $currdir = opendir($location);
-        while ($file = readdir($currdir)) { 
-            if ($file <> ".." && $file <> ".") {
-                $fullfile = $location."/".$file;
-                if (is_dir($fullfile)) { 
-                    if (!fulldelete($fullfile)) {
-                        return false;
-                    }
-                } else {
-                    if (!unlink($fullfile)) {
-                        return false;
-                    }
-                } 
-            }
-        } 
-        closedir($currdir);
-        if (! rmdir($location)) {
-            return false;
-        }
-
-    } else {
-        if (!unlink($location)) {
-            return false;
-        }
-    }
-    return true;
-}
-
-
 
 function setfilelist($VARS) {
     global $USER;
@@ -631,7 +594,7 @@ function printfilelist($filelist) {
             echo "<img src=\"$CFG->pixpath/f/folder.gif\" height=\"16\" width=\"16\" alt=\"\" /> $file<br />";
             $subfilelist = array();
             $currdir = opendir($basedir.$file);
-            while ($subfile = readdir($currdir)) { 
+            while (false !== ($subfile = readdir($currdir))) {
                 if ($subfile <> ".." && $subfile <> ".") {
                     $subfilelist[] = $file."/".$subfile;
                 }
@@ -646,12 +609,11 @@ function printfilelist($filelist) {
 }
 
 
-function print_cell($alignment="center", $text="&nbsp;") {
-    echo "<td align=\"$alignment\" nowrap=\"nowrap\">";
-    echo "<font size=\"-1\" face=\"Arial, Helvetica\">";
-    echo "$text";
-    echo "</font>";
-    echo "</td>\n";
+function print_cell($alignment='center', $text='&nbsp;', $class='') {
+    if ($class) {
+        $class = ' class="'.$class.'"';
+    }
+    echo '<td align="'.$alignment.'" nowrap="nowrap"'.$class.'>'.$text.'</td>';
 }
 
 function displaydir ($wdir) {
@@ -665,7 +627,7 @@ function displaydir ($wdir) {
     $fullpath = $basedir.$wdir;
 
     $directory = opendir($fullpath);             // Find all files
-    while ($file = readdir($directory)) {
+    while (false !== ($file = readdir($directory))) {
         if ($file == "." || $file == "..") {
             continue;
         }
@@ -700,13 +662,13 @@ function displaydir ($wdir) {
     echo "<form action=\"index.php\" method=\"post\" name=\"dirform\">";
     echo '<input type="hidden" name="choose" value="'.$choose.'">';
     echo "<hr width=\"640\" align=\"center\" noshade=\"noshade\" size=\"1\" />";
-    echo "<table border=\"0\" cellspacing=\"2\" cellpadding=\"2\" width=\"640\">";    
+    echo "<table border=\"0\" cellspacing=\"2\" cellpadding=\"2\" width=\"640\" class=\"files\">";    
     echo "<tr>";
     echo "<th width=\"5\"></th>";
-    echo "<th align=\"left\">$strname</th>";
-    echo "<th align=\"right\">$strsize</th>";
-    echo "<th align=\"right\">$strmodified</th>";
-    echo "<th align=\"right\">$straction</th>";
+    echo "<th align=\"left\" class=\"header name\">$strname</th>";
+    echo "<th align=\"right\" class=\"header size\">$strsize</th>";
+    echo "<th align=\"right\" class=\"header date\">$strmodified</th>";
+    echo "<th align=\"right\" class=\"header commands\">$straction</th>";
     echo "</tr>\n";
 
     if ($wdir == "/") {
@@ -721,31 +683,30 @@ function displaydir ($wdir) {
     if (!empty($dirlist)) {
         asort($dirlist);
         foreach ($dirlist as $dir) {
+            echo "<tr class=\"folder\">";
 
-            echo "<tr>";
-
-            if($dir == '..') {
+            if ($dir == '..') {
                 $fileurl = rawurlencode(dirname($wdir));
                 print_cell();
-                print_cell('left', '<a href="index.php?id='.$id.'&amp;wdir='.$fileurl.'"><img src="'.$CFG->pixpath.'/f/parent.gif" height="16" width="16" alt="'.get_string('parentfolder').'" /></a> <a href="index.php?id='.$id.'&amp;wdir='.$fileurl.'">'.get_string('parentfolder').'</a>');
+                print_cell('left', '<a href="index.php?id='.$id.'&amp;wdir='.$fileurl.'&amp;choose='.$choose.'"><img src="'.$CFG->pixpath.'/f/parent.gif" height="16" width="16" alt="'.get_string('parentfolder').'" /></a> <a href="index.php?id='.$id.'&amp;wdir='.$fileurl.'&amp;choose='.$choose.'">'.get_string('parentfolder').'</a>', 'name');
                 print_cell();
                 print_cell();
                 print_cell();
-            }
-            else {
+
+            } else {
                 $count++;
                 $filename = $fullpath."/".$dir;
                 $fileurl  = rawurlencode($wdir."/".$dir);
                 $filesafe = rawurlencode($dir);
                 $filesize = display_size(get_directory_size("$fullpath/$dir"));
                 $filedate = userdate(filemtime($filename), "%d %b %Y, %I:%M %p");
-                print_cell("center", "<input type=\"checkbox\" name=\"file$count\" value=\"$fileurl\" />");
-                print_cell("left", "<a href=\"index.php?id=$id&amp;wdir=$fileurl&amp;choose=$choose\"><img src=\"$CFG->pixpath/f/folder.gif\" height=\"16\" width=\"16\" border=\"0\" alt=\"Folder\" /></a> <a href=\"index.php?id=$id&amp;wdir=$fileurl&amp;choose=$choose\">".htmlspecialchars($dir)."</a>");
-                print_cell("right", "<b>$filesize</b>");
-                print_cell("right", $filedate);
-                print_cell("right", "<a href=\"index.php?id=$id&amp;wdir=$wdir&amp;file=$filesafe&amp;action=rename&amp;choose=$choose\">$strrename</a>");
+                print_cell("center", "<input type=\"checkbox\" name=\"file$count\" value=\"$fileurl\" />", 'checkbox');
+                print_cell("left", "<a href=\"index.php?id=$id&amp;wdir=$fileurl&amp;choose=$choose\"><img src=\"$CFG->pixpath/f/folder.gif\" height=\"16\" width=\"16\" border=\"0\" alt=\"Folder\" /></a> <a href=\"index.php?id=$id&amp;wdir=$fileurl&amp;choose=$choose\">".htmlspecialchars($dir)."</a>", 'name');
+                print_cell("right", $filesize, 'size');
+                print_cell("right", $filedate, 'date');
+                print_cell("right", "<a href=\"index.php?id=$id&amp;wdir=$wdir&amp;file=$filesafe&amp;action=rename&amp;choose=$choose\">$strrename</a>", 'commands');
             }
-
+    
             echo "</tr>";
         }
     }
@@ -770,10 +731,10 @@ function displaydir ($wdir) {
                 $selectfile = $fileurl;
             }
 
-            echo "<tr>";
+            echo "<tr class=\"file\">";
 
-            print_cell("center", "<input type=\"checkbox\" name=\"file$count\" value=\"$fileurl\" />");
-            echo "<td align=\"left\" nowrap=\"nowrap\">";
+            print_cell("center", "<input type=\"checkbox\" name=\"file$count\" value=\"$fileurl\" />", 'checkbox');
+            echo "<td align=\"left\" nowrap=\"nowrap\" class=\"name\">";
             if ($CFG->slasharguments) {
                 $ffurl = "/file.php/$id$fileurl";
             } else {
@@ -782,15 +743,15 @@ function displaydir ($wdir) {
             link_to_popup_window ($ffurl, "display", 
                                   "<img src=\"$CFG->pixpath/f/$icon\" height=\"16\" width=\"16\" border=\"0\" alt=\"File\" />", 
                                   480, 640);
-            echo "<font size=\"-1\" face=\"Arial, Helvetica\">";
+            echo '&nbsp;';
             link_to_popup_window ($ffurl, "display", 
                                   htmlspecialchars($file),
                                   480, 640);
-            echo "</font></td>";
+            echo "</td>";
 
             $file_size = filesize($filename);
-            print_cell("right", display_size($file_size));
-            print_cell("right", $filedate);
+            print_cell("right", display_size($file_size), 'size');
+            print_cell("right", $filedate, 'date');
 
             if ($choose) {
                 $edittext = "<b><a onMouseDown=\"return set_value('$selectfile')\" href=\"\">$strchoose</a></b>&nbsp;";
@@ -809,7 +770,7 @@ function displaydir ($wdir) {
                 }
             }
 
-            print_cell("right", "$edittext <a href=\"index.php?id=$id&amp;wdir=$wdir&amp;file=$filesafe&amp;action=rename&amp;choose=$choose\">$strrename</a>");
+            print_cell("right", "$edittext <a href=\"index.php?id=$id&amp;wdir=$wdir&amp;file=$filesafe&amp;action=rename&amp;choose=$choose\">$strrename</a>", 'commands');
     
             echo "</tr>";
         }
