@@ -2,13 +2,19 @@
       // lesson.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005020101)
 
 
-$string['accesscontrol'] = 'Access Control';
-$string['actionaftercorrectanswer'] = 'Action after Correct Answer';
+$string['accesscontrol'] = 'Access control';
+$string['actionaftercorrectanswer'] = 'Action after correct answer';
 $string['addabranchtable'] = 'Add a Branch Table';
 $string['addanendofbranch'] = 'Add an End of Branch';
 $string['addaquestionpage'] = 'Add a Question Page';
 $string['addcluster'] = 'Add a Cluster';
+$string['addedabranchtable'] = 'Added a Branch Table';
+$string['addedanendofbranch'] = 'Added an End of Branch';
+$string['addedaquestionpage'] = 'Added a Question Page';
+$string['addedcluster'] = 'Added a Cluster';
+$string['addedendofcluster'] = 'Added an End of Cluster';
 $string['addendofcluster'] = 'Add an End of Cluster';
+$string['and'] = 'AND';
 $string['answer'] = 'Answer';
 $string['answeredcorrectly'] = 'answered correctly.';
 $string['answersfornumerical'] = 'Answers for Numerical questions should be matched pairs of Minimum and Maximum values';
@@ -16,55 +22,61 @@ $string['arrangebuttonshorizontally'] = 'Arrange Branch buttons horizontally in
 $string['attempt'] = 'Attempt: $a';
 $string['attempts'] = 'Attempts';
 $string['available'] = 'Available from';
-$string['averagescore'] = 'Average Score';
-$string['averagetime'] = 'Average Time';
+$string['averagescore'] = 'Average score';
+$string['averagetime'] = 'Average time';
 $string['backtreeview'] = 'Back to Tree View';
 $string['branchtable'] = 'Branch Table';
 $string['cancel'] = 'Cancel';
-$string['canretake'] = '$a can Re-take';
-$string['casesensitive'] = 'Case Sensitive';
-$string['checkbranchtable'] = 'Check Branch Table';
+$string['canretake'] = '$a can re-take';
+$string['casesensitive'] = 'Case sensitive';
+$string['checkbranchtable'] = 'Check branch table';
 $string['checkedthisone'] = 'checked this one.';
 $string['checknavigation'] = 'Check navigation';
-$string['checkquestion'] = 'Check Question';
-$string['classstats'] = 'Class Statistics';
+$string['checkquestion'] = 'Check question';
+$string['classstats'] = 'Class statistics';
 $string['clicktopost'] = 'Click here to post your grade on the High Scores list.';
-$string['clusterjump'] = 'Unseen Question within a Cluster';
+$string['clusterjump'] = 'Unseen question within a cluster';
 $string['clustertitle'] = 'Cluster';
-$string['comments'] = 'Your Comments';
+$string['comments'] = 'Your comments';
 $string['commentswithname'] = '$a->firstname {$a->lastname}\'s comments';
 $string['completed'] = 'Completed';
+$string['completederror'] = 'Complete the lesson';
+$string['completethefollowingconditions'] = 'You must complete the following condition(s) in <b>$a</b> lesson before you can proceed.';
+$string['conditionsfordependency'] = 'Condition(s) for the dependency';
 $string['confirmdeletionofthispage'] = 'Confirm deletion of this page';
 $string['congratulations'] = 'Congratulations - end of lesson reached';
 $string['continue'] = 'Continue';
 $string['continuetoanswer'] = 'Continue to change answers.';
-$string['correctanswerjump'] = 'Correct Answer Jump';
-$string['correctanswerscore'] = 'Correct Answer Score';
-$string['correctresponse'] = 'Correct Response';
-$string['customscoring'] = 'Custom Scoring';
+$string['correctanswerjump'] = 'Correct answer jump';
+$string['correctanswerscore'] = 'Correct answer score';
+$string['correctresponse'] = 'Correct response';
+$string['customscoring'] = 'Custom scoring';
 $string['deadline'] = 'Deadline';
+$string['defaultessayresponse'] = 'Your essay will be graded by the course instructor.';
 $string['deleteattempts'] = 'Delete student attempts for this lesson (user id)';
+$string['deletedpage'] = 'Deleted page';
 $string['deleting'] = 'Deleting';
 $string['deletingpage'] = 'Deleting page: $a';
+$string['dependencyon'] = 'Dependent on';
 $string['description'] = 'Description';
-$string['detailedstats'] = 'Detailed Statistics';
+$string['detailedstats'] = 'Detailed statistics';
 $string['didnotanswerquestion'] = 'Did not answer this question.';
-$string['didnotreceivecredit'] = 'Did not Receive Credit';
-$string['displayhighscores'] = 'Display High Scores';
+$string['didnotreceivecredit'] = 'Did not receive credit';
+$string['displayhighscores'] = 'Display high scores';
 $string['displayinleftmenu'] = 'Display in left menu?';
-$string['displayleftmenu'] = 'Display Left Menu';
+$string['displayleftmenu'] = 'Display left menu';
 $string['displayofgrade'] = 'Display of grade (for students only)';
-$string['displayreview'] = 'Display Review Button';
+$string['displayreview'] = 'Display review button';
 $string['displayscorewithessays'] = 'You earned $a->score out of $a->tempmaxgrade for the automatically graded questions.<br>Your $a->essayquestions essay question(s) will be graded and added<br />into your final score at a later date.<br /><br />Your current grade without the essay question(s) is $a->score out of $a->grade';
-$string['displayscorewithoutessays'] = 'Your score is $a->score (Out of $a->grade).';
-$string['editlessonsettings'] = 'Edit This lesson\'s settings';
-$string['editpagecontent'] = 'Edit this page\'s contents';
+$string['displayscorewithoutessays'] = 'Your score is $a->score (out of $a->grade).';
+$string['editlessonsettings'] = 'Edit lesson settings';
+$string['editpagecontent'] = 'Edit page contents';
 $string['email'] = 'Email';
-$string['emailallgradedessays'] = 'Email ALL<br />Graded Essays';
-$string['emailgradedessays'] = 'Email Graded Essays';
-$string['emailsuccess'] = 'Email(s) Successful';
-$string['endofbranch'] = 'End of Branch';
-$string['endofclustertitle'] = 'End of Cluster';
+$string['emailallgradedessays'] = 'Email ALL<br />graded essays';
+$string['emailgradedessays'] = 'Email graded essays';
+$string['emailsuccess'] = 'Email(s) successful';
+$string['endofbranch'] = 'End of branch';
+$string['endofclustertitle'] = 'End of cluster';
 $string['endoflesson'] = 'End of lesson';
 $string['enteredthis'] = 'entered this.';
 $string['entername'] = 'Enter a nickname for the high scores list';
@@ -74,83 +86,92 @@ $string['eolstudentoutoftimenoanswers'] = 'You did not answer any questions.  Yo
 $string['essay'] = 'Essay';
 $string['essayemailsubject'] = 'Your grade for $a question';
 $string['essays'] = 'Essays';
-$string['essayscore'] = 'Essay Score';
+$string['essayscore'] = 'Essay score';
 $string['fileformat'] = 'File Format';
-$string['firstanswershould'] = 'First Answer should Jump to the \"Correct\" Page';
+$string['firstanswershould'] = 'First answer should jump to the \"Correct\" Page';
 $string['firstwrong'] = 'Unfortunately you cannot earn this one point, because your response was not correct.  Would you like to keep guessing, just for the sheer joy of learning (but for no point credit)?';
-$string['flowcontrol'] = 'Flow Control';
+$string['flowcontrol'] = 'Flow control';
 $string['general'] = 'General';
-$string['gobacktolesson'] = 'Go Back to Lesson';
+$string['gobacktolesson'] = 'Go back to lesson';
 $string['grade'] = 'Grade';
-$string['gradeessay'] = 'Grade Essay Questions';
+$string['gradebetterthan'] = 'Grade better than (&#37;)'; // &#37; = %
+$string['gradebetterthanerror'] = 'Earn a grade better than $a percent';
+$string['gradeessay'] = 'Grade essay questions ($a->notgradedcount not graded and $a->notsentcount not sent)';
 $string['gradeis'] = 'Grade is $a';
-$string['gradeoptions'] = 'Grade Options';
-$string['handlingofretakes'] = 'Handling of Re-takes';
+$string['gradeoptions'] = 'Grade options';
+$string['handlingofretakes'] = 'Handling of re-takes';
 $string['havenotgradedyet'] = 'Have not graded yet.';
 $string['here'] = 'here';
-$string['highscore'] = 'High Score';
-$string['hightime'] = 'High Time';
-$string['importquestions'] = 'Import Questions';
+$string['highscore'] = 'High score';
+$string['hightime'] = 'High time';
+$string['importppt'] = 'Import PowerPoint';
+$string['importquestions'] = 'Import questions';
+$string['insertedpage'] = 'Inserted page';
 $string['jump'] = 'Jump';
 $string['jumptsto'] = 'jumps to';
 $string['leftduringtimed'] = 'You have left during a timed lesson.<br />Please click on Continue to restart the lesson.';
 $string['leftduringtimednoretake'] = 'You have left during a timed lesson and you are<br />not allowed to retake or continue the lesson.';
-$string['lesson'] = '$a Lesson';
+$string['lesson'] = '$a lesson';
 $string['lessonclosed'] = 'This lesson closed on $a.';
+$string['lessoncloses'] = 'Lesson closes';
 $string['lessondefault'] = 'Use this lesson\'s settings as defaults';
-$string['lessonformating'] = 'Lesson Formating';
-$string['lessonmenu'] = 'Lesson Menu';
+$string['lessonformating'] = 'Lesson formating';
+$string['lessonmenu'] = 'Lesson menu';
 $string['lessonopen'] = 'This lesson will be open on $a.';
-$string['lessonstats'] = 'Lesson Statistics';
-$string['loginfail'] = 'Login Failed, please try again...';
-$string['lowscore'] = 'Low Score';
-$string['lowtime'] = 'Low Time';
-$string['mainmenu'] = 'Course Menu';
-$string['matchesanswer'] = 'Matches with Answer';
-$string['maxhighscores'] = 'Number of High Scores Displayed';
+$string['lessonopens'] = 'Lesson opens';
+$string['lessonstats'] = 'Lesson statistics';
+$string['loginfail'] = 'Login failed, please try again...';
+$string['lowscore'] = 'Low score';
+$string['lowtime'] = 'Low time';
+$string['mainmenu'] = 'Course menu';
+$string['matchesanswer'] = 'Matches with answer';
+$string['maxhighscores'] = 'Number of high scores displayed';
 $string['maximumnumberofanswersbranches'] = 'Maximum number of answers/branches';
-$string['maximumnumberofattempts'] = 'Maximum number of Attempts';
-$string['maxtime'] = 'Time Limit (minutes)';
+$string['maximumnumberofattempts'] = 'Maximum number of attempts';
+$string['maxtime'] = 'Time limit (minutes)';
 $string['maxtimewarning'] = 'You have $a minute(s) to finish the lesson.';
-$string['minimumnumberofquestions'] = 'Minimum number of Questions';
+$string['mediafile'] = 'Media File';
+$string['mediafilepopup'] = 'Click here to view this lesson\'s media file.';
+$string['minimumnumberofquestions'] = 'Minimum number of questions';
 $string['modattempts'] = 'Allow student review';
 $string['modattemptsnoteacher'] = 'Student review only works for students.';
 $string['modulename'] = 'Lesson';
 $string['modulenameplural'] = 'Lessons';
+$string['movedpage'] = 'Moved page';
 $string['movepagehere'] = 'Move page to here';
 $string['moving'] = 'Moving page: $a';
-$string['movingtonextpage'] = 'Moving to Next Page';
+$string['movingtonextpage'] = 'Moving to next page';
 $string['multianswer'] = 'Multianswer';
 $string['multipleanswer'] = 'Multiple Answer';
-$string['nameapproved'] = 'Name Approved';
+$string['nameapproved'] = 'Name approved';
 $string['namereject'] = 'Sorry, your name has been rejected by the filter.<br />Please try another name.';
 $string['nextpage'] = 'Next page';
 $string['noanswer'] = 'No answer given.  Please go back and submit an answer.';
-$string['noattemptrecordsfound'] = 'No Attempt Records Found: No Grade given';
+$string['noattemptrecordsfound'] = 'No attempt records found: no grade given';
 $string['nocommentyet'] = 'No comment yet.';
-$string['nohighscores'] = 'No High Scores';
+$string['nohighscores'] = 'No high scores';
 $string['nooneansweredcorrectly'] = 'No one answered correctly.';
 $string['nooneansweredthisquestion'] = 'No one answered this question.';
 $string['noonecheckedthis'] = 'No one checked this.';
 $string['nooneenteredthis'] = 'No one entered this.';
 $string['noretake'] = 'You are not allowed to retake this lesson.';
-$string['normal'] = 'Normal - follow Lesson Path';
-$string['notcompleted'] = 'Not Completed';
-$string['notdefined'] = 'Not Defined';
+$string['normal'] = 'Normal - follow lesson path';
+$string['notcompleted'] = 'Not completed';
+$string['notdefined'] = 'Not defined';
 $string['nothighscore'] = 'You did not make the top $a high scores list.';
-$string['notitle'] = 'No Title';
+$string['notitle'] = 'No title';
 $string['numberofcorrectanswers'] = 'Number of correct answers: $a';
-$string['numberofcorrectmatches'] = 'Number of Correct Matches: $a';
-$string['numberofpagestoshow'] = 'Number of Pages (Cards) to Show';
+$string['numberofcorrectmatches'] = 'Number of correct matches: $a';
+$string['numberofpagestoshow'] = 'Number of pages (cards) to show';
 $string['numberofpagesviewed'] = 'Number of pages viewed: $a';
-$string['ongoing'] = 'Display Ongoing Score';
+$string['ongoing'] = 'Display ongoing score';
 $string['ongoingcustom'] = 'You have earned $a->score point(s) out of $a->currenthigh point(s) thus far.';
 $string['ongoingnormal'] = 'You have answered $a->correct question(s) correctly out of $a->viewed question(s).';
 $string['or'] = 'OR';
 $string['ordered'] = 'Ordered';
 $string['other'] = 'Other';
 $string['outof'] = 'Out of $a';
-$string['outoftime'] = 'Out of Time';
+$string['outoftime'] = 'Out of time';
 $string['overview'] = 'Overview';
 $string['page'] = 'Page: $a';
 $string['pagecontents'] = 'Page contents';
@@ -158,31 +179,31 @@ $string['pages'] = 'Pages';
 $string['pagetitle'] = 'Page title';
 $string['password'] = 'Password';
 $string['passwordprotectedlesson'] = '$a is a password protected lesson.';
-$string['pleasecheckoneanswer'] = 'Please check one Answer';
-$string['pleasecheckoneormoreanswers'] = 'Please check one or more Answers';
-$string['pleaseenteryouranswerinthebox'] = 'Please enter your Answer in the Box';
-$string['pleasematchtheabovepairs'] = 'Please match the above Pairs';
-$string['pointsearned'] = 'Points Earned';
-$string['postsuccess'] = 'Post Successful';
-$string['practice'] = 'Practice Lesson';
-$string['previouspage'] = 'Previous Page';
+$string['pleasecheckoneanswer'] = 'Please check one answer';
+$string['pleasecheckoneormoreanswers'] = 'Please check one or more answers';
+$string['pleaseenteryouranswerinthebox'] = 'Please enter your answer in the Box';
+$string['pleasematchtheabovepairs'] = 'Please match the above pairs';
+$string['pointsearned'] = 'Points earned';
+$string['postsuccess'] = 'Post successful';
+$string['practice'] = 'Practice lesson';
+$string['previouspage'] = 'Previous page';
 $string['question'] = 'Question';
 $string['questionoption'] = 'Question ';
-$string['questiontype'] = 'Question Type';
-$string['randombranch'] = 'Random Branch Page';
-$string['randompageinbranch'] = 'Random Question within a Branch';
+$string['questiontype'] = 'Question type';
+$string['randombranch'] = 'Random branch page';
+$string['randompageinbranch'] = 'Random question within a branch';
 $string['rank'] = 'Rank';
 $string['reached'] = 'reached';
-$string['receivedcredit'] = 'Received Credit';
-$string['redisplaypage'] = 'Redisplay Page';
+$string['receivedcredit'] = 'Received credit';
+$string['redisplaypage'] = 'Redisplay page';
 $string['report'] = 'Report';
 $string['response'] = 'Response';
-$string['returnmainmenu'] = 'Return to Main Menu';
-$string['returntocourse'] = 'Return to the Course';
-$string['reviewlesson'] = 'Review Lesson';
+$string['returnmainmenu'] = 'Return to main menu';
+$string['returntocourse'] = 'Return to the course';
+$string['reviewlesson'] = 'Review lesson';
 $string['reviewquestionback'] = 'Yes, I\'d like to try again';
 $string['reviewquestioncontinue'] = 'No, I just want to go on to the next question';
-$string['sanitycheckfailed'] = 'Sanity Check Failed: This attempt has been deleted';
+$string['sanitycheckfailed'] = 'Sanity check failed: This attempt has been deleted';
 $string['savechanges'] = 'Save Changes';
 $string['savechangesandeol'] = 'Save all changes and go to the end of the lesson.';
 $string['savepage'] = 'Save page';
@@ -193,52 +214,58 @@ $string['showanunansweredpage'] = 'Show an unanswered Page';
 $string['showanunseenpage'] = 'Show an Unseen Page';
 $string['singleanswer'] = 'Single Answer';
 $string['slideshow'] = 'Slide Show';
-$string['slideshowbgcolor'] = 'Slide Show Background Color';
-$string['slideshowheight'] = 'Slide Show Height';
-$string['slideshowwidth'] = 'Slide Show Width';
-$string['startlesson'] = 'Start Lesson';
+$string['slideshowbgcolor'] = 'Slide show background color';
+$string['slideshowheight'] = 'Slide show height';
+$string['slideshowwidth'] = 'Slide show width';
+$string['startlesson'] = 'Start lesson';
 $string['studentattemptlesson'] = '$a->lastname, $a->firstname\'s attempt number $a->attempt';
 $string['studentname'] = '$a Name';
 $string['studentoneminwarning'] = 'Warning: You have 1 minute or less to finish the lesson.';
 $string['studentoutoftime'] = 'Attention: You ran out of time for this lesson. Your last answer does not count because it was answered after the time was up.  Please push the continue button to finish the lesson.';
 $string['studentresponse'] = '{$a}\'s response';
-$string['submitname'] = 'Submit Name';
+$string['submitname'] = 'Submit name';
 $string['teacherjumpwarning'] = 'An $a->cluster jump or an $a->unseen jump is being used in this lesson.  The Next Page jump will be used instead.  Login as a student to test these jumps.';
-$string['teacherongoingwarning'] = 'Ongoing Score is only displayed for student.  Login as a student to test Ongoing Score';
+$string['teacherongoingwarning'] = 'Ongoing score is only displayed for student.  Login as a student to test ongoing score';
 $string['teachertimerwarning'] = 'Timer only works for students.  Test the timer by loggin in as a student.';
-$string['thatsthecorrectanswer'] = 'That\'s the Correct Answer';
-$string['thatsthewronganswer'] = 'That\'s the Wrong Answer';
-$string['thefollowingpagesjumptothispage'] = 'The following Pages jump to this Page';
+$string['thatsthecorrectanswer'] = 'That\'s the correct answer';
+$string['thatsthewronganswer'] = 'That\'s the wrong answer';
+$string['thefollowingpagesjumptothispage'] = 'The following pages jump to this page';
 $string['thispage'] = 'This page';
 $string['timed'] = 'Timed';
-$string['timeremaining'] = 'Time Remaining';
+$string['timeremaining'] = 'Time remaining';
+$string['timespenterror'] = 'Spend at least $a minutes in the lesson';
+$string['timespentminutes'] = 'Time Spent (minutes)';
 $string['timetaken'] = 'Time taken';
 $string['topscorestitle'] = 'Top $a->maxhighscores scores for $a->name lesson.';
-$string['treeview'] = 'Tree View';
-$string['unseenpageinbranch'] = 'Unseen Question within a Branch';
-$string['updatefailed'] = 'Update Failed';
-$string['updatesuccess'] = 'Update Successful';
-$string['useeditor'] = 'Use Editor';
-$string['usemaximum'] = 'Use Maximum';
-$string['usemean'] = 'Use Mean';
-$string['usepassword'] = 'Password Protected Lesson';
-$string['viewallpages'] = 'View All Pages';
+$string['treeview'] = 'Tree view';
+$string['unseenpageinbranch'] = 'Unseen question within a branch';
+$string['updatedpage'] = 'Updated page';
+$string['updatefailed'] = 'Update failed';
+$string['updatesuccess'] = 'Update successful';
+$string['useeditor'] = 'Use editor';
+$string['usemaximum'] = 'Use maximum';
+$string['usemean'] = 'Use mean';
+$string['usepassword'] = 'Password protected lesson';
+$string['viewallpages'] = 'View all pages';
 $string['viewgrades'] = 'View grades';
-$string['viewhighscores'] = 'View High Scores list.';
-$string['viewlessonstats'] = 'View Lesson Statistics';
+$string['viewhighscores'] = 'View high scores list';
+$string['viewlessonstats'] = 'View lesson statistics ($a->users $a->usersname)';
 $string['waitpostscore'] = 'Please wait while posting high score...';
-$string['welldone'] = 'Well Done!';
+$string['welldone'] = 'Well done!';
 $string['whatdofirst'] = 'What would you like to do first?';
-$string['wronganswerjump'] = 'Wrong Answer Jump';
-$string['wronganswerscore'] = 'Wrong Answer Score';
-$string['wrongresponse'] = 'Wrong Response';
+$string['wronganswerjump'] = 'Wrong answer jump';
+$string['wronganswerscore'] = 'Wrong answer score';
+$string['wrongresponse'] = 'Wrong response';
 $string['youhavereceived'] = 'You have received $a->score out of $a->outof points for this essay question.';
 $string['youhaveseen'] = 'You have seen more than one page of this lesson already.<br />Do you want to start at the last page you saw?';
 $string['youmadehighscore'] = 'You made it on the top $a high scores list.';
-$string['youranswer'] = 'Your Answer';
-$string['yourcurrentgradeis'] = 'Your current Grade is $a';
+$string['youranswer'] = 'Your answer';
+$string['yourcurrentgradeis'] = 'Your current grade is $a';
 $string['yourgradeisnow'] = 'Your grade for the lesson has been changed to $a';
 $string['yourresponse'] = 'Your response';
 $string['youshouldview'] = 'You should view at least: $a';
 
+
+
+
 ?>
