@@ -3,6 +3,7 @@
 
 
 $string['action'] = 'Action';
+$string['actions'] = 'Actions';
 $string['active'] = 'Active';
 $string['activities'] = 'Activities';
 $string['activity'] = 'Activity';
@@ -10,6 +11,7 @@ $string['activityclipboard'] = 'Moving this activity: <b>$a</b>';
 $string['activityiscurrentlyhidden'] = 'Sorry, this activity is currently hidden';
 $string['activitymodule'] = 'Activity module';
 $string['activityreport'] = 'Activity report';
+$string['activityreports'] = 'Activity reports';
 $string['activityselect'] = 'Select this activity to be moved elsewhere';
 $string['activitysince'] = 'Activity since $a';
 $string['add'] = 'Add';
@@ -61,9 +63,11 @@ $string['administrator'] = 'Administrator';
 $string['administrators'] = 'Administrators';
 $string['administratorsall'] = 'All administrators';
 $string['administratorsandteachers'] = 'Administrators and teachers';
+$string['advanced'] = 'Advanced';
 $string['advancedfilter'] = 'Advanced search';
 $string['advancedsettings'] = 'Advanced settings';
 $string['again'] = 'again';
+$string['aimid'] = 'AIM ID';
 $string['all'] = 'All';
 $string['allactivities'] = 'All activities';
 $string['alldays'] = 'All days';
@@ -97,6 +101,7 @@ $string['autosubscribeyes'] = 'Yes: when I post, subscribe me to that forum';
 $string['availability'] = 'Availability';
 $string['availablecourses'] = 'Available Courses';
 $string['backup'] = 'Backup';
+$string['backupcancelled'] = 'Backup Cancelled';
 $string['backupcoursefileshelp'] = 'If enabled then course files will be included in automated backups';
 $string['backupdate'] = 'Backup Date';
 $string['backupdetails'] = 'Backup Details';
@@ -124,6 +129,8 @@ $string['blockdeleteconfirm'] = 'You are about to completely delete the block \'
 $string['blockdeletefiles'] = 'All data associated with the block \'$a->block\' has been deleted from the database.  To complete the deletion (and prevent the block re-installing itself), you should now delete this directory from your server: $a->directory';
 $string['blocks'] = 'Blocks';
 $string['blocksaddedit'] = 'Add/Edit Blocks';
+$string['blockseditoff'] = 'Blocks editing off';
+$string['blocksediton'] = 'Blocks editing on';
 $string['blocksetup'] = 'Setting up block tables';
 $string['blocksuccess'] = '$a tables have been set up correctly';
 $string['bycourseorder'] = 'By course order';
@@ -139,6 +146,7 @@ $string['changepassword'] = 'Change password';
 $string['changessaved'] = 'Changes saved';
 $string['checkingbackup'] = 'Checking backup';
 $string['checkingcourse'] = 'Checking course';
+$string['checkingforbbexport'] = 'Checking for BlackBoard export';
 $string['checkinginstances'] = 'Checking instances';
 $string['checkingsections'] = 'Checking sections';
 $string['checklanguage'] = 'Check language';
@@ -168,73 +176,14 @@ $string['clicktochange'] = 'Click to change';
 $string['closewindow'] = 'Close this window';
 $string['comparelanguage'] = 'Compare and edit current language';
 $string['complete'] = 'Complete';
-$string['configallowunenroll'] = 'If this is set \'Yes\', then students are allowed to unenroll themselves from courses whenever they like. Otherwise they are not allowed, and this process will be solely controlled by the teachers and administrators.';
-$string['configallusersaresitestudents'] = 'For activities on the front page of the site, should ALL users be considered as students?  If you answer \"Yes\", then any confirmed user account will be allowed to participate as a student in those activities.  If you answer \"No\", then only users who are already a participant in at least one course will be able to take part in those front page activities. Only admins and specially assigned teachers can act as teachers for these front page activities.';
-$string['configautologinguests'] = 'Should visitors be logged in as guests automatically when entering courses with guest access?';
-$string['configcachetext'] = 'For larger sites or sites that use text filters, this setting can really speed things up.  Copies of texts will be retained in their processed form for the time specified here.  Setting this too small may actually slow things down slightly,  but setting it too large may mean texts take too long to refresh (with new links, for example).';
-$string['configclamactlikevirus'] = 'Treat files like viruses';
-$string['configclamdonothing'] = 'Treat files as OK';
-$string['configclamfailureonupload'] = 'If you have configured clam to scan uploaded files, but it is configured incorrectly or fails to run for some unknown reason, how should it behave?  If you choose \'Treat files like viruses\', they\'ll be moved into the quarantine area, or deleted. If you choose \'Treat files as OK\', the files will be moved to the desination directory like normal. Either way, admins will be alerted that clam has failed.  If you choose \'Treat files like viruses\' and for some reason clam fails to run (usually because you have entered an invalid pathtoclam), ALL files that are uploaded will be moved to the given quarantine area, or deleted. Be careful with this setting.';
-$string['configcountry'] = 'If you set a country here, then this country will be selected by default on new user accounts.  To force users to choose a country, just leave this unset.';
-$string['configdbsessions'] = 'If enabled, this setting will use the database to store information about current sessions.  This is especially useful for large/busy sites or sites built on cluster of servers.  For most sites this should probably be left disabled so that the server disk is used instead.  Note that changing this setting now will log out all current users (including you).';
-$string['configdebug'] = 'If you turn this on, then PHP\'s error_reporting will be increased so that more warnings are printed.  This is only useful for developers.';
-$string['configdeleteunconfirmed'] = 'If you are using email authentication, this is the period within which a response will be accepted from users.  After this period, old unconfirmed accounts are deleted.';
-$string['configdigestmailtime'] = 'People who choose to have emails sent to them in digest form will be emailed the digest daily. This setting controls which time of day the daily mail will be sent (the next cron that runs after this hour will send it).';
-$string['configdisplayloginfailures'] = 'This will display information to selected users about previous failed logins.';
-$string['configenablerssfeeds'] = 'This switch will enable RSS feeds from across the site.  To actually see any change you will need to enable RSS feeds in the individual modules too - go to the Modules settings under Admin Configuration.';
-$string['configenablerssfeedsdisabled'] = ' It is not available because RSS feeds are disabled in all the Site. To enable them, go to the Variables settings under Admin Configuration.';
-$string['configerrorlevel'] = 'Choose the amount of PHP warnings that you want to be displayed.  Normal is usually the best choice.';
-$string['configextendedusernamechars'] = 'Enable this setting to allow students to use any characters in their usernames (note this does not affect their actual names).  The default is \"false\" which restricts usernames to be alphanumeric characters only';
-$string['configfilteruploadedfiles'] = 'Enabling this setting will cause Moodle to process all uploaded HTML and text files with the filters before displaying them.';
-$string['configforcelogin'] = 'Normally, the front page of the site and the course listings (but not courses) can be read by people without logging in to the site.  If you want to force people to log in before they do ANYTHING on the site, then you should enable this setting.';
-$string['configforceloginforprofiles'] = 'Enable this setting to force people to login as a real (non-guest) account before being allowed to see the user profile pages.  By default this is disabled (\"false\") so that prospective students can read about the teachers of each course, but this also means that web search engines can see them.';
-$string['configframename'] = 'If you are embedding Moodle within a web frame, then put the name of this frame here.  Otherwise this value should remain as \'_top\'';
-$string['configfullnamedisplay'] = 'This defines how names are shown when they are displayed in full. For most mono-lingual sites the most efficient setting is the default \"Given names + Surname\", but you may choose to hide surnames altogether, or to leave it up to the current language pack to decide (some languages have different conventions).';
-$string['configgdversion'] = 'Indicate the version of GD that is installed.  The version shown by default is the one that has been auto-detected.  Don\'t change this unless you really know what you\'re doing.';
-$string['confightmleditor'] = 'Choose whether or not to allow use of the embedded HTML text editor. Even if you choose allow, this editor will only appear when the user is using a compatible web browser.  Users can also choose not to use it.';
-$string['configidnumber'] = 'This option specifies whether (a) Users are not be asked for an ID number at all, (b) Users are asked for an ID number but can leave it blank or (c) Users are asked for an ID Number and cannot leave it blank. If given the User\'s ID number is displayed in their Profile.';
-$string['configintro'] = 'On this page you can specify a number of configuration variables that help make Moodle work properly on your server.  Don\'t worry too much about it - the defaults will usually work fine and you can always come back to this page later and change these settings.';
-$string['configintroadmin'] = 'On this page you should configure your main administrator account which will have complete control over the site. Make sure you give it a secure username and password as well as a valid email address.  You can create more admin accounts later on.';
-$string['configintrosite'] = 'This page allows you to configure the front page and name of this new site.  You can come back here later to change these settings any time using the \'Site Settings\' link on the home page.';
-$string['configlang'] = 'Choose a default language for the whole site.  Users can override this setting later.';
-$string['configlangdir'] = 'Most languages are printed left-to-right, but some, like Arabic and Hebrew, are printed right-to-left.';
-$string['configlanglist'] = 'Leave this blank to allow users to choose from any language you have in this installation of Moodle.  However, you can shorten the language menu by entering a comma-separated list of language codes that you want.  For example:  en,es_es,fr,it';
-$string['configlangmenu'] = 'Choose whether or not you want to display the general-purpose language menu on the home page, login page etc.  This does not affect the user\'s ability to set the preferred language in their own profile.';
-$string['configlocale'] = 'Choose a sitewide locale - this will affect the format and language of dates. You need to have this locale data installed on your operating system.  (eg en_US or es_ES).  If you don\'t know what to choose leave it blank.';
-$string['configloginhttps'] = 'Turning this on will make Moodle use a secure https connection just for the login page (providing a secure login), and then afterwards revert back to the normal http URL for general speed.  CAUTION: this setting REQUIRES https to be specifically enabled on the web server - if it is not then YOU COULD LOCK YOURSELF OUT OF YOUR SITE.';
-$string['configloglifetime'] = 'This specifies the length of time you want to keep logs about user activity.  Logs that are older than this age are automatically deleted.  It is best to keep logs as long as possible, in case you need them, but if you have a very busy server and are experiencing performance problems, then you may want to lower the log lifetime.';
-$string['configlongtimenosee'] = 'If students haven\'t logged in for a very long time, then they are automatically unsubscribed from courses.  This parameter specifies that time limit.';
-$string['configmaxbytes'] = 'This specifies a maximum size that uploaded files can be throughout the whole site.  This setting is limited by the PHP setting upload_max_filesize and the Apache setting LimitRequestBody.  In turn, maxbytes limits the range of sizes that can be chosen at course level or module level.';
-$string['configmaxeditingtime'] = 'This specifies the amount of time people have to re-edit forum postings, journal feedback etc.  Usually 30 minutes is a good value.';
-$string['configmessaging'] = 'Should the messaging system between site users be enabled?';
-$string['confignoreplyaddress'] = 'Emails are sometimes sent out on behalf of a user (eg forum posts). The email address you specify here will be used as the \"From\" address in those cases when the recipients should not be able to reply directly to the user (eg when a user chooses to keep their address private).';
-$string['confignotifyloginfailures'] = 'If login failures have been recorded, email notifications can be sent out.  Who should see these notifications?';
-$string['confignotifyloginthreshold'] = 'If notifications about failed logins are active, how many failed login attempts by one user or one IP address is it worth notifying about?';
-$string['configopentogoogle'] = 'If you enable this setting, then Google will be allowed to enter your site as a Guest.  In addition, people coming in to your site via a Google search will automatically be logged in as a Guest.  Note that this only provides transparent access to courses that already allow guest access.';
-$string['configpathtoclam'] = 'Path to clam AV.  Probably something like /usr/bin/clamscan or /usr/bin/clamdscan. You need this in order for clam AV to run.';
-$string['configproxyhost'] = 'If this <b>server</b> needs to use a proxy computer (eg a firewall) to access the Internet, then provide the proxy hostname and port here.  Otherwise leave it blank.';
-$string['configquarantinedir'] = 'If you want clam AV to move infected files to a quarantine directory, enter it here. It must be writable by the webserver.  If you leave this blank, or if you enter a directory that doesn\'t exit or isn\'t writable, infected files will be deleted.  Do not include a trailing slash.';
-$string['configrunclamonupload'] = 'Run clam AV on file upload? You will need a correct path in pathtoclam for this to work.  (Clam AV is a free virus scanner that you can get from http://www.clamav.net/)';
-$string['configsecureforms'] = 'Moodle can use an additional level of security when accepting data from web forms. If this is enabled, then the browser\'s HTTP_REFERER variable is checked against the current form address.  In a very few cases this can cause problems if the user is using a firewall (eg Zonealarm) configured to strip HTTP_REFERER from their web traffic.  Symptoms are getting \'stuck\' on a form. If your users are having problems with the login page (for example) you might want to disable this setting, although it might leave your site more open to brute-force password attacks.  If in doubt, leave this set to \'Yes\'.';
-$string['configsessioncookie'] = 'This setting customises the name of the cookie used for Moodle sessions.  This is optional, and only useful to avoid cookies being confused when there is more than one copy of Moodle running within the same web site.';
-$string['configsessiontimeout'] = 'If people logged in to this site are idle for a long time (without loading pages) then they are automatically logged out (their session is ended).  This variable specifies how long this time should be.';
-$string['configshowsiteparticipantslist'] = 'All of these site students and site teachers will be listed on the site participants list. Who shall be allowed to see this site participants list?';
-$string['configsitepolicy'] = 'If you have a site policy that all users must see and agree to before using this site, then specify the URL to it here, otherwise leave this field blank.  The URL can point to anywhere - one convenient place would be a file in the site files.  eg http://yoursite/file.php/1/policy.html';
-$string['configslasharguments'] = 'Files (images, uploads etc) are provided via a script using \'slash arguments\' (the second option here). This method allows files to be more easily cached in web browsers, proxy servers etc.  Unfortunately, some PHP servers don\'t allow this method, so if you have trouble viewing uploaded files or images (eg user pictures), set this variable to the first option';
-$string['configsmtphosts'] = 'Give the full name of one or more local SMTP servers that Moodle should use to send mail (eg \'mail.a.com\' or \'mail.a.com;mail.b.com\'). If you leave it blank, Moodle will use the PHP default method of sending mail.';
-$string['configsmtpuser'] = 'If you have specified an SMTP server above, and the server requires authentication, then enter the username and password here.';
-$string['configteacherassignteachers'] = 'Should ordinary teachers be allowed to assign other teachers within courses they teach?  If \'No\', then only course creators and admins can assign teachers.';
-$string['configtimezone'] = 'You can set the default timezone here.  This is the only the DEFAULT timezone for displaying dates - each user can override this by setting their own in their profile. \"Server time\" here will make Moodle default to the server\'s operating system setting, but \"Server time\" in the user profile will make the user default to this timezone setting.';
-$string['configunzip'] = 'Indicate the location of your unzip program (Unix only, optional).  If specified, this will be used to unpack zip archives on the server.  If you leave this blank, then Moodle will use internal routines.';
+$string['completereport'] = 'Complete report';
 $string['configuration'] = 'Configuration';
-$string['configvariables'] = 'Variables';
-$string['configwarning'] = 'Be careful modifying these settings - strange values could cause problems.';
-$string['configzip'] = 'Indicate the location of your zip program (Unix only, optional).  If specified, this will be used to create zip archives on the server.  If you leave this blank, then Moodle will use internal routines.';
 $string['confirm'] = 'Confirm';
 $string['confirmed'] = 'Your registration has been confirmed';
 $string['confirmednot'] = 'Your registration has not yet been confirmed!';
 $string['continue'] = 'Continue';
 $string['continuetocourse'] = 'Click here to enter your course';
+$string['convertingwikitomarkdown'] = 'Converting Wiki to Markdown';
 $string['cookiesenabled'] = 'Cookies must be enabled in your browser';
 $string['cookiesnotenabled'] = 'Unfortunately, cookies are currently not enabled in your browser';
 $string['copy'] = 'copy';
@@ -244,6 +193,7 @@ $string['copyingzipfile'] = 'Copying zip file';
 $string['copyrightnotice'] = 'Copyright notice';
 $string['cost'] = 'Cost';
 $string['costdefault'] = 'Default cost';
+$string['counteditems'] = '$a->count $a->items';
 $string['country'] = 'Country';
 $string['course'] = 'Course';
 $string['courseavailable'] = 'This course is available to students';
@@ -260,6 +210,7 @@ $string['courserestore'] = 'Course restore';
 $string['courses'] = 'Courses';
 $string['coursestaught'] = 'Courses I have taught';
 $string['coursescategory'] = 'Courses in the same category';
+$string['coursehidden'] = 'This course is currently unavailable to students';
 $string['courseupdates'] = 'Course updates';
 $string['courseuploadlimit'] = 'Course upload limit';
 $string['create'] = 'Create';
@@ -271,8 +222,10 @@ $string['creatingblocks'] = 'Creating blocks';
 $string['creatingcategoriesandquestions'] = 'Creating categories and questions';
 $string['creatingcoursemodules'] = 'Creating course modules';
 $string['creatingevents'] = 'Creating events';
+$string['creatinggradebook'] = 'Creating gradebook';
 $string['creatinggroups'] = 'Creating groups';
 $string['creatinglogentries'] = 'Creating log entries';
+$string['creatingmessagesinfo'] = 'Creating messages info';
 $string['creatingmetacoursedata'] = 'Creating metacourse info';
 $string['creatingnewcourse'] = 'Creating new course';
 $string['creatingscales'] = 'Creating scales';
@@ -301,6 +254,7 @@ $string['datemostrecentlast'] = 'Date - most recent last';
 $string['day'] = 'day';
 $string['days'] = 'days';
 $string['decodinginternallinks'] = 'Decoding internal links';
+$string['default'] = 'Default';
 $string['defaultcoursefullname'] = 'Course Fullname 101';
 $string['defaultcourseshortname'] = 'CF101';
 $string['defaultcoursestudent'] = 'Student';
@@ -344,9 +298,10 @@ $string['doyouagree'] = 'Have you read these conditions and understood them?';
 $string['duplicate'] = 'Duplicate';
 $string['duplicatinga'] = 'Duplicating: $a';
 $string['duplicatingain'] = 'Duplicating $a->what in $a->in';
-$string['edhelpbgcolor'] = 'Define editarea\'s background-color.<br />Valid values are for example: #ffffff or white';
-$string['edhelpcleanword'] = 'This setting enables or disables Word specific format filtering.';
-$string['edhelpenablespelling'] = 'Enable or disable spellchecking. When enabled, <strong>aspell</strong> must be installed on the server. The second value is the <strong>default dictionary</strong>. This value will be used if aspell doesn\'t have dictionary for users own language.';
+$string['edhelpaspellpath'] = 'To use spell-checking within the editor, you MUST have <strong>aspell 0.50</strong> or later installed on your server, and you must specify the correct path to access the aspell binary.  On Unix/Linux systems, this path is usually <strong>/usr/bin/aspell</strong>, but it might be something else.';
+$string['edhelpbgcolor'] = 'Define the edit area\'s background color.<br />Valid values are, for example: #FFFFFF or white';
+$string['edhelpcleanword'] = 'This setting enables or disables Word-specific format filtering.';
+$string['edhelpenablespelling'] = 'Enable or disable spell-checking. When enabled, <strong>aspell</strong> must be installed on the server. The second value is the <strong>default dictionary</strong>. This value will be used if aspell doesn\'t have dictionary for users own language.';
 $string['edhelpfontfamily'] = 'The font-family property is a list of font family names and/or generic family names. Family names must be seperated with comma.';
 $string['edhelpfontlist'] = 'Define the fonts used on editors dropdown menu.';
 $string['edhelpfontsize'] = 'The default font-size sets the size of a font. <br />Valid values are for example: medium, large, smaller, larger, 10pt, 11px.';
@@ -441,8 +396,9 @@ $string['enable'] = 'Enable';
 $string['encryptedcode'] = 'Encrypted code';
 $string['enrolledincourse'] = 'Enrolled in course \"$a\"';
 $string['enrolledincoursenot'] = 'Not enrolled in course \"$a\"';
-$string['enrollfirst'] = 'You have to enroll in one of the courses before you can use the site activities';
-$string['enrolmentconfirmation'] = 'You are about to enroll yourself as a member of this course.<br />Are you sure you wish to do this?';
+$string['enrollfirst'] = 'You have to enrol in one of the courses before you can use the site activities';
+$string['enrolme'] = 'Enrol me in this course';
+$string['enrolmentconfirmation'] = 'You are about to enrol yourself as a member of this course.<br />Are you sure you wish to do this?';
 $string['enrolmentkey'] = 'Enrolment key';
 $string['enrolmentkeyfrom'] = 'This course requires an \'enrolment key\' - a one-time<br />
 password that you should have received from $a';
@@ -453,7 +409,7 @@ $string['enrolmentnewuser'] = '$a->user has enrolled in course \"$a->course\"';
 $string['enrolmentnointernal'] = 'Manual enrolments are currently not enabled';
 $string['enrolmentnotyet'] = 'Sorry, you can not access this course until <br /> $a';
 $string['enrolments'] = 'Enrolments';
-$string['enrolperiod'] = 'Enrolment period';
+$string['enrolperiod'] = 'Enrolment duration';
 $string['entercourse'] = 'Click to enter this course';
 $string['enteremailaddress'] = 'Enter in your email address to reset your
    password and have the new password sent to you via email.';
@@ -492,11 +448,14 @@ $string['forcelanguage'] = 'Force language';
 $string['forceno'] = 'Do not force';
 $string['forcepasswordchange'] = 'Force password change';
 $string['forcepasswordchangehelp'] = 'Prompt user to change it on their next login';
+$string['forcetheme'] = 'Force theme';
 $string['forgotten'] = 'Forgotten your username or password?';
+$string['forgotaccount'] = 'Lost password?';
 $string['format'] = 'Format';
 $string['formathtml'] = 'HTML format';
 $string['formatmarkdown'] = 'Markdown format';
 $string['formatplain'] = 'Plain text format';
+$string['formatscorm'] = 'SCORM format';
 $string['formatsocial'] = 'Social format';
 $string['formattext'] = 'Moodle auto-format';
 $string['formattexttype'] = 'Formatting';
@@ -509,6 +468,7 @@ $string['frontpagecourselist'] = 'Show a list of courses';
 $string['frontpagedescription'] = 'Front Page Description';
 $string['frontpageformat'] = 'Front page format';
 $string['frontpagenews'] = 'Show news items';
+$string['frontpagetopiconly'] = 'Show arbitrary HTML or activities (topic section)';
 $string['fulllistofcourses'] = 'All courses';
 $string['fullname'] = 'Full name';
 $string['fullnamedisplay'] = '$a->firstname $a->lastname';
@@ -520,7 +480,7 @@ $string['gd2'] = 'GD 2.x is installed';
 $string['gdneed'] = 'GD must be installed to see this graph';
 $string['gdnot'] = 'GD is not installed';
 $string['go'] = 'Go';
-$string['gpl'] = 'Copyright (C) 1999-2004  Martin Dougiamas  (http://dougiamas.com)
+$string['gpl'] = 'Copyright (C) 1999-2005  Martin Dougiamas  (http://moodle.com)
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -540,8 +500,10 @@ $string['groupadd'] = 'Add new group';
 $string['groupaddusers'] = 'Add selected to group';
 $string['groupfor'] = 'for group';
 $string['groupinfo'] = 'Info about selected group';
+$string['groupinfoedit'] = 'Edit group settings';
 $string['groupinfomembers'] = 'Info about selected members';
 $string['groupinfopeople'] = 'Info about selected people';
+$string['groupmembers'] = 'Group members';
 $string['groupmemberssee'] = 'See group members';
 $string['groupmembersselected'] = 'Members of selected group';
 $string['groupmode'] = 'Group mode';
@@ -562,6 +524,11 @@ $string['guestsnotallowed'] = 'Sorry, \'$a\' does not allow guests to enter.';
 $string['guestsyes'] = 'Allow guests without the key';
 $string['guestuser'] = 'Guest User';
 $string['guestuserinfo'] = 'This user is a special user that allows read-only access to some courses.';
+$string['healthcenter'] = 'Health Center';
+$string['healthproblemsdetected'] = 'Health Problems Detected!';
+$string['healthproblemsolution'] = 'Health Problem Solution';
+$string['healthreturntomain'] = 'Continue';
+$string['healthsolution'] = 'Solution';
 $string['help'] = 'Help';
 $string['helpemoticons'] = 'Use emoticons';
 $string['helpformatting'] = 'About formatting text';
@@ -634,6 +601,7 @@ $string['latestlanguagepack'] = 'Check for latest language pack on moodle.org';
 $string['latestnews'] = 'Latest News';
 $string['leavetokeep'] = 'Leave blank to keep current password';
 $string['license'] = 'GPL License';
+$string['liketologin'] = 'Would you like to log in now with a full user account?';
 $string['list'] = 'List';
 $string['listfiles'] = 'List of files in $a';
 $string['listofallpeople'] = 'List of all people';
@@ -641,6 +609,7 @@ $string['livelogs'] = 'Live logs from the past hour';
 $string['locale'] = 'en';
 $string['location'] = 'Location';
 $string['loggedinas'] = 'You are logged in as $a ';
+$string['loggedinasguest'] = 'You are currently using guest access';
 $string['loggedinnot'] = 'You are not logged in.';
 $string['login'] = 'Login';
 $string['login_failure_logs'] = 'Login failure logs';
@@ -751,10 +720,12 @@ $string['moveright'] = 'Move right';
 $string['moveselectedcoursesto'] = 'Move selected courses to...';
 $string['movetoanotherfolder'] = 'Move to another folder';
 $string['moveup'] = 'Move up';
+$string['msnid'] = 'MSN ID';
 $string['mustchangepassword'] = 'The new password must be different than the current one';
 $string['mustconfirm'] = 'You need to confirm your login';
 $string['mycourses'] = 'My courses';
 $string['name'] = 'Name';
+$string['namescorm'] = 'SCORM';
 $string['namesocial'] = 'section';
 $string['nametopics'] = 'topic';
 $string['nameweeks'] = 'week';
@@ -795,6 +766,7 @@ $string['no'] = 'No';
 $string['nobody'] = 'Nobody';
 $string['nocoursesfound'] = 'No courses were found with the words \'$a\'';
 $string['nocoursesyet'] = 'No courses in this category';
+$string['nodstpresets'] = 'The administrator has not enabled Daylight Savings Time support.';
 $string['noexistingadmins'] = 'No existing admins, this is a serious error and you should never have seen this message.';
 $string['noexistingcreators'] = 'No existing creators';
 $string['noexistingstudents'] = 'No existing students';
@@ -811,19 +783,21 @@ $string['nopotentialcreators'] = 'No potential course creators';
 $string['nopotentialstudents'] = 'No potential students';
 $string['nopotentialteachers'] = 'No potential teachers';
 $string['noreplyname'] = 'Do not reply to this email';
-$string['noreplybouncemessage'] = 'You have replied to a no-reply email address. If you were atttempting to reply to a forum post, please instead reply using the $a forums. '."\n\n".'Following is the content of your email:'."\n\n";
+$string['noreplybouncemessage'] = 'You have replied to a no-reply email address. If you were attempting to reply to a forum post, please instead reply using the $a forums. '."\n\n".'Following is the content of your email:'."\n\n";
 $string['noreplybouncesubject'] = '$a - bounced email.';
 $string['noresults'] = 'No results';
 $string['normal'] = 'Normal';
 $string['normalfilter'] = 'Normal search';
 $string['nostudentsfound'] = 'No $a found';
 $string['nostudentsyet'] = 'No students enrolled in this course yet';
+$string['nostudentsingroup'] = 'There are no students in this group yet';
 $string['nosuchemail'] = 'No such email address';
 $string['notavailable'] = 'Not available';
 $string['noteachersyet'] = 'No teachers in this course yet';
 $string['notenrolled'] = '$a is not enrolled in this course.';
-$string['noteuserschangednonetocourse'] = 'Note: course users need to be restored when restoring user data. This setting has been changed for you.';
+$string['noteuserschangednonetocourse'] = 'Note: course users need to be restored when restoring user data (in activities, files or messages). This setting has been changed for you.';
 $string['nothingnew'] = 'Nothing new since your last login';
+$string['nothingtodisplay'] = 'Nothing to display';
 $string['noticenewerbackup'] = 'This backup file has been created with Moodle $a->backuprelease ($a->backupversion) and it\'s newer than your currently installed Moodle $a->serverrelease ($a->serverversion). This could cause some inconsistencies because backwards compatibility of backup files cannot be guaranteed.';
 $string['notifyloginfailuresmessage'] = '$a->time, IP: $a->ip, User: $a->info';
 $string['notifyloginfailuresmessageend'] = 'You can view these logs at $a/course/log.php?id=1&chooselog=1&modid=site_errors.';
@@ -831,6 +805,7 @@ $string['notifyloginfailuresmessagestart'] = 'Here is a list of failed login att
 $string['notifyloginfailuressubject'] = '$a :: Failed logins notification';
 $string['notincluded'] = 'Not included';
 $string['notingroup'] = 'Sorry, but you need to be part of a group to see this activity.';
+$string['notpublic'] = 'Not public!';
 $string['nousersmatching'] = 'No users matching \'$a\' were found';
 $string['nousersyet'] = 'There are no users yet';
 $string['now'] = 'now';
@@ -850,6 +825,7 @@ $string['optional'] = 'optional';
 $string['order'] = 'Order';
 $string['other'] = 'Other';
 $string['outline'] = 'Outline';
+$string['outlinereport'] = 'Outline report';
 $string['page'] = 'Page';
 $string['pageheaderconfigablock'] = 'Configuring a block in %%fullname%%';
 $string['parentcoursenotfound'] = 'Parent course not found!';
@@ -885,9 +861,11 @@ $string['potentialcreators'] = 'Potential course creators';
 $string['potentialstudents'] = 'Potential students';
 $string['potentialteachers'] = 'Potential teachers';
 $string['preferredlanguage'] = 'Preferred language';
+$string['preferredtheme'] = 'Preferred theme';
 $string['preview'] = 'Preview';
 $string['previeworchoose'] = 'Preview or choose a theme';
 $string['previous'] = 'Previous';
+$string['profile'] = 'Profile';
 $string['publicdirectory'] = 'Public directory';
 $string['publicdirectory0'] = 'Please do not publish this site';
 $string['publicdirectory1'] = 'Publish the site name only';
@@ -898,8 +876,12 @@ $string['readinginfofrombackup'] = 'Reading info from backup';
 $string['readme'] = 'README';
 $string['recentactivity'] = 'Recent Activity';
 $string['recentactivityreport'] = 'Full report of recent activity...';
+$string['recreatedcategory'] = 'Recreated category $a';
 $string['refreshingevents'] = 'Refreshing events';
 $string['registration'] = 'Moodle Registration';
+$string['registrationcontact'] = 'Contact from the public';
+$string['registrationcontactno'] = 'No, I do not want a contact form in the site listing';
+$string['registrationcontactyes'] = 'Yes, provide a form for prospective Moodlers to contact me';
 $string['registrationemail'] = 'Email notifications';
 $string['registrationinfo'] = '<p>This page allows you to register your Moodle site with moodle.org.  Registration is free.
 The main benefit of registering is that you will be added to a low-volume mailing list
@@ -924,7 +906,7 @@ $string['requirespayment'] = 'This course requires payment for access';
 $string['resortcoursesbyname'] = 'Re-sort courses by name';
 $string['resources'] = 'Resources';
 $string['restore'] = 'Restore';
-$string['restorecancelled'] = 'Restore cancelled';
+$string['restorecancelled'] = 'Restore canceled';
 $string['restorecoursenow'] = 'Restore this course now!';
 $string['restorefinished'] = 'Restore completed successfully';
 $string['restoreto'] = 'Restore to';
@@ -946,6 +928,7 @@ $string['scalesstandard'] = 'Standard scales';
 $string['scalestip'] = 'To create custom scales, use the \'Scales...\' link in your course administration menu.';
 $string['schedule'] = 'Schedule';
 $string['scheduledbackupstatus'] = 'Scheduled backup status';
+$string['screenshot'] = 'Screenshot';
 $string['search'] = 'Search';
 $string['searchagain'] = 'Search again';
 $string['searchcourses'] = 'Search courses';
@@ -976,6 +959,7 @@ $string['showgrades'] = 'Show grades';
 $string['showlistofcourses'] = 'Show list of courses';
 $string['showonlytopic'] = 'Show only topic $a';
 $string['showonlyweek'] = 'Show only week $a';
+$string['showperpage'] = 'Show $a per page';
 $string['showrecent'] = 'Show recent activity';
 $string['showreports'] = 'Show activity reports';
 $string['showsettings'] = 'Show settings';
@@ -996,17 +980,19 @@ $string['sitesettings'] = 'Site settings';
 $string['siteteachers'] = 'Site teachers';
 $string['size'] = 'Size';
 $string['sizeb'] = 'bytes';
-$string['sizegb'] = 'Gb';
-$string['sizekb'] = 'Kb';
-$string['sizemb'] = 'Mb';
+$string['sizegb'] = 'GB';
+$string['sizekb'] = 'KB';
+$string['sizemb'] = 'MB';
+$string['skypeid'] = 'Skype ID';
 $string['socialheadline'] = 'Social forum - latest topics';
 $string['someallowguest'] = 'Some courses may allow guest access';
 $string['someerrorswerefound'] = 'Some information was missing or incorrect. Look below for details.';
 $string['sortby'] = 'Sort by';
 $string['specifyname'] = 'You must specify a name.';
 $string['startdate'] = 'Course start date';
-$string['startsignup'] = 'Start now by creating a new account!';
+$string['startsignup'] = 'Create new account';
 $string['state'] = 'State/Province';
+$string['statistics'] = 'Statistics';
 $string['status'] = 'Status';
 $string['strftimedate'] = '%%d %%B %%Y';
 $string['strftimedateshort'] = '%%d %%B';
@@ -1046,14 +1032,19 @@ $string['timezone'] = 'Timezone';
 $string['to'] = 'To';
 $string['today'] = 'Today';
 $string['todaylogs'] = 'Today\'s logs';
+$string['toeveryone'] = 'to everyone';
 $string['toomanybounces'] = 'That email address has had too many bounces. You <b>must</b> change it to continue.';
 $string['toomanytoshow'] = 'There are too many users to show.';
+$string['toonly'] = 'to $a only';
 $string['top'] = 'Top';
 $string['topic'] = 'Topic';
 $string['topichide'] = 'Hide this topic from $a';
 $string['topicoutline'] = 'Topic outline';
 $string['topicshow'] = 'Show this topic to $a';
 $string['total'] = 'Total';
+$string['trackforums'] = 'Forum tracking';
+$string['trackforumsno'] = 'No: don\'t keep track of posts I have seen';
+$string['trackforumsyes'] = 'Yes: highlight new posts for me';
 $string['trysearching'] = 'Try searching instead.';
 $string['turneditingoff'] = 'Turn editing off';
 $string['turneditingon'] = 'Turn editing on';
@@ -1118,6 +1109,7 @@ $string['usethiscourse'] = 'Use this course';
 $string['usingexistingcourse'] = 'Using existing course';
 $string['version'] = 'Version';
 $string['view'] = 'View';
+$string['viewsolution'] = 'view solution';
 $string['virusfound'] = 'Attention administrator! Clam AV has found a virus in a file uploaded by $a->user for the course $a->course. Here is the output of clamscan:';
 $string['virusfoundlater'] = 'A file you uploaded on $a->date with the filename $a->filename for the course $a->course has since been found to contain a virus.  Here is a summary of what has happened to your file:
 
@@ -1137,6 +1129,7 @@ $a->action';
 $string['virusfoundsubject'] = '$a: Virus found!';
 $string['virusfounduser'] = 'The file you have uploaded, $a->filename, has been scanned by a virus checker and found to be infected! Your file upload was NOT successful.';
 $string['virusplaceholder'] = 'This file that has been uploaded was found to contain a virus and has been moved or delted and the user notified.';
+$string['visibletostudents'] = 'Visible to $a';
 $string['webpage'] = 'Web page';
 $string['week'] = 'Week';
 $string['weekhide'] = 'Hide this week from $a';
@@ -1165,13 +1158,16 @@ $string['writingcategoriesandquestions'] = 'Writing categories and questions';
 $string['writingcoursedata'] = 'Writing course data';
 $string['writingeventsinfo'] = 'Writing events info';
 $string['writinggeneralinfo'] = 'Writing general info';
+$string['writinggradebookinfo'] = 'Writing gradebook info';
 $string['writinggroupsinfo'] = 'Writing groups info';
 $string['writingheader'] = 'Writing header';
 $string['writingloginfo'] = 'Writing logs info';
+$string['writingmessagesinfo'] = 'Writing messages info';
 $string['writingmoduleinfo'] = 'Writing modules info';
 $string['writingscalesinfo'] = 'Writing scales info';
 $string['writinguserinfo'] = 'Writing users info';
 $string['wrongpassword'] = 'Incorrect password for this username';
+$string['yahooid'] = 'Yahoo ID';
 $string['yes'] = 'Yes';
 $string['youareabouttocreatezip'] = 'You are about to create a zip file containing';
 $string['youaregoingtorestorefrom'] = 'You are about to start the restore process for';
