@@ -1,36 +1,48 @@
-<?php // $Id$ 
-      // quiz.php - created with Moodle 1.4 development (2004080300)
+<?PHP // $Id$ 
+      // quiz.php - created with Moodle 1.5 ALPHA (2005050600)
 
 
 $string['acceptederror'] = 'Accepted error';
+$string['action'] = 'Action';
+$string['adaptive'] = 'Adaptive mode';
 $string['addcategory'] = 'Add category';
 $string['addingquestions'] = 'This side of the page is where you manage your database of questions.  Questions are stored in categories to help you keep them organised, and can be used by any quiz in your course or even other courses if you choose to \'publish\' them. <br /><br />After you select or create a question category you will be able to create or edit questions.  You can select any of these questions to add to your quiz over on the other side of this page.';
 $string['addquestions'] = 'Add questions';
 $string['addquestionstoquiz'] = 'Add questions to current quiz';
-$string['addrandom1'] = ' Add ';
+$string['addrandom'] = 'Add $a random questions';
+$string['addrandom1'] = ' << Add ';
 $string['addrandom2'] = 'random questions ';
 $string['addselectedtoquiz'] = 'Add selected to quiz';
+$string['addtoquiz'] = 'Add to quiz';
+$string['affectedstudents'] = 'Affected $a';
 $string['aiken'] = 'Aiken format';
+$string['allattempts'] = 'All attempts';
 $string['allinone'] = 'Unlimited';
 $string['allowreview'] = 'Allow review';
 $string['alreadysubmitted'] = 'It is likely that you have already submitted this attempt';
 $string['alternativeunits'] = 'Alternative Units';
 $string['alwaysavailable'] = 'Always available';
+$string['analysisoptions'] = 'Analysis options';
+$string['analysistitle'] = 'Item Analysis Table';
 $string['answer'] = 'Answer';
 $string['answerhowmany'] = 'One or multiple answers?';
+$string['answers'] = 'Answers';
 $string['answersingleno'] = 'Multiple answers allowed';
 $string['answersingleyes'] = 'One answer only';
 $string['answerswithacceptederrormarginmustbenumeric'] = 'Answers with accepted error must be numeric';
 $string['answertoolong'] = 'Answer too long after line $a (255 char. max)';
 $string['aon'] = 'AON format';
 $string['attempt'] = 'Attempt $a';
+$string['attemptduration'] = 'Time taken';
+$string['attemptedon'] = 'Attempted on';
 $string['attemptfirst'] = 'First attempt';
 $string['attemptincomplete'] = 'That attempt (by $a) is not yet completed.';
 $string['attemptlast'] = 'Last attempt';
 $string['attemptquiznow'] = 'Attempt quiz now';
 $string['attempts'] = 'Attempts';
 $string['attemptsallowed'] = 'Attempts allowed';
-$string['attemptsexist'] = 'This quiz has already been attempted';
+$string['attemptselection'] = 'Select which attempts to analyze per user: ';
+$string['attemptsexist'] = 'This quiz has already been attempted.<br />You can no longer add or remove questions.';
 $string['attemptsunlimited'] = 'Unlimited attempts';
 $string['back'] = 'Back to preview question';
 $string['backtoquiz'] = 'Back to quiz editing';
@@ -43,18 +55,29 @@ $string['casesensitive'] = 'Case sensitivity';
 $string['caseyes'] = 'Yes, case must match';
 $string['categories'] = 'Categories';
 $string['category'] = 'Category';
+$string['categoryadded'] = 'The category \'$a\' was added';
+$string['categorydeleted'] = 'The category \'$a\' was deleted';
 $string['categoryinfo'] = 'Category info';
-$string['categorymove'] = 'The category \'$a->name\' contains $a->count questions.  Please choose another category to move them to.';
+$string['categorymove'] = 'The category \'$a->name\' contains $a->count questions (some of them may be old, hidden, questions that are still in use in some existing quizzes).<br />Please choose another category to move them to.';
 $string['categorymoveto'] = 'Move them to this category';
+$string['categorynoedit'] = 'You do not have editing privileges in the category \'$a\'.';
 $string['categoryupdated'] = 'The category was successfully updated';
 $string['checkanswer'] = 'Check';
 $string['choice'] = 'Choice';
 $string['choices'] = 'Available choices';
 $string['choosedatasetproperties'] = 'Choose dataset properties';
-$string['close'] = 'Close preview';
+$string['close'] = 'Close window';
+$string['closepreview'] = 'Close preview';
+$string['closereview'] = 'Close review';
+$string['completedon'] = 'Completed on';
+$string['confirmclose'] = 'You are about to close this attempt. Once you close the attempt you will no longer be able to change your answers.';
+$string['confirmserverdelete'] = 'Are you sure you want to remove the server <b>$a</b> from the list?';
 $string['confirmstartattempt'] = 'The Quiz has a time limit. Are you sure that you wish to start?';
+$string['containercategorycreated'] = 'This category has been created to store all the original categories moved to site level due to the causes specified below.';
+$string['continueattemptquiz'] = 'Continue the last attempt';
 $string['copyingfrom'] = 'Creating a copy of the question \'$a\'';
 $string['copyingquestion'] = 'Copying a question';
+$string['correct'] = 'Correct';
 $string['correctanswer'] = 'Correct answer';
 $string['correctanswerformula'] = 'Correct Answer Formula';
 $string['correctanswerlength'] = 'Significant Figures';
@@ -73,17 +96,25 @@ $string['datasetdefinitions'] = 'Reusable dataset definitions for category $a';
 $string['datasetnumber'] = 'Number';
 $string['daysavailable'] = 'Days available';
 $string['decimalformat'] = 'decimals';
+$string['decimalpoints'] = 'Decimal points';
 $string['decimals'] = ' with $a ';
 $string['default'] = 'Default';
 $string['defaultgrade'] = 'Default question grade';
 $string['defaultinfo'] = 'The default category for questions.';
 $string['deleteattemptcheck'] = 'Are you absolutely sure you want to completely delete these attempts?';
 $string['deletequestioncheck'] = 'Are you absolutely sure you want to delete \'$a\'?';
+$string['deletequestionscheck'] = 'Are you absolutely sure you want to delete the following questions? <div>$a</div>';
+$string['deleteselected'] = 'Delete selected';
 $string['description'] = 'Description';
 $string['discrimination'] = 'Discrim. Index';
+$string['displayoptions'] = 'Display options';
+$string['download'] = 'Click to download the exported category file';
+$string['downloadextra'] = '(file is also stored in the course files in the /quiz folder)';
+$string['duplicateresponse'] = 'This submission has been ignored because you gave an equivalent answer earlier.';
 $string['eachattemptbuildsonthelast'] = 'Each attempt builds on the last';
 $string['editcategories'] = 'Edit categories';
 $string['editcategory'] = 'Edit category';
+$string['editcatquestions'] = 'Edit category questions';
 $string['editdatasets'] = 'Edit the datasets';
 $string['editingcalculated'] = 'Editing a Calculated question';
 $string['editingdescription'] = 'Editing a Description';
@@ -95,10 +126,20 @@ $string['editingquestion'] = 'Editing a question';
 $string['editingquiz'] = 'Editing quiz';
 $string['editingrandom'] = 'Editing a Random Question';
 $string['editingrandomsamatch'] = 'Editing a Random Short-Answer Matching question';
+$string['editingrqp'] = '$a: editing a question';
 $string['editingshortanswer'] = 'Editing a Short-Answer question';
 $string['editingtruefalse'] = 'Editing a True/False question';
 $string['editquestions'] = 'Edit questions';
+$string['editquiz'] = 'Edit Quiz';
+$string['errormissingquestion'] = 'Error: The system is missing the question with id $a';
+$string['errornotnumbers'] = 'Error - answers must be numeric';
 $string['errorsdetected'] = '$a error(s) detected';
+$string['event1'] = 'Autosave';
+$string['event2'] = 'Save';
+$string['event3'] = 'Grade';
+$string['event5'] = 'Validate';
+$string['event6'] = 'Close';
+$string['examview'] = 'Examview';
 $string['existingcategory1'] = 'a literal from an already existing set of literals that are also used by other questions in this category';
 $string['existingcategory2'] = 'a file from an already existing set of files that are also used by other questions in this category';
 $string['existingcategory3'] = 'a link from an already existing set of links that are also used by other questions in this category';
@@ -110,9 +151,11 @@ $string['false'] = 'False';
 $string['feedback'] = 'Feedback';
 $string['file'] = 'File';
 $string['fileformat'] = 'File format';
+$string['fillcorrect'] = 'Fill with correct';
 $string['filloutoneanswer'] = 'You must fill out at least one possible answer.  Answers left blank will not be used.';
 $string['filloutthreequestions'] = 'You must fill out at least three questions.  Questions left blank will not be used.';
 $string['fillouttwochoices'] = 'You must fill out at least two choices.  Choices left blank will not be used.';
+$string['finishattempt'] = 'Submit all and finish';
 $string['forceregeneration'] = 'force regeneration';
 $string['fractionsaddwrong'] = 'The positive grades you have chosen do not add up to 100%%<br />Instead, they add up to $a%%<br />Do you want to go back and fix this question?';
 $string['fractionsnomax'] = 'One of the answers should be 100%%, so that it is<br />possible to get a full grade for this question.<br />Do you want to go back and fix this question?';
@@ -124,29 +167,50 @@ $string['functiontakestwoargs'] = 'The function $a must have exactly two argumen
 $string['generatevalue'] = 'Generate a new value between';
 $string['geometric'] = 'Geometric';
 $string['gift'] = 'GIFT format';
+$string['grade'] = 'Grade';
 $string['gradeaverage'] = 'Average grade';
 $string['gradehighest'] = 'Highest grade';
 $string['grademethod'] = 'Grading method';
+$string['gradingdetails'] = 'Marks for this submission: $a->raw/$a->max. ';
+$string['gradingdetailsadjustment'] = 'With previous penalties this gives <strong>$a->cur/$a->max</strong>. ';
+$string['gradingdetailspenalty'] = 'This submission attracted a penalty of $a. ';
+$string['gradingdetailszeropenalty'] = 'You were not penalized for this submission. ';
 $string['guestsno'] = 'Sorry, guests can not see or attempt quizzes';
+$string['hotpot'] = 'Hot Potatoes format';
 $string['illegalformulasyntax'] = 'Illegal formula syntax starting with \'$a\'';
 $string['imagedisplay'] = 'Image to display';
 $string['imagemissing'] = 'Image not available at line $a. The filename will be ignored';
+$string['importmax10error'] = 'There is an error in the question. You may not have more than ten answers';
+$string['importminerror'] = 'There is an error in the question. There are not enough answers for this question type';
 $string['importquestions'] = 'Import questions from file';
+$string['incorrect'] = 'Incorrect';
 $string['indivresp'] = 'Responses of Individuals to Each Item';
+$string['info'] = 'Info';
 $string['introduction'] = 'Introduction';
+$string['invalidsource'] = 'The source is not accepted as valid.';
+$string['invalidsourcetype'] = 'Invalid source type.';
 $string['itemanal'] = 'Item Response Analysis';
 $string['itemdefinition'] = 'Definition';
+$string['itemsource'] = 'Item Source';
+$string['itemsourceformat'] = 'Item Source Format';
+$string['itemtypes'] = 'Remote Question Types';
 $string['keptcategory1'] = 'a literal from the same category reusable set of literals as before';
 $string['keptcategory2'] = 'a file from the same category reusable set of files as before';
 $string['keptcategory3'] = 'a link from the same category reusable set of links as before';
 $string['keptlocal1'] = 'a literal from the same question private set of literals as before';
 $string['keptlocal2'] = 'a file from the same question private set of files as before';
 $string['keptlocal3'] = 'a link from the same question private set of links as before';
+$string['lastanswer'] = 'Your last answer was';
 $string['learnwise'] = 'Learnwise format';
 $string['link'] = 'Link';
 $string['listitems'] = 'Listing of Items in Quiz';
 $string['literal'] = 'Literal';
 $string['loguniform'] = 'digits, from a loguniform distribution';
+$string['lowmarkslimit'] = '    Don\'t analyze if score is less than: ';
+$string['makecopy'] = 'Save as new question';
+$string['managetypes'] = 'Manage question types and servers';
+$string['mark'] = 'Submit';
+$string['markall'] = 'Submit page';
 $string['marks'] = 'Marks';
 $string['match'] = 'Matching';
 $string['matchanswer'] = 'Matching answer';
@@ -155,16 +219,19 @@ $string['min'] = 'Min';
 $string['minutes'] = 'Minutes';
 $string['missinganswer'] = 'Too few :ANSWER, :Lx, :Rx statements for question line $a. You must define at last 2 possible answers';
 $string['missingcorrectanswer'] = 'Correct answer must be specified';
+$string['missingitemtypename'] = 'Missing name';
 $string['missingname'] = 'Missing question name';
 $string['missingquestion'] = 'Missing question label after line $a';
 $string['missingquestiontext'] = 'Missing question text';
 $string['missingword'] = 'Missing word format';
 $string['modulename'] = 'Quiz';
 $string['modulenameplural'] = 'Quizzes';
+$string['moveto'] = 'Move to >>';
 $string['multianswer'] = 'Embedded Answers (Cloze)';
 $string['multichoice'] = 'Multiple Choice';
 $string['multiplier'] = 'Multiplier';
 $string['name'] = 'Name';
+$string['newattemptfail'] = 'Error: Could not start a new attempt at the quiz';
 $string['newcategory1'] = 'a literal from a new set of literals that may also be used by other questions in this category';
 $string['newcategory2'] = 'a file from a new set of files that may also be used by other questions in this category';
 $string['newcategory3'] = 'a link from a new set of links that may also be used by other questions in this category';
@@ -173,37 +240,55 @@ $string['newlocal2'] = 'a file  from a new set of files that will only be used b
 $string['newlocal3'] = 'a link from a new set of links that will only be used by this question';
 $string['noanswers'] = 'No answers were selected!';
 $string['noattempts'] = 'No attempts have been made on this quiz';
+$string['noattemptstoshow'] = 'There are no attempts to show';
+$string['noconnection'] = 'There is currently no connection to a web service that can process this question. Please contact your administrator';
 $string['nodataset'] = 'nothing - it is not a wild card';
 $string['nominal'] = 'Nominal';
 $string['nomoreattempts'] = 'No more attempts are allowed';
 $string['nopossibledatasets'] = 'No possible datasets';
 $string['noquestionintext'] = 'The question text does not contain any embedded questions';
 $string['noquestions'] = 'No questions have been added yet';
+$string['noquestionsfound'] = 'No questions found';
 $string['noresponse'] = 'No Response';
 $string['noreview'] = 'You are not allowed to review this quiz';
 $string['noreviewuntil'] = 'You are not allowed to review this quiz until $a';
 $string['noscript'] = 'JavaScript must be enabled to continue!';
+$string['notavailable'] = 'Sorry, this quiz is not available';
+$string['notavailabletostudents'] = 'Note: This quiz is not currently available to your students';
 $string['notenoughanswers'] = 'This type of question requires at least $a answers';
 $string['notenoughsubquestions'] = 'Not enough sub-questions have been defined!<br />Do you want to go back and fix this question?';
+$string['notimedependentitems'] = 'Time dependent items are not currently supported by the quiz module. As a work around, set a time limit for the whole quiz. Do you wish to choose a different item (or use the current item regardless)?';
+$string['numberabbr'] = '#';
 $string['numerical'] = 'Numerical';
 $string['optional'] = 'optional';
+$string['outof'] = ' out of a maximum of ';
 $string['overdue'] = 'Overdue';
 $string['paragraphquestion'] = 'Paragraph Question not supported at line $a. The question will be ignored';
 $string['parent'] = 'Parent';
+$string['partiallycorrect'] = 'Partially correct';
 $string['passworderror'] = 'The password entered was incorrect';
+$string['penalty'] = 'Penalty';
+$string['penaltyfactor'] = 'Penalty factor';
+$string['penaltyscheme'] = 'Apply penalties';
 $string['percentcorrect'] = 'Percent Correct';
 $string['popup'] = 'Show quiz in a \"secure\" window';
+$string['popupnotice'] = 'Students will see this quiz in a secure window';
 $string['preview'] = 'Preview';
 $string['previewquestion'] = 'Preview question';
+$string['previewquiz'] = 'Preview $a';
+$string['previous'] = 'Previous state';
 $string['publish'] = 'Publish';
 $string['publishedit'] = 'You must have permission in the publishing course to add or edit questions in this category';
 $string['qti'] = 'IMS QTI format';
+$string['qti2'] = 'IMS QTI 2.0 format';
 $string['question'] = 'Question';
-$string['questioninuse'] = 'The question \'$a\' is currently being used:';
+$string['questioninuse'] = 'The question \'$a->questionname\' is currently being used in: <br />$a->quiznames<br />The question will not be deleted from these quizzes but only from the category list.';
 $string['questionname'] = 'Question name';
 $string['questionnametoolong'] = 'Question name too long at line $a (255 char. max). It has been truncated.';
 $string['questions'] = 'Questions';
-$string['questionsperpage'] = 'Max number of questions per page';
+$string['questionsinuse'] = '(* Questions marked by an asterisk are already in use in some quizzes. These question will not be deleted from these quizzes but only from the category list.)';
+$string['questionsperpage'] = 'Questions per page';
+$string['questiontype'] = 'Question type $a';
 $string['questiontypesetupoptions'] = 'Setup options for question types:';
 $string['quizavailable'] = 'The quiz is available until: $a';
 $string['quizclose'] = 'Close the quiz';
@@ -214,6 +299,7 @@ $string['quizopen'] = 'Open the quiz';
 $string['quizopens'] = 'Quiz opens';
 $string['quiztimelimit'] = 'Time limit: $a';
 $string['quiztimer'] = 'Quiz Timer';
+$string['pleaseclose'] = 'Your request has been processed. You can now close this window';
 $string['random'] = 'Random Question';
 $string['randomcreate'] = 'Create Random Questions';
 $string['randomsamatch'] = 'Random Short-Answer Matching';
@@ -227,50 +313,90 @@ $string['recurse'] = 'Display questions from sub-categories too';
 $string['regrade'] = 'Regrade all attempts';
 $string['regradecomplete'] = 'All attempts have been regraded';
 $string['regradecount'] = '$a->changed out of $a->attempt grades were changed';
+$string['regradedisplayexplanation'] = 'Attempts that change during regrading are displayed as hyperlinks to the question review window';
+$string['regradingquestion'] = 'Regrading \"$a\".';
+$string['regradingquiz'] = 'Regrading Quiz \"$a\"';
 $string['relative'] = 'Relative';
-$string['reviewnever'] = 'Never allow review';
-$string['reviewafter'] = 'Allow review after quiz is closed';
-$string['reviewbefore'] = 'Allow review while quiz is open';
-$string['reviewalways'] = 'Allow review at any time';
 $string['remove'] = 'Remove';
 $string['rename'] = 'Rename';
+$string['renderingserverconnectfailed'] = 'The server $a failed to process an RQP request. Check that the URL is correct.';
+$string['repaginate'] = 'Repaginate with $a questions per page';
+$string['replace'] = 'Replace';
+$string['replacementoptions'] = 'Replacement Options';
 $string['report'] = 'Reports';
+$string['reportanalysis'] = 'Item analysis';
 $string['reportfullstat'] = 'Detailed statistics';
 $string['reportmulti_percent'] = 'Multi-Percentages';
 $string['reportmulti_q_x_student'] = 'Multi-Student Choices';
 $string['reportmulti_resp'] = 'Individual Responses';
 $string['reportoverview'] = 'Overview';
 $string['reportregrade'] = 'Regrade attempts';
+$string['reports'] = 'Reports';
 $string['reportsimplestat'] = 'Simple statistics';
 $string['requirepassword'] = 'Require password';
 $string['requirepasswordmessage'] = 'To attempt this quiz you need to know the quiz password';
 $string['requiresubnet'] = 'Require network address';
+$string['response'] = 'Response';
+$string['responses'] = 'Responses';
 $string['reuseifpossible'] = 'reuse previously removed';
 $string['review'] = 'Review';
+$string['reviewafter'] = 'Allow review after quiz is closed';
+$string['reviewalways'] = 'Allow review at any time';
+$string['reviewbefore'] = 'Allow review while quiz is open';
+$string['reviewclosed'] = 'After the quiz is closed';
+$string['reviewimmediately'] = 'Immediately after the attempt';
+$string['reviewnever'] = 'Never allow review';
+$string['reviewofattempt'] = 'Review of Attempt $a';
+$string['reviewopen'] = 'Later, while the quiz is still open';
+$string['reviewoptions'] = 'Students may review';
+$string['reviewresponse'] = 'Review response';
+$string['rqp'] = 'Remote Question';
+$string['rqps'] = 'Remote Questions';
 $string['save'] = 'Save';
 $string['saveandedit'] = 'Save changes and edit questions';
+$string['savedfromdeletedcourse'] = 'Saved from deleted course \"$a\"';
 $string['savegrades'] = 'Save grades';
 $string['savemyanswers'] = 'Save my answers';
+$string['savenosubmit'] = 'Save without submitting';
 $string['savequiz'] = 'Save this whole quiz';
 $string['score'] = 'Raw score';
+$string['scores'] = 'Scores';
 $string['select'] = 'Select';
 $string['selectall'] = 'Select all';
 $string['selectcategoryabove'] = 'Select a category above';
+$string['selectedattempts'] = 'Selected attempts...';
+$string['selectnone'] = 'Deselect all';
+$string['serveradded'] = 'Server added';
+$string['serveridentifier'] = 'Identifier';
+$string['serverinfo'] = 'Server information';
+$string['serverinuse'] = 'The server that you are about to delete is the last $a server and there are already questions which will not work any more if you delete this server.';
+$string['servers'] = 'Servers';
+$string['serverurl'] = 'Server URL';
 $string['shortanswer'] = 'Short Answer';
 $string['show'] = 'Show';
+$string['showall'] = 'Show all questions on one page';
+$string['showbreaks'] = 'Show page breaks';
 $string['showcorrectanswer'] = 'In feedback, show correct answers?';
+$string['showdetailedmarks'] = 'Show mark details';
 $string['showfeedback'] = 'After answering, show feedback?';
+$string['showhidden'] = 'Also show old questions';
+$string['shownoattempts'] = 'Show students with no attempts';
+$string['showteacherattempts'] = 'Show teacher attempts';
 $string['shuffleanswers'] = 'Shuffle answers';
 $string['shufflequestions'] = 'Shuffle questions';
-$string['significantfiguresformat'] = 'significant figures';
 $string['significantfigures'] = ' with $a ';
+$string['significantfiguresformat'] = 'significant figures';
+$string['startagain'] = 'Start again';
+$string['startedon'] = 'Started on';
 $string['subneterror'] = 'Sorry, this quiz has been locked so that it is only accessible from certain locations.  Currently your computer is not one of those allowed to use this quiz.';
+$string['subnetnotice'] = 'This quiz has been locked so that it is only accessible from certain locations. Your computer is not on an allowed subnet. As teacher you are allowed to preview anyway.';
 $string['substitutedby'] = 'will be substituted by';
 $string['time'] = 'Time';
 $string['timecompleted'] = 'Completed';
 $string['timeleft'] = 'Time Remaining';
 $string['timelimit'] = 'Time limit';
-$string['timelimitexeeded'] = 'Sorry! Quiz time limit exeeded!';
+$string['timelimitexeeded'] = 'Sorry! Quiz time limit exceeded!';
+$string['timestr'] = '%%H:%%M:%%S on %%d/%%m/%%y';
 $string['timesup'] = 'Time is up!';
 $string['timetaken'] = 'Time taken';
 $string['tolerance'] = 'Tolerance';
@@ -280,18 +406,28 @@ $string['top'] = 'Top';
 $string['true'] = 'True';
 $string['truefalse'] = 'True/False';
 $string['type'] = 'Type';
+$string['unfinished'] = 'open';
 $string['uniform'] = 'decimals, from a uniform distribution';
 $string['unit'] = 'Unit';
 $string['unknowntype'] = 'Question type not supported at line $a. The question will be ignored';
+$string['unusedcategorydeleted'] = 'This category has been deleted because, after deleting the course, their questions weren\'t used in the server anymore.';
 $string['unsupportedformulafunction'] = 'The function $a is not supported';
-$string['viewallanswers'] = 'View $a completed quizzes';
+$string['upgradesure'] = '<div style=\"color: red;\">In particular the quiz module will perform an extensive change of the quiz tables and this upgrade has not yet been sufficiently tested. You are very strongly urged to backup your database tables before proceeding.</div>';
+$string['url'] = 'URL';
+$string['usedcategorymoved'] = 'This category has been moved to site level because, after deleting the course, their questions were in use by other quizzes in the server.';
+$string['validate'] = 'Validate';
+$string['viewallanswers'] = 'View $a quiz attempts';
 $string['viewallreports'] = 'View reports for $a attempts';
 $string['warningsdetected'] = '$a warning(s) detected';
 $string['webct'] = 'WebCT format';
 $string['wildcard'] = 'Wild card';
+$string['withselected'] = 'With selected';
 $string['withsummary'] = 'with Summary Statistics';
 $string['wronggrade'] = 'Wrong grade (after line $a) : ';
+$string['wronguse'] = 'You can not use this page like that';
+$string['xhtml'] = 'XHTML Format';
 $string['xml'] = 'Moodle XML format';
+$string['xmltypeunsupported'] = 'Question type $a is not supported by xml import';
 $string['yourfinalgradeis'] = 'Your final grade for this quiz is $a';
 $string['zerosignificantfiguresnotallowed'] = 'The correct answer cannot have zero significant figures!';
 
