@@ -1,15 +1,20 @@
 <?PHP // $Id$ 
-      // admin.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)
+      // admin.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005030501)
 
 
+$string['adminseesallevents'] = 'Yllpitj nkee kaikki tapahtumat';
+$string['adminseesownevents'] = 'Yllpitj on kuten tavallinen kyttj';
 $string['blockinstances'] = 'Ilmentymt';
 $string['blockmultiple'] = 'Monenkertainen';
 $string['cachetext'] = 'Tekstivlimuistin kesto';
+$string['calendarsettings'] = 'Kalenteri';
 $string['change'] = 'muutos';
+$string['configallowcoursethemes'] = 'Tm asetus sallii kurssien kytt omia teemojaan.';
+$string['configallowemailaddresses'] = 'Jos haluat sallie kyttjt vain tietyist ositteista kirjoita toimialueet thn pilkuilla eroteltuina.';
+$string['configallowunenroll'] = 'Tm sallii opiskelijoiden poistua kursseilta koska tahansa. Jos asetus ei ole pll opettajien tai yllpitjien pit poistaa opiskelijat kursseilta.';
+$string['configallowuserblockhiding'] = 'Voivatko kyttjt piiloittaa lohkoja?';
+$string['configallowuserthemes'] = 'Voivatko kyttjt valita omia teemojaan?';
 $string['filteruploadedfiles'] = 'Suodata lhetettyj tiedostoja';
-$string['thischarset'] = 'iso-8859-1';
-$string['thisdirection'] = 'ltr';
-$string['thislanguage'] = 'Suomi';
 $string['upgradelogs'] = 'Tapahtumalokien sisllt pit pivitt uuteen muotoon. <a href=\"$a\">Listietoja</a>';
 $string['upgradelogsinfo'] = 'Tapahtumalokien tallennuksessa on tapahtunut muutoksia. Jotta voisit tarkastella lokeja uudella tavalla, vanhat lokimerkinnt pit pivitt uuteen muotoon. Tm tapahtuu automaattisesti eik hiritse sivustosi muuta kytt. Riippuen sivustosi koosta thn saattaa kuitenkin menn aikaa jopa useita tunteja. Kun aloitat pivityksen, pit se antaan menn loppuun asti keskeyttmtt.
 <br /><br />
