@@ -1,5 +1,5 @@
 <?PHP // $Id$ 
-      // glossary.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)
+      // glossary.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005030501)
 
 
 $string['addcomment'] = 'Lis kommentti';
@@ -102,7 +102,7 @@ $string['exporttomainglossary'] = 'Vie psanastoon';
 $string['filetoimport'] = 'Tuontitiedosto';
 $string['fillfields'] = 'Ksite ja mritelm ovat pakollisia kentti.';
 $string['filtername'] = 'Sanaston automaattinen linkitys';
-$string['fullmatch'] = 'Hae vain kokonaisia sanoja';
+$string['fullmatch'] = 'Vain tydet sanat ';
 $string['globalglossary'] = 'Yleinen sanasto';
 $string['glossaryleveldefaultsettings'] = 'Sanastojen oletusasetukset';
 $string['glossarytype'] = 'Sanaston tyyppi';
@@ -114,7 +114,7 @@ $string['importentries'] = 'Tuo tietueita';
 $string['isglobal'] = 'Globaali sanasto?';
 $string['linkcategory'] = 'Linkit tm kategoria automaattisesti';
 $string['mainglossary'] = 'Psanasto';
-$string['maxtimehaspassed'] = 'Tmn kommentin ($a) sallittu muokkausaika ylittynyt.';
+$string['maxtimehaspassed'] = 'Kommentin ($a) sallittu muokkausaika on ylittynyt.';
 $string['modulename'] = 'Sanasto';
 $string['modulenameplural'] = 'Sanastot';
 $string['newentries'] = 'Uudet sanaston tietueet';
@@ -130,6 +130,7 @@ $string['notcategorised'] = 'Kategorisoimaton';
 $string['numberofentries'] = 'Hakusanojen lukumr';
 $string['onebyline'] = '(yksi rivi kohden)';
 $string['printerfriendly'] = 'Tulostukseen soveltuva versio';
+$string['printviewnotallowed'] = 'Tulostusnkym ei ole sallittu';
 $string['question'] = 'Kysymys';
 $string['rate'] = 'Arvo';
 $string['rating'] = 'Arvio';
@@ -149,16 +150,13 @@ $string['sendinratings'] = 'Lhet viimeisimmt arvioni';
 $string['showall'] = 'Nyt \'Kaikki\'';
 $string['showalphabet'] = 'Nyt aakkosittain';
 $string['showspecial'] = 'Nyt \'Erikoiset\'';
-$string['sortby'] = 'Lajittele';
+$string['sortby'] = 'Lajittele...';
 $string['sortbycreation'] = 'Luontipivyksen mukaan';
 $string['sortbylastupdate'] = 'Viimeisen pivityksen mukaan';
 $string['sortchronogically'] = 'Lajittele kronologisesti';
 $string['special'] = 'Erikoiset';
 $string['standardview'] = 'Selaa aakkosjrjestyksess';
 $string['studentcanpost'] = 'Opiskelijat voivat list tietueita';
-$string['thischarset'] = 'iso-8859-1';
-$string['thisdirection'] = 'ltr';
-$string['thislanguage'] = 'Suomi';
 $string['totalentries'] = 'Hakusanojen kokonaismr';
 $string['usedynalink'] = 'Linkit sanaston tietueet automaattisesti';
 $string['waitingapproval'] = 'Odotetaan hyvksynt';
