@@ -1,118 +1,164 @@
 <?PHP // $Id$ 
-      // lesson.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)
+      // lesson.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005032600)
 
 
+$string['accesscontrol'] = 'Saatavuus';
 $string['actionaftercorrectanswer'] = 'Toiminto oikean vastauksen jlkeen';
-$string['addabranchtable'] = 'Lis tietopuun haara';
-$string['addanendofbranch'] = 'Lis tietopuun haaran pte';
+$string['addabranchtable'] = 'Lis haara';
+$string['addanendofbranch'] = 'Pt haara';
 $string['addaquestionpage'] = 'Lis kysymyssivu';
 $string['addcluster'] = 'Lis ryhm';
-$string['addendofcluster'] = 'Lis ryhmn lopetus';
+$string['addedabranchtable'] = 'Listty haara';
+$string['addedanendofbranch'] = 'Haara ptetty';
+$string['addedaquestionpage'] = 'Listty Kysymyssivu';
+$string['addedcluster'] = 'Listty ryhm';
+$string['addedendofcluster'] = 'Ryhm ptetty';
+$string['addendofcluster'] = 'Pt ryhm';
 $string['answer'] = 'Vastaus';
+$string['answeredcorrectly'] = 'vastasi oikein.';
 $string['answersfornumerical'] = 'Numeeristen kysymysten vastauksia pitisi verrata minimi- ja maksimiarvoihin. Tlle vlille osuva arvo katsotaan oikeaksi vastaukseksi.';
 $string['arrangebuttonshorizontally'] = 'Jrjest haarapainikkeet horisontaalisesti diashowtilassa? ';
 $string['attempt'] = 'Yritys: $a';
 $string['attempts'] = 'Yritykset';
 $string['available'] = 'Tehtviss';
+$string['averagescore'] = 'Pisteiden keskiarvo';
+$string['averagetime'] = 'Ajan keskiarvo';
 $string['backtreeview'] = 'Takaisin puunkymn';
-$string['branchtable'] = 'Tietopuun haara';
+$string['branchtable'] = 'Haara';
 $string['cancel'] = 'Peruuta';
 $string['canretake'] = '$a voi aloittaa uudelleen';
 $string['casesensitive'] = 'Kirjainkoko merkityksellinen (case sensitive)';
-$string['checkbranchtable'] = 'Tarkista tietopuun haaran toiminta';
+$string['checkbranchtable'] = 'Tarkista  haara';
+$string['checkedthisone'] = 'tarkasti tmn.';
 $string['checknavigation'] = 'Tarkista navigointi';
 $string['checkquestion'] = 'Tarkista kysymys';
-$string['clicktopost'] = 'Klikkaa tss sijoittaaksesi arvosanasi Korkeimmat Tulokset listalle.';
+$string['classstats'] = 'Luokan tiedot';
+$string['clicktopost'] = 'Klikkaa tss lhettksesi arvosanasi Parhaat Tulokset listalle.';
 $string['clusterjump'] = 'Kysymys, jota ei ole nhty ryhmss';
-$string['clustertitle'] = 'ryhm';
-$string['comments'] = 'sinun kommenttisi';
+$string['clustertitle'] = 'Ryhm';
+$string['comments'] = 'Kommenttisi';
+$string['commentswithname'] = 'a$->firstname {a$->lastname} :n kommentit';
+$string['completed'] = 'Suoritettu';
 $string['confirmdeletionofthispage'] = 'Vahvista tmn sivun poistaminen';
 $string['congratulations'] = 'Onnittelut - oppitunnin loppu saavutettu';
 $string['continue'] = 'Jatka';
-$string['correctanswerjump'] = 'Korjaa Vastaus Hyppy';
-$string['correctanswerscore'] = 'Korjaa Vastaus Tulos';
-$string['correctresponse'] = 'Korjaa Vaste';
-$string['customscoring'] = ' ';
+$string['continuetoanswer'] = 'Jatka vastausten muuttamista';
+$string['correctanswerjump'] = 'Oikea vastaus hyppy';
+$string['correctanswerscore'] = 'Oikea vastaus tulos';
+$string['correctresponse'] = 'Oikea vaste';
+$string['customscoring'] = 'Muokattu pisteytys';
 $string['deadline'] = 'Viimeinen suorituspiv';
 $string['deleteattempts'] = 'Poista opiskelijoiden yritykset tlle oppitunnille (kyttjtunnus)';
+$string['deletedpage'] = 'Poistettu sivu';
 $string['deleting'] = 'Poistetaan';
 $string['deletingpage'] = 'Poistetaan sivu $a';
 $string['description'] = 'Kuvaus';
-$string['displayhighscores'] = 'Nyt Korkeat Tulokset';
+$string['detailedstats'] = 'Tarkemmat tiedot';
+$string['didnotanswerquestion'] = 'Ei vastannut thn kysymykseen.';
+$string['displayhighscores'] = 'Nyt parhaat tulokset';
 $string['displayinleftmenu'] = 'Nyt vasemmassa valikossa?';
-$string['displayleftmenu'] = 'Nyt Vasen Valikko';
+$string['displayleftmenu'] = 'Nyt vasen valikko';
 $string['displayofgrade'] = 'Arvosanan nyttminen (vain opiskelijoille)';
-$string['displayreview'] = 'Nyt Arvostelu Nppin';
-$string['displayscorewithessays'] = 'Olet ansainnut $a->score $a->tempmaxgrade :sta automaattisesti arvostelluista kysymyksist.<br> Sinun $a->essayquestions essee kysymykset arvioidaan ja listn<br>lopulliseen tulokseesi myhempn pivn.<br><br>Tmn hetkinen tuloksesi ilman esseekysymyksi on $a->score $a->grade :st. ';
+$string['displayreview'] = 'Nyt arvostelu nppin';
+$string['displayscorewithessays'] = 'Olet ansainnut $a->score $a->tempmaxgrade :sta automaattisesti arvostelluista kysymyksist.<br /> Sinun $a->essayquestions essee kysymykset arvioidaan ja listn<br />lopulliseen tulokseesi myhempn pivn.<br /><br />Tmn hetkinen tuloksesi ilman esseekysymyksi on $a->score $a->grade :st. ';
 $string['displayscorewithoutessays'] = 'Tuloksesi on $a->score ($a->grade:sta).';
 $string['editlessonsettings'] = 'Muokkaa tmn oppitunnin asetuksia';
 $string['editpagecontent'] = 'Muokkaa tmn sivun osia';
 $string['email'] = 'Shkposti';
-$string['emailallgradedessays'] = 'Lhet Kaikki<br>Arvostellut esseet';
+$string['emailallgradedessays'] = 'Lhet kaikki<br />arvostellut esseet';
 $string['emailgradedessays'] = 'Lhet arvostellut eseet';
 $string['emailsuccess'] = 'Lhettminen onnistui';
-$string['endofbranch'] = 'Tietopuun haaran pte';
+$string['endofbranch'] = 'Haaran pte';
 $string['endofclustertitle'] = 'Ryhmn pte';
 $string['endoflesson'] = 'Oppitunnin loppu';
-$string['entername'] = 'Syt lempinimi korkeat tulokset listalle';
+$string['enteredthis'] = 'kirjoitti tmn';
+$string['entername'] = 'Syt lempinimi parhaat tulokset listalle';
 $string['enterpassword'] = 'Syt salasana:';
 $string['eolstudentoutoftime'] = 'Huomio: Aika loppui tmn oppitunnin osalta. Viimeinen vastauksesi ei merkinnyt mitn, jos se annettiin ajan pttymisen jlkeen.';
 $string['eolstudentoutoftimenoanswers'] = 'Et vastannut yhteenkn kysymykseen. Sait a 0 tst oppitunnista.';
 $string['essay'] = 'Essee';
+$string['essayemailsubject'] = 'Arvosanasi tehtvst: a$';
 $string['essays'] = 'Esseet';
 $string['essayscore'] = 'Essee tulos';
 $string['fileformat'] = 'Tiedoston tyyppi';
 $string['firstanswershould'] = 'Ensimminen vastaus hypp \"oikealle\" sivulle.';
 $string['firstwrong'] = 'Valitettavasti et voi tienata tt yht pistett, koska vastauksesi ei ollut oikein. Haluatko jatkaa arvaamista vain oppimisen ilosta(en et saa pisteit)?';
+$string['flowcontrol'] = 'Kulunvalvonta';
+$string['general'] = 'Yleist';
+$string['gobacktolesson'] = 'Takaisin tunnille';
+$string['grade'] = 'Arvosana';
 $string['gradeessay'] = 'Arvostele Essee Kysymykset';
 $string['gradeis'] = 'Arvosana on $a';
+$string['gradeoptions'] = 'Arviointi';
 $string['handlingofretakes'] = 'Useiden yritysten arvioinnin ksittelytapa';
+$string['havenotgradedyet'] = 'Ei ole viel arvostellut.';
 $string['here'] = 'tnne';
+$string['highscore'] = 'Parhaat tulokset';
+$string['hightime'] = 'Parhaat ajat';
 $string['importquestions'] = 'Tuo kysymykset';
+$string['insertedpage'] = 'Listty sivu';
 $string['jump'] = 'Siirry';
+$string['jumptsto'] = 'Siirtyy';
 $string['leftduringtimed'] = 'Olet lhtenyt ajastetun oppitunnin aikana.<br>Ole hyv ja klikkaa \"jatka\" aloittaaksesi oppitunnin uudelleen.';
 $string['leftduringtimednoretake'] = 'Olet lhtenyt ajastetun oppitunnin aikana, etk<br> saa aloittaa uudelleen tai jatkaa oppituntia.';
+$string['lesson'] = 'a$ oppitunti';
 $string['lessonclosed'] = 'Tm oppitunti on suljettu $a:ssa';
 $string['lessondefault'] = 'Kyt tmn oppitunnin asetuksia oletuksina';
+$string['lessonformating'] = 'Oppitunnin muotoilu';
 $string['lessonmenu'] = 'Oppitunnin valikko';
 $string['lessonopen'] = 'Tm oppitunti on auki $a:ssa';
+$string['lessonstats'] = 'Tunnin tiedot';
 $string['loginfail'] = 'Sisnkirjautuminen eponnistui, yrit uudelleen...';
+$string['lowscore'] = 'Matalat pisteet';
+$string['lowtime'] = 'Huono aika';
 $string['mainmenu'] = 'Pvalikko';
-$string['matchesanswer'] = 'Sopii yhteen Vastausten kanssa';
-$string['maxhighscores'] = 'Kuinka monta korkeaa tulosta nytetn';
+$string['matchesanswer'] = 'Sopii yhteen vastausten kanssa';
+$string['maxhighscores'] = 'Pararhaiden tulosten mr';
 $string['maximumnumberofanswersbranches'] = 'Vastausten/haarojen maksimimr';
 $string['maximumnumberofattempts'] = 'Vastausyritysten maksimimr';
 $string['maxtime'] = 'Aika raja (minuuteissa)';
 $string['maxtimewarning'] = 'Sinulla on $a minuutti(a) viimeistell oppitunti.';
 $string['minimumnumberofquestions'] = 'Kysymysten minimimr';
+$string['modattempts'] = 'Salli oppilaiden esikatselu';
+$string['modattemptsnoteacher'] = 'Vain oppilaat voivat esikatsella';
 $string['modulename'] = 'Oppitunti';
 $string['modulenameplural'] = 'Oppitunnit';
+$string['movedpage'] = 'Siirrety sivu';
 $string['movepagehere'] = 'Siirr sivu thn';
 $string['moving'] = 'Siirretn sivu $a';
 $string['movingtonextpage'] = 'Siirrytn seuraavalle sivulle';
 $string['multianswer'] = 'Monivastaus';
 $string['multipleanswer'] = 'Useita vastauksia';
-$string['nameapproved'] = 'Nimi Hyvksytty';
-$string['namereject'] = 'Valitettavasti nimesi on hyltty suodattimen takia.<br>Yrit toista nime.';
+$string['nameapproved'] = 'Nimi hyvksytty';
+$string['namereject'] = 'Valitettavasti suodatin hylksi nimesi.<br>Yrit toista nime.';
 $string['nextpage'] = 'Seuraava sivu';
 $string['noanswer'] = 'Ei vastausta';
 $string['noattemptrecordsfound'] = 'Ei yrityksi: ei arvosanaa';
-$string['nohighscores'] = 'Ei Korkeita Tuloksia';
-$string['noretake'] = 'Sinulla ei ole lupaa ottaa uudelleen tt oppituntia.';
+$string['nocommentyet'] = 'ei viel kommentteja';
+$string['nohighscores'] = 'Ei parhaita tuloksia';
+$string['nooneansweredcorrectly'] = 'Kukaan ei vastannut oikein';
+$string['nooneansweredthisquestion'] = 'Kukaan ei vastannut thn kysymykseen';
+$string['noonecheckedthis'] = 'Kukaan ei valinnut tt';
+$string['nooneenteredthis'] = 'Kukaan ei kirjoittanut tt';
+$string['noretake'] = 'Sinulla ei ole lupaa uusia tt oppituntia.';
 $string['normal'] = 'Normaali - seuraa oppitunnin polkua';
+$string['notcompleted'] = 'Ei valmis';
 $string['notdefined'] = 'Ei mritelty';
-$string['nothighscore'] = 'Et selviytynyt Top $a:n korkeat tulokset listalle.';
+$string['nothighscore'] = 'Et pssyt  $a :n parhaan joukkoon.';
 $string['notitle'] = 'Otsikko puuttuu';
 $string['numberofcorrectanswers'] = 'Oikeiden vastausten lukumr: $a';
 $string['numberofcorrectmatches'] = 'Oikeiden parikysymysten mr: $a ';
-$string['numberofpagestoshow'] = 'Nytettvien sivujen (korttien) mr';
+$string['numberofpagestoshow'] = 'Nytettvien sivujen  mr';
 $string['numberofpagesviewed'] = 'Katsottujen sivujen mr: $a';
 $string['ongoing'] = 'Nyt menossa oleva pistemr.';
 $string['ongoingcustom'] = 'Tm on $a->grade pisteen oppitunti. Olet ansainnut $a->score pistett $a->currenthigh pisteest thn menness.';
 $string['ongoingnormal'] = 'Olet vastannut oikein $a->correct kysymykseen $a->viewed kysymyksest.';
+$string['or'] = 'TAI';
 $string['ordered'] = 'Jrjestetty';
+$string['other'] = 'Muu';
 $string['outof'] = 'maksimipisteet $a';
 $string['outoftime'] = 'Aika Loppuu';
+$string['overview'] = 'Yleist';
 $string['page'] = 'Sivu $a';
 $string['pagecontents'] = 'Sivun sislt';
 $string['pages'] = 'Sivuja';
@@ -123,23 +169,28 @@ $string['pleasecheckoneanswer'] = 'Valitse yksi vastausvaihtoehto';
 $string['pleasecheckoneormoreanswers'] = 'Valitse yksi tai useampia vastausvaihtoehdoista';
 $string['pleaseenteryouranswerinthebox'] = 'Kirjoita vastauksesi';
 $string['pleasematchtheabovepairs'] = 'Yhdist yll olevien listojen kohdat pareiksi';
+$string['pointsearned'] = 'Pisteit ansaittu';
 $string['postsuccess'] = 'Lhetys onnistui';
 $string['practice'] = 'Harjoitus Oppitunti';
 $string['previouspage'] = 'Edellinen Sivu';
 $string['question'] = 'Kysymys';
 $string['questionoption'] = 'Kysymyksen vaihtoehtoinen toiminta';
 $string['questiontype'] = 'Kysymyksen tyyppi';
-$string['randombranch'] = 'Satunnainen tietopuun haara sivu';
-$string['randompageinbranch'] = 'Satunnainen kysymys tietopuun haaran sisll';
+$string['randombranch'] = 'Satunnainen tietopuun haara';
+$string['randompageinbranch'] = 'Satunnainen kysymys haaran sisll';
 $string['rank'] = 'Luokitus';
 $string['reached'] = 'saavutettu';
 $string['redisplaypage'] = 'Nyt sivu uudelleen';
+$string['report'] = 'Raportti';
 $string['response'] = 'Palaute';
 $string['returnmainmenu'] = 'Palaa pvalikkoon';
 $string['returntocourse'] = 'Palaa kurssiin';
+$string['reviewlesson'] = 'Esikatesele tuntia';
 $string['reviewquestionback'] = 'Kyll, haluaisin yritt uudelleen';
 $string['reviewquestioncontinue'] = 'Ei, haluan vain siirty seuraavaan kysymykseen';
 $string['sanitycheckfailed'] = 'Tarkistus eponnistui: tm yritys on poistettu';
+$string['savechanges'] = 'Tallenna muutokset';
+$string['savechangesandeol'] = 'Tallenna muutokset ja mene tunnin loppuun';
 $string['savepage'] = 'Tallenna sivu';
 $string['score'] = 'Tulos';
 $string['scores'] = 'Tulokset';
@@ -152,24 +203,25 @@ $string['slideshowbgcolor'] = 'Diaesityksen taustavri';
 $string['slideshowheight'] = 'Diaesityksen korkeus';
 $string['slideshowwidth'] = 'Diaesityksen leveys';
 $string['startlesson'] = 'Aloita oppitunti';
+$string['studentattemptlesson'] = '$a->lastname, $a->firstname\'s yritys numero $a->attempt';
 $string['studentoneminwarning'] = 'Varoitus: Sinulla on 1 minuutti tai vhemmn viimeistell oppitunti.';
 $string['studentoutoftime'] = 'HUOMIO: Aika loppui tmn oppitunnin osalta. Viimeist vastaustasi ei lasketa, koska se annettiin ajan jo loputtua. Paina jatka painiketta lopettaaksesi oppitunnin.';
-$string['studentresponse'] = '{$a}\'n vaste';
-$string['submitname'] = 'Luovuta nimi';
+$string['studentresponse'] = '{$a}\'n vastaus';
+$string['submitname'] = 'Lhet nimi';
 $string['teacherjumpwarning'] = '$a->cluster hyppy tai $a->unseen hyppy kytetn tll oppitunnilla. Seuraava Sivu hyppy kytetn sen sijaan. Kirjaudu sisn opiskelijana testataksesi nit hyppyj.';
 $string['teacherongoingwarning'] = 'Menossa oleva tulos on nytetty ainoastaan opiskelijalle. Kirjaudu sisn opiskelijana testataksesi menossa olevaa tulosta.';
 $string['teachertimerwarning'] = 'Ajastin toimii vain opiskelijalle. Kirjaudu sisn opiskelijana testataksesi ajastinta.';
 $string['thatsthecorrectanswer'] = 'Vastaus on oikein';
 $string['thatsthewronganswer'] = 'Vastaus on vrin';
 $string['thefollowingpagesjumptothispage'] = 'Seuraavat sivut hyppvt tlle sivulle';
-$string['thischarset'] = 'iso-8859-1';
-$string['thisdirection'] = 'ltr';
-$string['thislanguage'] = 'Suomi';
 $string['thispage'] = 'Tm sivu';
-$string['timed'] = 'Ajastin';
-$string['topscorestitle'] = 'Parhaat $a->maxhighscores tulokset $a->name oppitunnille.';
+$string['timed'] = 'Ajastettu';
+$string['timeremaining'] = 'Aikaa jljell';
+$string['timetaken'] = 'Aikaa kulunut';
+$string['topscorestitle'] = 'Parhaat $a->maxhighscores tulosta oppitunnilla: $a->name .';
 $string['treeview'] = 'Puu nkym';
-$string['unseenpageinbranch'] = 'Kysymys, jota ei ole nhty tietopuun haarassa';
+$string['unseenpageinbranch'] = 'Katsomaton kysymys haarassa';
+$string['updatedpage'] = 'Sivu pivitetty';
 $string['updatefailed'] = 'Pivitys eponnistui';
 $string['updatesuccess'] = 'Pivitys onnistui';
 $string['useeditor'] = 'Kyt editoria';
@@ -178,17 +230,21 @@ $string['usemean'] = 'Kyt keskiarvoa';
 $string['usepassword'] = 'salasanasuojattu oppitunti';
 $string['viewallpages'] = 'Katsele kaikkia sivuja';
 $string['viewgrades'] = 'Katsele arvosanoja';
-$string['viewhighscores'] = 'Katsele korkeat tulokset listaa.';
-$string['waitpostscore'] = 'Odota, korkeita tuloksia lhetetn';
+$string['viewhighscores'] = 'Nyt parhaat tulokset..';
+$string['viewlessonstats'] = 'Nyt oppitunnin tiedot';
+$string['waitpostscore'] = 'Odota, tuloksia lhetetn';
 $string['welldone'] = 'Hyvin tehty!';
 $string['whatdofirst'] = 'Mit haluaisit tehd ensimmiseksi?';
 $string['wronganswerjump'] = 'Vr vastaus hyppy';
 $string['wronganswerscore'] = 'Vr vastaus tulos';
 $string['wrongresponse'] = 'Vr vaste';
+$string['youhavereceived'] = 'Sait tst kysymyksest $a->score pistett a$-outof pisteest.';
 $string['youhaveseen'] = 'Olet aikaisemmin aloittanut tmn oppitunnin.<br />Haluatko jatkaa sivulta, jolle viimeksi jit?';
-$string['youmadehighscore'] = 'Selvisit TOP $a korkeimmat tulokset listalle.';
+$string['youmadehighscore'] = 'Selvisit TOP $a :iin parhaat tulokset listalla.';
 $string['youranswer'] = 'Vastauksesi';
 $string['yourcurrentgradeis'] = 'Nykyinen arvosanasi on $a';
+$string['yourgradeisnow'] = 'Arvosanasi tunnista on mutettu $a :iksi';
+$string['yourresponse'] = 'Vastauksesi';
 $string['youshouldview'] = 'Sinun pitisi katsoa ainakin $a sivua';
 
 ?>
