@@ -1,5 +1,5 @@
-<?PHP // $Id$ 
-      // glossary.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)
+<?PHP // $Id$
+
 
 
 $string['addcomment'] = ' ';
@@ -10,6 +10,7 @@ $string['allcategories'] = ' ';
 $string['allentries'] = 'ü';
 $string['allowcomments'] = ' ';
 $string['allowduplicatedentries'] = ' ';
+$string['allowprintview'] = '̸';
 $string['allowratings'] = 'õ ';
 $string['answer'] = '';
 $string['approve'] = '';
@@ -49,6 +50,7 @@ $string['commentson'] = '';
 $string['commentupdated'] = ' ߰Ǿϴ.';
 $string['concept'] = '';
 $string['concepts'] = '';
+$string['configenablerssfeeds'] = '̽ġRss  ּޱ⸦ ϰմϴ.   ּޱ⸦ Ͽ غ    ʿ մϴ.';
 $string['currentglossary'] = ' ڷ';
 $string['dateview'] = '¥ ';
 $string['defaultapproval'] = '  ⺻';
@@ -61,8 +63,16 @@ $string['descending'] = '';
 $string['destination'] = '';
 $string['displayformat'] = ' ';
 $string['displayformatcontinuous'] = 'ø̾ ̾';
+$string['displayformatdictionary'] = '  ';
+$string['displayformatencyclopedia'] = '';
+$string['displayformatentrylist'] = 'Ը';
+$string['displayformatfaq'] = '';
+$string['displayformatfullwithauthor'] = 'ø̱۷β';
+$string['displayformatfullwithoutauthor'] = 'ø̰ƴѱ۷β';
 $string['displayformats'] = ' ';
+$string['displayformatssetup'] = 'غ';
 $string['duplicateentry'] = '׸ ';
+$string['editalways'] = '׻ϱ';
 $string['editcategories'] = ' ';
 $string['editentry'] = '׸ ';
 $string['editingcomment'] = ' ';
@@ -75,6 +85,9 @@ $string['entryapproved'] = ' ׸ ε';
 $string['entrydeleted'] = '׸ ';
 $string['entryexported'] = '׸  ';
 $string['entryishidden'] = '( ׸  )';
+$string['entryleveldefaultsettings'] = 'Է¼ ʱȭ';
+$string['entrysaved'] = 'ԷǾ';
+$string['entryupdated'] = 'Է';
 $string['entryusedynalink'] = '׸ ڵ ũ';
 $string['explainaddentry'] = ' ڷ  ׸ ߰մϴ.';
 $string['explainall'] = ' ʿ  ׸ ';
@@ -91,6 +104,8 @@ $string['filetoimport'] = ' ';
 $string['fillfields'] = 'ʼ ä־ ϴ ׸';
 $string['filtername'] = '۷μ ڵ ũ';
 $string['fullmatch'] = ' ġϴ ܾ';
+$string['globalglossary'] = 'Ǿֻ';
+$string['glossaryleveldefaultsettings'] = 'ּʱ⼳';
 $string['glossarytype'] = 'ڷ ';
 $string['glosssaryexported'] = 'ڷ ';
 $string['importcategories'] = '׸ ';
@@ -116,6 +131,7 @@ $string['notcategorised'] = '  ';
 $string['numberofentries'] = '׸ ';
 $string['onebyline'] = '( ٿ ϳ)';
 $string['printerfriendly'] = 'μ ';
+$string['printviewnotallowed'] = '¹̸Ⱑ ';
 $string['question'] = '';
 $string['rate'] = 'õ';
 $string['rating'] = 'õϱ';
@@ -128,6 +144,7 @@ $string['ratingsuse'] = 'õ ';
 $string['ratingtime'] = 'Ʒ  Ⱓ ׸ õ  ֵ մϴ:';
 $string['rejectedentries'] = 'ݼ۵ ׸';
 $string['rejectionrpt'] = 'ݼ ';
+$string['rsssubscriberss'] = '\'Sa\'RSS մϴ';
 $string['searchindefinition'] = ' ˻';
 $string['secondaryglossary'] = ' ڷ';
 $string['sendinratings'] = ' ֱ õ ּ';
@@ -141,14 +158,12 @@ $string['sortchronogically'] = 'ǥ  ';
 $string['special'] = 'Ư';
 $string['standardview'] = ' ';
 $string['studentcanpost'] = 'л ׸ ߰  ';
-$string['thischarset'] = 'euc-kr';
-$string['thisdirection'] = 'ltr';
-$string['thislanguage'] = '&#54620;&#44397;&#50612;';
 $string['totalentries'] = 'ü ׸';
 $string['usedynalink'] = 'ڷ ׸ ڵ ũ';
 $string['waitingapproval'] = '  ';
 $string['warningstudentcapost'] = '(ڷ  ڷ ƴҶ ϼ)';
+$string['withauthor'] = 'ø̻,';
+$string['withoutauthor'] = 'ø̻ ';
 $string['writtenby'] = 'ø:';
 $string['youarenottheauthor'] = '    ĥ  ֽϴ.';
-
 ?>
