@@ -1,4 +1,4 @@
-<?PHP  //$Id: mysql.php,v 1.105.2.12 2005/02/08 20:33:12 defacer Exp $
+<?PHP  //$Id: mysql.php,v 1.153.2.6 2005/07/15 13:03:19 moodler Exp $
 //
 // This file keeps track of upgrades to Moodle.
 //
@@ -282,7 +282,7 @@ function main_upgrade($oldversion=0) {
         if ($files = get_directory_list($CFG->dataroot)) {
             echo "Attempting to update permissions for all files... ignore any errors.";
             foreach ($files as $file) {
-                echo "$CFG->dataroot/$file<br>";
+                echo "$CFG->dataroot/$file<br />";
                 @chmod("$CFG->dataroot/$file", $CFG->directorypermissions);
             }
         }
@@ -325,7 +325,7 @@ function main_upgrade($oldversion=0) {
         }
 
         $cerrors = "";
-        echo "Checking userdatabase:<br>";
+        echo "Checking userdatabase:<br />";
         foreach ($users as $user) {
             $lcname = trim(moodle_strtolower($user->username));
             if ($lcname != $user->username) {
@@ -834,33 +834,82 @@ function main_upgrade($oldversion=0) {
         }
     }
 
+    if ($oldversion < 2004082600) {
+        //update auth-fields for external users
+        include_once ($CFG->dirroot."/auth/".$CFG->auth."/lib.php");
+        if (function_exists('auth_get_userlist')) {
+            $externalusers = auth_get_userlist();
+            if (!empty($externalusers)){
+                $externalusers = '\''. implode('\',\'',$externalusers).'\'';
+                execute_sql("UPDATE {$CFG->prefix}user SET auth = '$CFG->auth' WHERE username  IN ($externalusers)");
+            }
+        }
+    }
+
     if ($oldversion < 2004082900) {  // Make sure guest is "manual" too.
         set_field('user', 'auth', 'manual', 'username', 'guest');
     }
+    
+    /* Commented out unused guid-field code
+    if ($oldversion < 2004090300) { // Add guid-field used in user syncronization
+        table_column('user', '', 'guid', 'varchar', '128', '', '', '', 'auth');
+        execute_sql("ALTER TABLE {$CFG->prefix}user ADD INDEX authguid (auth, guid)");
+    }
+    */
 
-    if ($oldversion < 2004083127) {  // Update any users/courses using wrongly-named lang pack
+    if ($oldversion < 2004091900) { // modify idnumber to hold longer values
+        table_column('user', 'idnumber', 'idnumber', 'varchar', '64', '', '', '', '');
+        execute_sql("ALTER TABLE {$CFG->prefix}user DROP INDEX user_idnumber",false); // added in case of conflicts with upgrade from 14stable
+        execute_sql("ALTER TABLE {$CFG->prefix}user DROP INDEX user_auth",false); // added in case of conflicts with upgrade from 14stable
+
+        execute_sql("ALTER TABLE {$CFG->prefix}user ADD INDEX idnumber (idnumber)");
+        execute_sql("ALTER TABLE {$CFG->prefix}user ADD INDEX auth (auth)");
+    }
+
+    if ($oldversion < 2004093001) { // add new table for sessions storage
+        execute_sql(" CREATE TABLE `{$CFG->prefix}sessions` (
+                          `sesskey` char(32) NOT null,
+                          `expiry` int(11) unsigned NOT null,
+                          `expireref` varchar(64),
+                          `data` text NOT null,
+                          PRIMARY KEY (`sesskey`), 
+                          KEY (`expiry`) 
+                      ) TYPE=MyISAM COMMENT='Optional database session storage, not used by default';");
+    }
+
+    if ($oldversion < 2004111500) {  // Update any users/courses using wrongly-named lang pack
         execute_sql("UPDATE {$CFG->prefix}user SET lang = 'mi_nt' WHERE lang = 'ma_nt'");
         execute_sql("UPDATE {$CFG->prefix}course SET lang = 'mi_nt' WHERE lang = 'ma_nt'");
     }
 
-    if ($oldversion < 2004083128) { // add indexes.
-        execute_sql(" ALTER TABLE `{$CFG->prefix}user` ADD INDEX user_idnumber (idnumber) ");
-        execute_sql(" ALTER TABLE `{$CFG->prefix}user` ADD INDEX user_auth (auth) ");
+    if ($oldversion < 2004111700) { // add indexes. - drop them first silently to avoid conflicts when upgrading.
+        execute_sql(" ALTER TABLE `{$CFG->prefix}course` DROP INDEX idnumber;",false);
+        execute_sql(" ALTER TABLE `{$CFG->prefix}course` DROP INDEX shortname;",false);
+        execute_sql(" ALTER TABLE `{$CFG->prefix}user_students` DROP INDEX userid;",false);
+        execute_sql(" ALTER TABLE `{$CFG->prefix}user_teachers` DROP INDEX userid;",false);
+
+        execute_sql(" ALTER TABLE `{$CFG->prefix}course` ADD INDEX idnumber (idnumber);");
+        execute_sql(" ALTER TABLE `{$CFG->prefix}course` ADD INDEX shortname (shortname);");
+        execute_sql(" ALTER TABLE `{$CFG->prefix}user_students` ADD INDEX userid (userid);");
+        execute_sql(" ALTER TABLE `{$CFG->prefix}user_teachers` ADD INDEX userid (userid);");
     }
 
-    if ($oldversion < 2004083128) { // add indexes.
-        execute_sql(" ALTER TABLE `{$CFG->prefix}course` ADD INDEX idnumber (idnumber) ");
-        execute_sql(" ALTER TABLE `{$CFG->prefix}course` ADD INDEX shortname (shortname) ");
-        execute_sql(" ALTER TABLE `{$CFG->prefix}user_students` ADD INDEX userid (userid) ");
-        execute_sql(" ALTER TABLE `{$CFG->prefix}user_teachers` ADD INDEX userid (userid) ");
-    }
+    if ($oldversion < 2004111700) {// add an index to event for timestart and timeduration. - drop them first silently to avoid conflicts when upgrading.
+        execute_sql("ALTER TABLE {$CFG->prefix}event DROP INDEX timestart;",false);
+        execute_sql("ALTER TABLE {$CFG->prefix}event DROP INDEX timeduration;",false); 
 
-    if ($oldversion < 2004083128) {// add an index to event for timestart and timeduration
         modify_database('','ALTER TABLE prefix_event ADD INDEX timestart (timestart);');
         modify_database('','ALTER TABLE prefix_event ADD INDEX timeduration (timeduration);');
     }
 
-    if ($oldversion < 2004083128) { //add indexes on modules and course_modules
+    if ($oldversion < 2004111700) { //add indexes on modules and course_modules. - drop them first silently to avoid conflicts when upgrading.
+        execute_sql("ALTER TABLE {$CFG->prefix}course_modules drop key visible;",false);
+        execute_sql("ALTER TABLE {$CFG->prefix}course_modules drop key course;",false);
+        execute_sql("ALTER TABLE {$CFG->prefix}course_modules drop key module;",false);
+        execute_sql("ALTER TABLE {$CFG->prefix}course_modules drop key instance;",false);
+        execute_sql("ALTER TABLE {$CFG->prefix}course_modules drop key deleted;",false);
+        execute_sql("ALTER TABLE {$CFG->prefix}modules drop key name;",false);
+
         modify_database('','ALTER TABLE prefix_course_modules add key visible(visible);');
         modify_database('','ALTER TABLE prefix_course_modules add key course(course);');
         modify_database('','ALTER TABLE prefix_course_modules add key module(module);');
@@ -869,25 +918,43 @@ function main_upgrade($oldversion=0) {
         modify_database('','ALTER TABLE prefix_modules add key name(name);');
     }
 
+    if ($oldversion < 2004111700) { // add an index on the groups_members table. - drop them first silently to avoid conflicts when upgrading.
+        execute_sql("ALTER TABLE {$CFG->prefix}groups_members DROP INDEX userid;",false);
 
-    if ($oldversion < 2004083128) { // add an index on the groups_members table
         modify_database('','ALTER TABLE prefix_groups_members ADD INDEX userid (userid);');
     }
 
-    if ($oldversion < 2004083128) { // add an index on user students timeaccess (used for sorting)
+    if ($oldversion < 2004111700) { // add an index on user students timeaccess (used for sorting)- drop them first silently to avoid conflicts when upgrading
+        execute_sql("ALTER TABLE {$CFG->prefix}user_students DROP INDEX timeaccess;",false);
+
         modify_database('','ALTER TABLE prefix_user_students ADD INDEX timeaccess (timeaccess);');
     }
 
-    if ($oldversion < 2004083128) { 
+    if ($oldversion < 2004111700) {  // add indexes on faux-foreign keys. - drop them first silently to avoid conflicts when upgrading.
+        execute_sql("ALTER TABLE {$CFG->prefix}scale DROP INDEX courseid;",false);
+        execute_sql("ALTER TABLE {$CFG->prefix}user_admins DROP INDEX userid;",false);
+        execute_sql("ALTER TABLE {$CFG->prefix}user_coursecreators DROP INDEX userid;",false);
+
         modify_database('','ALTER TABLE prefix_scale ADD INDEX courseid (courseid);');
         modify_database('','ALTER TABLE prefix_user_admins ADD INDEX userid (userid);');
         modify_database('','ALTER TABLE prefix_user_coursecreators ADD INDEX userid (userid);');
     }
 
-    if ($oldversion < 2004083128) { // replace index on course
+    if ($oldversion < 2004111700) { // replace index on course
         fix_course_sortorder(0,0,1);
-        modify_database('', "ALTER TABLE `prefix_course` DROP KEY category");
+        execute_sql("ALTER TABLE `{$CFG->prefix}course` DROP KEY category",false);
+
+        execute_sql("ALTER TABLE `{$CFG->prefix}course` DROP KEY category_sortorder;",false);
         modify_database('', "ALTER TABLE `prefix_course` ADD UNIQUE KEY category_sortorder(category,sortorder)"); 
+
+        execute_sql("ALTER TABLE `{$CFG->prefix}user` DROP INDEX {$CFG->prefix}user_deleted_idx;",false);
+        execute_sql("ALTER TABLE `{$CFG->prefix}user` DROP INDEX {$CFG->prefix}user_confirmed_idx;",false);
+        execute_sql("ALTER TABLE `{$CFG->prefix}user` DROP INDEX {$CFG->prefix}user_firstname_idx;",false);
+        execute_sql("ALTER TABLE `{$CFG->prefix}user` DROP INDEX {$CFG->prefix}user_lastname_idx;",false);
+        execute_sql("ALTER TABLE `{$CFG->prefix}user` DROP INDEX {$CFG->prefix}user_city_idx;",false); 
+        execute_sql("ALTER TABLE `{$CFG->prefix}user` DROP INDEX {$CFG->prefix}user_country_idx;",false); 
+        execute_sql("ALTER TABLE `{$CFG->prefix}user` DROP INDEX {$CFG->prefix}user_lastaccess_idx;",false);
+
         modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_deleted_idx  (deleted)");
         modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_confirmed_idx (confirmed)");
         modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_firstname_idx (firstname)");
@@ -895,41 +962,21 @@ function main_upgrade($oldversion=0) {
         modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_city_idx (city)");
         modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_country_idx (country)");
         modify_database("", "ALTER TABLE `prefix_user` ADD INDEX prefix_user_lastaccess_idx (lastaccess)");
-    }
-    
-    if ($oldversion < 2004083128) { // one more index for email (for sorting)
+     }
+ 
+    if ($oldversion < 2004111700) { // one more index for email (for sorting)
+        execute_sql("ALTER TABLE `{$CFG->prefix}user` DROP INDEX {$CFG->prefix}user_email_idx;",false);
         modify_database('','ALTER TABLE `prefix_user` ADD INDEX prefix_user_email_idx (email);');
     }
 
-    if ($oldversion < 2004083129) { // Undoing some module version mess from recent upgrade
-        if (get_field('modules', 'version', 'name', 'assignment') == '2004111200') {
-            set_field('modules', 'version', 2004060401, 'name', 'assignment');
-        }
-        if (get_field('modules', 'version', 'name', 'attendance') == '2004111200') {
-            set_field('modules', 'version', 2004060401, 'name', 'attendance');
-        }
-        if (get_field('modules', 'version', 'name', 'chat') == '2004121100') {
-            set_field('modules', 'version', 2004060401, 'name', 'chat');
-        }
-        if (get_field('modules', 'version', 'name', 'choice') == '2004111200') {
-            set_field('modules', 'version', 2004070103, 'name', 'choice');
-        }
-        if (get_field('modules', 'version', 'name', 'dialogue') == '2004111000') {
-            set_field('modules', 'version', 2004060401, 'name', 'dialogue');
-        }
-        if (get_field('modules', 'version', 'name', 'exercise') == '2004111200') {
-            set_field('modules', 'version', 2004062301, 'name', 'exercise');
-        }
-        if (get_field('modules', 'version', 'name', 'forum') == '2004111200') {
-            set_field('modules', 'version', 2004081801, 'name', 'forum');
-        }
-        if (get_field('modules', 'version', 'name', 'glossary') == '2004111200') {
-            set_field('modules', 'version', 2004080932, 'name', 'glossary');
-        }
+    if ($oldversion < 2004112200) { // new 'enrol' field for enrolment tables
+        table_column('user_students', '', 'enrol', 'varchar', '20', '', '', 'not null');
+        table_column('user_teachers', '', 'enrol', 'varchar', '20', '', '', 'not null');
+        execute_sql("ALTER TABLE `{$CFG->prefix}user_students` ADD INDEX enrol (enrol);");
+        execute_sql("ALTER TABLE `{$CFG->prefix}user_teachers` ADD INDEX enrol (enrol);");
     }
-
     
-    if ($oldversion < 2004083130) {
+    if ($oldversion < 2004112400) {
         /// Delete duplicate enrolments 
         /// and then tell the database course,userid is a unique combination
         if ($users = get_records_select("user_students", "userid > 0 GROUP BY course, userid ".
@@ -954,22 +1001,455 @@ function main_upgrade($oldversion=0) {
             }
         }
         flush();
-        
         modify_database('','ALTER TABLE prefix_user_teachers DROP INDEX courseuserid;');
         modify_database('','ALTER TABLE prefix_user_teachers ADD UNIQUE INDEX courseuserid(course,userid);');        
     } 
 
-    if ($oldversion < 2004083133) {
+    if ($oldversion < 2004112900) {
+        table_column('user', '', 'policyagreed', 'integer', '1', 'unsigned', '0', 'not null', 'confirmed');
+    }
+
+    if ($oldversion < 2004121400) {
+        table_column('groups', '', 'password', 'varchar', '50', '', '', 'not null', 'description');
+    }
+
+    if ($oldversion < 2004121500) {
+        modify_database('',"CREATE TABLE prefix_dst_preset (
+            id int(10) NOT NULL auto_increment,
+            name char(48) default '' NOT NULL,
+            
+            apply_offset tinyint(3) default '0' NOT NULL,
+            
+            activate_index tinyint(1) default '1' NOT NULL,
+            activate_day tinyint(1) default '1' NOT NULL,
+            activate_month tinyint(2) default '1' NOT NULL,
+            activate_time char(5) default '03:00' NOT NULL,
+            
+            deactivate_index tinyint(1) default '1' NOT NULL,
+            deactivate_day tinyint(1) default '1' NOT NULL,
+            deactivate_month tinyint(2) default '2' NOT NULL,
+            deactivate_time char(5) default '03:00' NOT NULL,
+            
+            last_change int(10) default '0' NOT NULL,
+            next_change int(10) default '0' NOT NULL,
+            current_offset tinyint(3) default '0' NOT NULL,
+            
+            PRIMARY KEY (id))");
+    }       
+
+    if ($oldversion < 2004122800) {
+        execute_sql("DROP TABLE {$CFG->prefix}message", false);
+        execute_sql("DROP TABLE {$CFG->prefix}message_read", false);
+        execute_sql("DROP TABLE {$CFG->prefix}message_contacts", false);
+
+        modify_database('',"CREATE TABLE `prefix_message` (
+                               `id` int(10) unsigned NOT NULL auto_increment,
+                               `useridfrom` int(10) NOT NULL default '0',
+                               `useridto` int(10) NOT NULL default '0',
+                               `message` text NOT NULL,
+                               `timecreated` int(10) NOT NULL default '0',
+                               `messagetype` varchar(50) NOT NULL default '',
+                               PRIMARY KEY  (`id`),
+                               KEY `useridfrom` (`useridfrom`),
+                               KEY `useridto` (`useridto`)
+                             ) TYPE=MyISAM COMMENT='Stores all unread messages';");
+
+        modify_database('',"CREATE TABLE `prefix_message_read` (
+                               `id` int(10) unsigned NOT NULL auto_increment,
+                               `useridfrom` int(10) NOT NULL default '0',
+                               `useridto` int(10) NOT NULL default '0',
+                               `message` text NOT NULL,
+                               `timecreated` int(10) NOT NULL default '0',
+                               `timeread` int(10) NOT NULL default '0',
+                               `messagetype` varchar(50) NOT NULL default '',
+                               `mailed` tinyint(1) NOT NULL default '0',
+                               PRIMARY KEY  (`id`),
+                               KEY `useridfrom` (`useridfrom`),
+                               KEY `useridto` (`useridto`)
+                             ) TYPE=MyISAM COMMENT='Stores all messages that have been read';");
+
+        modify_database('',"CREATE TABLE `prefix_message_contacts` (
+                               `id` int(10) unsigned NOT NULL auto_increment,
+                               `userid` int(10) unsigned NOT NULL default '0',
+                               `contactid` int(10) unsigned NOT NULL default '0',
+                               `blocked` tinyint(1) unsigned NOT NULL default '0',
+                               PRIMARY KEY  (`id`),
+                               UNIQUE KEY `usercontact` (`userid`,`contactid`)
+                             ) TYPE=MyISAM COMMENT='Maintains lists of relationships between users';");
+
+        modify_database('', "INSERT INTO prefix_log_display VALUES ('message', 'write', 'user', 'CONCAT(firstname,\" \",lastname)'); ");
+        modify_database('', "INSERT INTO prefix_log_display VALUES ('message', 'read', 'user', 'CONCAT(firstname,\" \",lastname)'); ");
+    }
+
+    if ($oldversion < 2004122801) {
+        table_column('message', '', 'format', 'integer', '4', 'unsigned', '0', 'not null', 'message');
+        table_column('message_read', '', 'format', 'integer', '4', 'unsigned', '0', 'not null', 'message');
+    }
+
+    if ($oldversion < 2005010100) {
+        modify_database('', "INSERT INTO prefix_log_display VALUES ('message', 'add contact', 'user', 'CONCAT(firstname,\" \",lastname)'); ");
+        modify_database('', "INSERT INTO prefix_log_display VALUES ('message', 'remove contact', 'user', 'CONCAT(firstname,\" \",lastname)'); ");
+        modify_database('', "INSERT INTO prefix_log_display VALUES ('message', 'block contact', 'user', 'CONCAT(firstname,\" \",lastname)'); ");
+        modify_database('', "INSERT INTO prefix_log_display VALUES ('message', 'unblock contact', 'user', 'CONCAT(firstname,\" \",lastname)'); ");
+    }
+
+    if ($oldversion < 2005011000) {     // Create a .htaccess file in dataroot, just in case
+        if (!file_exists($CFG->dataroot.'/.htaccess')) {
+            if ($handle = fopen($CFG->dataroot.'/.htaccess', 'w')) {   // For safety
+                @fwrite($handle, "deny from all\r\n");
+                @fclose($handle); 
+                notify("Created a default .htaccess file in $CFG->dataroot");
+            }
+        }
+    }
+    
+
+    if ($oldversion < 2005012500) { 
+        /*
+        // add new table for meta courses.
+        modify_database("","CREATE TABLE `prefix_meta_course` (
+            `id` int(1) unsigned NOT NULL auto_increment,
+            `parent_course` int(10) NOT NULL default 0,
+            `child_course` int(10) NOT NULL default 0,
+            PRIMARY KEY (`id`),
+            KEY `parent_course` (parent_course),
+            KEY `child_course` (child_course)
+        );");
+        // add flag to course field
+        table_column('course','','meta_course','integer','1','','0','not null');
+        */ // taking this OUT for upgrade from 1.4 to 1.5 (those tracking head will have already seen it)
+    }
+
+    if ($oldversion < 2005012501) { 
+        execute_sql("DROP TABLE {$CFG->prefix}meta_course",false); // drop silently
+        execute_sql("ALTER TABLE {$CFG->prefix}course DROP COLUMN meta_course",false); // drop silently
+        
+        // add new table for meta courses.
+        modify_database("","CREATE TABLE `prefix_course_meta` (
+            `id` int(10) unsigned NOT NULL auto_increment,
+            `parent_course` int(10) NOT NULL default 0,
+            `child_course` int(10) NOT NULL default 0,
+            PRIMARY KEY (`id`),
+            KEY `parent_course` (parent_course),
+            KEY `child_course` (child_course)
+        );");
+        // add flag to course field
+        table_column('course','','metacourse','integer','1','','0','not null');
+    }
+
+    if ($oldversion < 2005012800) {
+        // fix a typo (int 1 becomes int 10) 
+        table_column('course_meta','id','id','integer','10','','0','not null');
+    }
+
+    if ($oldversion < 2005020100) {
         fix_course_sortorder(0, 1, 1);
     }   
 
-    if ($oldversion < 2004083134) {
-        // Expand module column to max 20 chars
+
+    if ($oldversion < 2005020101) {
+        // hopefully this is the LAST TIME we need to do this ;)
+        if ($rows = count_records("course_meta")) {
+            // we need to upgrade
+            modify_database("","CREATE TABLE `prefix_course_meta_tmp` (
+            `parent_course` int(10) NOT NULL default 0,
+            `child_course` int(10) NOT NULL default 0);");
+            
+            execute_sql("INSERT INTO {$CFG->prefix}course_meta_tmp (parent_course,child_course) 
+               SELECT {$CFG->prefix}course_meta.parent_course, {$CFG->prefix}course_meta.child_course
+               FROM {$CFG->prefix}course_meta");
+            $insertafter = true;
+        }
+
+        execute_sql("DROP TABLE {$CFG->prefix}course_meta");
+
+        modify_database("","CREATE TABLE `prefix_course_meta` (
+            `id` int(10) unsigned NOT NULL auto_increment,
+            `parent_course` int(10) unsigned NOT NULL default 0,
+            `child_course` int(10) unsigned NOT NULL default 0,
+            PRIMARY KEY (`id`),
+            KEY `parent_course` (parent_course),
+            KEY `child_course` (child_course));");
+
+        if (!empty($insertafter)) {
+            execute_sql("INSERT INTO {$CFG->prefix}course_meta (parent_course,child_course) 
+               SELECT {$CFG->prefix}course_meta_tmp.parent_course, {$CFG->prefix}course_meta_tmp.child_course
+               FROM {$CFG->prefix}course_meta_tmp");
+
+            execute_sql("DROP TABLE {$CFG->prefix}course_meta_tmp");
+        }
+    }
+
+    if ($oldversion < 2005020800) {     // Expand module column to max 20 chars
         table_column('log','module','module','varchar','20','','','not null');
     }
 
-    return $result;
+    if ($oldversion < 2005021000) {     // New fields for theme choices
+        table_column('course', '', 'theme', 'varchar', '50', '', '', '', 'lang');
+        table_column('groups', '', 'theme', 'varchar', '50', '', '', '', 'lang');
+        table_column('user',   '', 'theme', 'varchar', '50', '', '', '', 'lang');
+
+        set_config('theme', 'standardwhite');         // Reset to a known good theme 
+    }
     
+    if ($oldversion < 2005021600) {     // course.idnumber should be varchar(100)
+        table_column('course', 'idnumber', 'idnumber', 'varchar', '100', '', '', '', '');
+    }
+
+    if ($oldversion < 2005021700) {
+        table_column('user', '', 'dstpreset', 'int', '10', '', '0', 'not null', 'timezone');
+    }
+
+    if ($oldversion < 2005021800) {     // For database debugging, not for normal use
+        modify_database(""," CREATE TABLE `adodb_logsql` (
+                               `created` datetime NOT NULL,
+                               `sql0` varchar(250) NOT NULL,
+                               `sql1` text NOT NULL,
+                               `params` text NOT NULL,
+                               `tracer` text NOT NULL,
+                               `timer` decimal(16,6) NOT NULL
+                              );");
+    }
+
+    if ($oldversion < 2005022400) {
+        // Add more visible digits to the fields
+        table_column('dst_preset', 'activate_index', 'activate_index', 'tinyint', '2', '', '0', 'not null');
+        table_column('dst_preset', 'activate_day', 'activate_day', 'tinyint', '2', '', '0', 'not null');
+        // Add family and year fields
+        table_column('dst_preset', '', 'family', 'varchar', '100', '', '', 'not null', 'name');
+        table_column('dst_preset', '', 'year', 'int', '10', '', '0', 'not null', 'family');
+    }
+
+    if ($oldversion < 2005030501) {
+        table_column('user', '', 'msn', 'varchar', '50', '', '', '', 'icq');
+        table_column('user', '', 'aim', 'varchar', '50', '', '', '', 'icq');
+        table_column('user', '', 'yahoo', 'varchar', '50', '', '', '', 'icq');
+        table_column('user', '', 'skype', 'varchar', '50', '', '', '', 'icq');
+    }
+
+    if ($oldversion < 2005032300) {
+        table_column('user', 'dstpreset', 'timezonename', 'varchar', '100');
+        execute_sql('UPDATE `'.$CFG->prefix.'user` SET timezonename = \'\'');
+    }
+
+    if ($oldversion < 2005032600) {
+        execute_sql('DROP TABLE '.$CFG->prefix.'dst_preset', false);
+        modify_database('',"CREATE TABLE `prefix_timezone` (
+                              `id` int(10) NOT NULL auto_increment,
+                              `name` varchar(100) NOT NULL default '',
+                              `year` int(11) NOT NULL default '0',
+                              `rule` varchar(20) NOT NULL default '',
+                              `gmtoff` int(11) NOT NULL default '0',
+                              `dstoff` int(11) NOT NULL default '0',
+                              `dst_month` tinyint(2) NOT NULL default '0',
+                              `dst_startday` tinyint(3) NOT NULL default '0',
+                              `dst_weekday` tinyint(3) NOT NULL default '0',
+                              `dst_skipweeks` tinyint(3) NOT NULL default '0',
+                              `dst_time` varchar(5) NOT NULL default '00:00',
+                              `std_month` tinyint(2) NOT NULL default '0',
+                              `std_startday` tinyint(3) NOT NULL default '0',
+                              `std_weekday` tinyint(3) NOT NULL default '0',
+                              `std_skipweeks` tinyint(3) NOT NULL default '0',
+                              `std_time` varchar(5) NOT NULL default '00:00',
+                              PRIMARY KEY (`id`)
+                            ) TYPE=MyISAM COMMENT='Rules for calculating local wall clock time for users';");
+    }
+
+    if ($oldversion < 2005032800) {
+        execute_sql("CREATE TABLE `{$CFG->prefix}grade_category` (
+            `id` int(10) unsigned NOT NULL auto_increment,
+            `name` varchar(64) default NULL,
+            `courseid` int(10) unsigned NOT NULL default '0',
+            `drop_x_lowest` int(10) unsigned NOT NULL default '0',
+            `bonus_points` int(10) unsigned NOT NULL default '0',
+            `hidden` int(10) unsigned NOT NULL default '0',
+            `weight` decimal(4,2) default '0.00',
+            PRIMARY KEY  (`id`),
+            KEY `courseid` (`courseid`)
+          ) TYPE=MyISAM ;");
+
+        execute_sql("CREATE TABLE `{$CFG->prefix}grade_exceptions` (
+            `id` int(10) unsigned NOT NULL auto_increment,
+            `courseid` int(10) unsigned NOT NULL default '0',
+            `grade_itemid` int(10) unsigned NOT NULL default '0',
+            `userid` int(10) unsigned NOT NULL default '0',
+            PRIMARY KEY  (`id`),
+            KEY `courseid` (`courseid`)
+          ) TYPE=MyISAM ;");
+
+
+        execute_sql("CREATE TABLE `{$CFG->prefix}grade_item` (
+            `id` int(10) unsigned NOT NULL auto_increment,
+            `courseid` int(10) unsigned default NULL,
+            `category` int(10) unsigned default NULL,
+            `modid` int(10) unsigned default NULL,
+            `cminstance` int(10) unsigned default NULL,
+            `scale_grade` float(11,10) default '1.0000000000',
+            `extra_credit` int(10) unsigned NOT NULL default '0',
+            `sort_order` int(10) unsigned NOT NULL default '0',
+            PRIMARY KEY  (`id`),
+            KEY `courseid` (`courseid`)
+          ) TYPE=MyISAM ;");
+
+
+        execute_sql("CREATE TABLE `{$CFG->prefix}grade_letter` (
+            `id` int(10) unsigned NOT NULL auto_increment,
+            `courseid` int(10) unsigned NOT NULL default '0',
+            `letter` varchar(8) NOT NULL default 'NA',
+            `grade_high` decimal(4,2) NOT NULL default '100.00',
+            `grade_low` decimal(4,2) NOT NULL default '0.00',
+            PRIMARY KEY  (`id`),
+            KEY `courseid` (`courseid`)
+          ) TYPE=MyISAM ;");
+          
+
+        execute_sql("CREATE TABLE `{$CFG->prefix}grade_preferences` (
+            `id` int(10) unsigned NOT NULL auto_increment,
+            `courseid` int(10) unsigned default NULL,
+            `preference` int(10) NOT NULL default '0',
+            `value` int(10) NOT NULL default '0',
+            PRIMARY KEY  (`id`),
+            UNIQUE KEY `courseidpreference` (`courseid`,`preference`)
+          ) TYPE=MyISAM ;");
+          
+    }
+
+    if ($oldversion < 2005033100) {   // Get rid of defunct field from course modules table
+         delete_records('course_modules', 'deleted', 1);  // Delete old records we don't need any more
+         execute_sql('ALTER TABLE `'.$CFG->prefix.'course_modules` DROP INDEX `deleted`');  // Old index
+         execute_sql('ALTER TABLE `'.$CFG->prefix.'course_modules` DROP `deleted`');    // Old field
+    }
+
+    if ($oldversion < 2005040800) {
+        table_column('user', 'timezone', 'timezone', 'varchar', '100', '', '99');
+        execute_sql(" ALTER TABLE `{$CFG->prefix}user` DROP `timezonename` ");
+    }
+    
+    if ($oldversion < 2005041101) {
+        require_once($CFG->libdir.'/filelib.php');
+        if (is_readable($CFG->dirroot.'/lib/timezones.txt')) {  // Distribution file
+            if ($timezones = get_records_csv($CFG->dirroot.'/lib/timezones.txt', 'timezone')) {
+                $db->debug = false;
+                update_timezone_records($timezones);
+                notify(count($timezones).' timezones installed');
+                $db->debug = true;
+            }
+        }
+    }
+
+    if ($oldversion < 2005041900) {  // Copy all Dialogue entries into Messages, and hide Dialogue module
+
+        if ($entries = get_records_sql('SELECT e.id, e.userid, c.recipientid, e.text, e.timecreated
+                                          FROM '.$CFG->prefix.'dialogue_conversations c,
+                                               '.$CFG->prefix.'dialogue_entries e
+                                         WHERE e.conversationid = c.id')) {
+            foreach ($entries as $entry) {
+                $message = new object;
+                $message->useridfrom    = $entry->userid;
+                $message->useridto      = $entry->recipientid;
+                $message->message       = addslashes($entry->text);
+                $message->format        = FORMAT_HTML;
+                $message->timecreated   = $entry->timecreated;
+                $message->messagetype   = 'direct';
+            
+                insert_record('message_read', $message);
+            }
+        }
+
+        set_field('modules', 'visible', 0, 'name', 'dialogue');
+
+        notify('The Dialogue module has been disabled, and all the old Messages from it copied into the new standard Message feature.  If you really want Dialogue back, you can enable it using the "eye" icon here:  Admin >> Modules >> Dialogue');
+
+    }
+
+    if ($oldversion < 2005042100) {
+        $result = table_column('event', '', 'repeatid', 'int', '10', 'unsigned', '0', 'not null', 'userid') && $result;
+    }
+
+    if ($oldversion < 2005042400) {  // Add user tracking prefs field.
+        table_column('user', '', 'trackforums', 'int', '4', 'unsigned', '0', 'not null', 'autosubscribe');
+    }
+
+    if ($oldversion < 2005052301 ) { // Add config_plugins table
+        
+        execute_sql("CREATE TABLE `{$CFG->prefix}config_plugins` (
+                                  `id`         int(10) unsigned NOT NULL auto_increment,
+                                  `plugin`     varchar(100) NOT NULL default 'core',
+                                  `name`       varchar(100) NOT NULL default '',
+                                  `value`      text NOT NULL default '',
+                                  PRIMARY KEY  (`id`),
+                                  UNIQUE KEY `plugin_name` (`plugin`, `name`)
+                                  ) TYPE=MyISAM 
+                                  COMMENT='Moodle modules and plugins configuration variables';");
+    }
+
+    if ($oldversion < 2005052302) {  // migrate some config items to config_plugins table
+
+        // NOTE: this block is in both postgres AND mysql upgrade
+        // files. If you edit either, update the otherone. 
+        $user_fields = array("firstname", "lastname", "email", 
+                             "phone1", "phone2", "department", 
+                             "address", "city", "country", 
+                             "description", "idnumber", "lang");
+        if (!empty($CFG->auth)) { // if we have no auth, just pass
+            foreach ($user_fields as $field) {
+                $suffixes = array('', '_editlock', '_updateremote', '_updatelocal');
+                foreach ($suffixes as $suffix) {
+                    $key = 'auth_user_' . $field . $suffix;
+                    if (isset($CFG->$key)) {
+                        
+                        // translate keys & values
+                        // to the new convention
+                        // this should support upgrading 
+                        // even 1.5dev installs
+                        $newkey = $key;
+                        $newval = $CFG->$key;
+                        if ($suffix === '') {
+                            $newkey = 'field_map_' . $field;
+                        } elseif ($suffix === '_editlock') {
+                            $newkey = 'field_lock_' . $field;
+                            $newval = ($newval==1) ? 'locked' : 'unlocked'; // translate 0/1 to locked/unlocked
+                        } elseif ($suffix === '_updateremote') {
+                            $newkey = 'field_updateremote_' . $field;                            
+                        } elseif ($suffix === '_updatelocal') {
+                            $newkey = 'field_updatelocal_' . $field;
+                            $newval = ($newval==1) ? 'onlogin' : 'oncreate'; // translate 0/1 to locked/unlocked
+                        }
+
+                        if (!(set_config($newkey, addslashes($newval), 'auth/'.$CFG->auth)
+                            && delete_records('config', 'name', $key))) {
+                            notify("Error updating Auth configuration $key to {$CFG->auth} $newkey .");
+                            $result = false;
+                        }
+                    } // end if isset key
+                } // end foreach suffix
+            } // end foreach field
+        }
+    }
+
+    if ($oldversion < 2005060201) {  // Close down the Attendance module, we are removing it from CVS.
+        if (!file_exists($CFG->dirroot.'/mod/attendance/lib.php')) {
+            if (count_records('attendance')) {   // We have some data, so should keep it
+
+                set_field('modules', 'visible', 0, 'name', 'attendance');
+                notify('The Attendance module has been discontinued.  If you really want to 
+                        continue using it, you should download it individually from 
+                        http://download.moodle.org/modules and install it, then 
+                        reactivate it from Admin >> Configuration >> Modules.  
+                        None of your existing data has been deleted, so all existing 
+                        Attendance activities should re-appear.');
+
+            } else {  // No data, so do a complete delete
+
+                execute_sql('DROP TABLE '.$CFG->prefix.'attendance', false);
+                delete_records('modules', 'name', 'attendance');
+                notify("The Attendance module has been discontinued and removed from your site.  
+                        You weren't using it anyway.  ;-)");
+            }
+        }
+    }
+
+    return $result;
 }
 
 ?>
