@@ -1,11 +1,11 @@
-<?PHP  // $Id: subscribers.php,v 1.19 2004/08/21 20:20:55 gustav_delius Exp $
+<?php  // $Id: subscribers.php,v 1.28 2005/03/26 01:57:40 stronk7 Exp $
 
     require_once("../../config.php");
     require_once("lib.php");
 
     require_variable($id);                // forum
     optional_variable($group);            // change of group
-    
+
     optional_variable($edit);     // Turn editing on and off
 
     if (! $forum = get_record("forum", "id", $id)) {
@@ -20,7 +20,7 @@
         $cm->id = 0;
     }
 
-    require_login($course->id);
+    require_login($course->id, false, $cm);
 
     if (!isteacher($course->id)) {
         error("This page is for teachers only");
@@ -29,7 +29,7 @@
     unset($SESSION->fromdiscussion);
 
     add_to_log($course->id, "forum", "view subscribers", "subscribers.php?id=$forum->id", $forum->id, $cm->id);
-    
+
     if (isset($_GET['edit'])) {
         if($edit == "on") {
             $USER->subscriptionsediting = true;
@@ -43,11 +43,11 @@
     $strsubscribers = get_string("subscribers", "forum");
     $strforums      = get_string("forums", "forum");
 
-    $navigation = "<a href=\"index.php?id=$course->id\">$strforums</a> -> 
-       <a href=\"view.php?f=$forum->id\">$forum->name</a> -> $strsubscribers";
+    $navigation = "<a href=\"index.php?id=$course->id\">$strforums</a> ->
+       <a href=\"view.php?f=$forum->id\">".format_string($forum->name,true)."</a> -> $strsubscribers";
 
-    print_header_simple("$strsubscribers", "", "$navigation", 
-        "", "", true, forum_update_subscriptions_button($course->id, $id));
+    print_header_simple("$strsubscribers", "", "$navigation",
+        "", "", true, forum_update_subscriptions_button($course->id, $id), true);
 
 /// Check to see if groups are being used in this forum
     if ($groupmode = groupmode($course, $cm)) {   // Groups are being used
@@ -57,28 +57,28 @@
     }
 
     if (empty($USER->subscriptionsediting)) {         /// Display an overview of subscribers
-        
+
         if (! $users = forum_subscribed_users($course, $forum, $currentgroup) ) {
-    
+
             print_heading(get_string("nosubscribers", "forum"));
-    
+
         } else {
-    
-            print_heading(get_string("subscribersto","forum", "'$forum->name'"));
-    
+
+            print_heading(get_string("subscribersto","forum", "'".format_string($forum->name)."'"));
+
             echo '<table align="center" cellpadding="5" cellspacing="5">';
             foreach ($users as $user) {
-                echo "<tr><td>";
+                echo '<tr><td>';
                 print_user_picture($user->id, $course->id, $user->picture);
-                echo "</td><td bgcolor=\"$THEME->cellcontent\">";
+                echo '</td><td>';
                 echo fullname($user);
-                echo "</td><td bgcolor=\"$THEME->cellcontent\">";
-                echo "$user->email";
-                echo "</td></tr>";
+                echo '</td><td>';
+                echo $user->email;
+                echo '</td></tr>';
             }
             echo "</table>";
         }
-    
+
         print_footer($course);
         exit;
     }
@@ -124,13 +124,13 @@
     if (!$subscribers = forum_subscribed_users($course, $forum, $currentgroup)) {
         $subscribers = array();
     }
-    
+
     $subscriberarray = array();
     foreach ($subscribers as $subscriber) {
         $subscriberarray[] = $subscriber->id;
     }
     $subscriberlist = implode(',', $subscriberarray);
-    
+
     unset($subscriberarray);
 
 /// Get search results excluding any users already subscribed
@@ -138,7 +138,7 @@
     if (!empty($frm->searchtext) and $previoussearch) {
         $searchusers = search_users($course->id, $currentgroup, $frm->searchtext, 'firstname ASC, lastname ASC', $subscriberlist);
     }
-    
+
 /// If no search results then get potential subscribers for this forum excluding users already subscribed
     if (empty($searchusers)) {
         if ($currentgroup) {
@@ -155,12 +155,12 @@
     $searchtext = (isset($frm->searchtext)) ? $frm->searchtext : "";
     $previoussearch = ($previoussearch) ? '1' : '0';
 
-    print_simple_box_start("center", "", "$THEME->cellheading");
+    print_simple_box_start('center');
 
     include('subscriber.html');
 
     print_simple_box_end();
 
-    print_footer();
+    print_footer($course);
 
 ?>
