@@ -1,11 +1,12 @@
-<?PHP // $Id: import.php,v 1.3.2.1 2004/09/29 06:56:55 moodler Exp $
+<?PHP // $Id: import.php,v 1.14.2.2 2005/06/29 23:11:03 michaelpenne Exp $
       // Import quiz questions into the given category
 
     require_once("../../config.php");
     require_once("lib.php");
+    require_once("locallib.php");
 
-    optional_variable($format);
-    require_variable($id);    // Course Module ID
+    $id     = required_param('id', PARAM_INT);         // Course Module ID
+    $pageid = optional_param('pageid', '', PARAM_INT); // Page ID
 
     if (! $cm = get_record("course_modules", "id", $id)) {
         error("Course Module ID was incorrect");
@@ -20,7 +21,7 @@
     }
 
 
-    require_login($course->id);
+    require_login($course->id, false);
 
     if (!isteacher($course->id)) {
         error("Only the teacher can import questions!");
@@ -30,43 +31,37 @@
     $strlessons = get_string("modulenameplural", "lesson");
 
     print_header_simple("$strimportquestions", " $strimportquestions",
-                 "<A HREF=index.php?id=$course->id>$strlessons</A> -> <a href=\"view.php?id=$cm->id\">$lesson->name</a>-> $strimportquestions");
+                 "<a href=index.php?id=$course->id>$strlessons</a> -> <a href=\"view.php?id=$cm->id\">".format_string($lesson->name,true)."</a>-> $strimportquestions");
 
     if ($form = data_submitted()) {   /// Filename
 
         $form->format = clean_filename($form->format); // For safety
 
-        if (isset($form->filename)) {                 // file already on server
-            $newfile['tmp_name'] = $form->filename; 
-            $newfile['size'] = filesize($form->filename);
-
-        } else if (!empty($_FILES['newfile'])) {      // file was just uploaded
-            $newfile = $_FILES['newfile'];
+        if (empty($_FILES['newfile'])) {      // file was just uploaded
+            notify(get_string("uploadproblem") );
         }
 
-        if (empty($newfile)) {
-            notify(get_string("uploadproblem") );
-
-        } else if (!isset($filename) and (!is_uploaded_file($newfile['tmp_name']) or $newfile['size'] == 0)) {
+        if ((!is_uploaded_file($_FILES['newfile']['tmp_name']) or $_FILES['newfile']['size'] == 0)) {
             notify(get_string("uploadnofilefound") );
 
         } else {  // Valid file is found
 
             if (! is_readable("../quiz/format/$form->format/format.php")) {
-                error("Format not known (".clean_text($form->format).")");
+                error("Format not known ($form->format)");
             }
 
             require("format.php");  // Parent class
-            require("$CFG->dirroot/mod/quiz/lib.php"); // for the constants used in quiz/format/<format>/format.php
+            require("$CFG->dirroot/mod/quiz/locallib.php"); // for the constants used in quiz/format/<format>/format.php
             require("$CFG->dirroot/mod/quiz/format/$form->format/format.php");
 
-            $format = new quiz_file_format();
+            $classname = "quiz_format_$form->format";
+            $format = new $classname();
 
             if (! $format->importpreprocess()) {             // Do anything before that we need to
                 error("Error occurred during pre-processing!");
             }
 
-            if (! $format->importprocess($newfile['tmp_name'], $lesson, $_POST['pageid'])) {    // Process the uploaded file
+            if (! $format->importprocess($_FILES['newfile']['tmp_name'], $lesson, $pageid)) {    // Process the uploaded file
                 error("Error occurred during processing!");
             }
 
@@ -79,7 +74,7 @@
             print_footer($course);
             exit;
         }
-    } 
+    }
 
     /// Print upload form
 
@@ -97,10 +92,10 @@
 
     print_heading_with_help($strimportquestions, "import", "lesson");
 
-    print_simple_box_start("center", "", "$THEME->cellheading");
+    print_simple_box_start("center");
     echo "<form enctype=\"multipart/form-data\" method=\"post\" action=import.php>";
     echo "<input type=\"hidden\" name=\"id\" value=\"$cm->id\">\n";
-    echo "<input type=\"hidden\" name=\"pageid\" value=\"".$_GET['pageid']."\">\n";
+    echo "<input type=\"hidden\" name=\"pageid\" value=\"$pageid\">\n";
     echo "<table cellpadding=5>";
 
     echo "<tr><td align=right>";
